"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.connections_and_sockets.gears._2352 import (
        AGMAGleasonConicalGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2353 import (
        AGMAGleasonConicalGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2354 import (
        BevelDifferentialGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2355 import (
        BevelDifferentialGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2356 import (
        BevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2357 import (
        BevelGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2358 import (
        ConceptGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2359 import (
        ConceptGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2360 import (
        ConicalGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2361 import (
        ConicalGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2362 import (
        CylindricalGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2363 import (
        CylindricalGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2364 import (
        FaceGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2365 import (
        FaceGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2366 import (
        GearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2367 import (
        GearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2368 import (
        HypoidGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2369 import (
        HypoidGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2370 import (
        KlingelnbergConicalGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2371 import (
        KlingelnbergCycloPalloidConicalGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2372 import (
        KlingelnbergCycloPalloidHypoidGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2373 import (
        KlingelnbergCycloPalloidSpiralBevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2374 import (
        KlingelnbergHypoidGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2375 import (
        KlingelnbergSpiralBevelGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2376 import (
        SpiralBevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2377 import (
        SpiralBevelGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2378 import (
        StraightBevelDiffGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2379 import (
        StraightBevelDiffGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2380 import (
        StraightBevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2381 import (
        StraightBevelGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2382 import (
        WormGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2383 import (
        WormGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2384 import (
        ZerolBevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2385 import (
        ZerolBevelGearTeethSocket,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.connections_and_sockets.gears._2352": [
            "AGMAGleasonConicalGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2353": [
            "AGMAGleasonConicalGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2354": [
            "BevelDifferentialGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2355": [
            "BevelDifferentialGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2356": ["BevelGearMesh"],
        "_private.system_model.connections_and_sockets.gears._2357": [
            "BevelGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2358": [
            "ConceptGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2359": [
            "ConceptGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2360": [
            "ConicalGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2361": [
            "ConicalGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2362": [
            "CylindricalGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2363": [
            "CylindricalGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2364": ["FaceGearMesh"],
        "_private.system_model.connections_and_sockets.gears._2365": [
            "FaceGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2366": ["GearMesh"],
        "_private.system_model.connections_and_sockets.gears._2367": [
            "GearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2368": ["HypoidGearMesh"],
        "_private.system_model.connections_and_sockets.gears._2369": [
            "HypoidGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2370": [
            "KlingelnbergConicalGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2371": [
            "KlingelnbergCycloPalloidConicalGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2372": [
            "KlingelnbergCycloPalloidHypoidGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2373": [
            "KlingelnbergCycloPalloidSpiralBevelGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2374": [
            "KlingelnbergHypoidGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2375": [
            "KlingelnbergSpiralBevelGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2376": [
            "SpiralBevelGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2377": [
            "SpiralBevelGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2378": [
            "StraightBevelDiffGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2379": [
            "StraightBevelDiffGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2380": [
            "StraightBevelGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2381": [
            "StraightBevelGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2382": ["WormGearMesh"],
        "_private.system_model.connections_and_sockets.gears._2383": [
            "WormGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2384": [
            "ZerolBevelGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2385": [
            "ZerolBevelGearTeethSocket"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AGMAGleasonConicalGearMesh",
    "AGMAGleasonConicalGearTeethSocket",
    "BevelDifferentialGearMesh",
    "BevelDifferentialGearTeethSocket",
    "BevelGearMesh",
    "BevelGearTeethSocket",
    "ConceptGearMesh",
    "ConceptGearTeethSocket",
    "ConicalGearMesh",
    "ConicalGearTeethSocket",
    "CylindricalGearMesh",
    "CylindricalGearTeethSocket",
    "FaceGearMesh",
    "FaceGearTeethSocket",
    "GearMesh",
    "GearTeethSocket",
    "HypoidGearMesh",
    "HypoidGearTeethSocket",
    "KlingelnbergConicalGearTeethSocket",
    "KlingelnbergCycloPalloidConicalGearMesh",
    "KlingelnbergCycloPalloidHypoidGearMesh",
    "KlingelnbergCycloPalloidSpiralBevelGearMesh",
    "KlingelnbergHypoidGearTeethSocket",
    "KlingelnbergSpiralBevelGearTeethSocket",
    "SpiralBevelGearMesh",
    "SpiralBevelGearTeethSocket",
    "StraightBevelDiffGearMesh",
    "StraightBevelDiffGearTeethSocket",
    "StraightBevelGearMesh",
    "StraightBevelGearTeethSocket",
    "WormGearMesh",
    "WormGearTeethSocket",
    "ZerolBevelGearMesh",
    "ZerolBevelGearTeethSocket",
)
