"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.nodal_analysis.states._121 import ElementScalarState
    from mastapy._private.nodal_analysis.states._122 import ElementVectorState
    from mastapy._private.nodal_analysis.states._123 import EntityVectorState
    from mastapy._private.nodal_analysis.states._124 import NodeScalarState
    from mastapy._private.nodal_analysis.states._125 import NodeVectorState
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.nodal_analysis.states._121": ["ElementScalarState"],
        "_private.nodal_analysis.states._122": ["ElementVectorState"],
        "_private.nodal_analysis.states._123": ["EntityVectorState"],
        "_private.nodal_analysis.states._124": ["NodeScalarState"],
        "_private.nodal_analysis.states._125": ["NodeVectorState"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "ElementScalarState",
    "ElementVectorState",
    "EntityVectorState",
    "NodeScalarState",
    "NodeVectorState",
)
