"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7154 import (
        AbstractAssemblyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7155 import (
        AbstractShaftAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7156 import (
        AbstractShaftOrHousingAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7157 import (
        AbstractShaftToMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7158 import (
        AdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7159 import (
        AtsamExcitationsOrOthers,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7160 import (
        AtsamNaturalFrequencyViewOption,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7161 import (
        AdvancedTimeSteppingAnalysisForModulationOptions,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7162 import (
        AGMAGleasonConicalGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7163 import (
        AGMAGleasonConicalGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7164 import (
        AGMAGleasonConicalGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7165 import (
        AssemblyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7166 import (
        ATSAMResultsVsLargeTimeStepSettings,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7167 import (
        BearingAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7168 import (
        BeltConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7169 import (
        BeltDriveAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7170 import (
        BevelDifferentialGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7171 import (
        BevelDifferentialGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7172 import (
        BevelDifferentialGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7173 import (
        BevelDifferentialPlanetGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7174 import (
        BevelDifferentialSunGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7175 import (
        BevelGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7176 import (
        BevelGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7177 import (
        BevelGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7178 import (
        BoltAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7179 import (
        BoltedJointAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7180 import (
        ClutchAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7181 import (
        ClutchConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7182 import (
        ClutchHalfAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7183 import (
        CoaxialConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7184 import (
        ComponentAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7185 import (
        ConceptCouplingAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7186 import (
        ConceptCouplingConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7187 import (
        ConceptCouplingHalfAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7188 import (
        ConceptGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7189 import (
        ConceptGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7190 import (
        ConceptGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7191 import (
        ConicalGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7192 import (
        ConicalGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7193 import (
        ConicalGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7194 import (
        ConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7195 import (
        ConnectorAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7196 import (
        CouplingAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7197 import (
        CouplingConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7198 import (
        CouplingHalfAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7199 import (
        CVTAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7200 import (
        CVTBeltConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7201 import (
        CVTPulleyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7202 import (
        CycloidalAssemblyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7203 import (
        CycloidalDiscAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7204 import (
        CycloidalDiscCentralBearingConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7205 import (
        CycloidalDiscPlanetaryBearingConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7206 import (
        CylindricalGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7207 import (
        CylindricalGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7208 import (
        CylindricalGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7209 import (
        CylindricalPlanetGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7210 import (
        DatumAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7211 import (
        ExternalCADModelAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7212 import (
        FaceGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7213 import (
        FaceGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7214 import (
        FaceGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7215 import (
        FEPartAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7216 import (
        FlexiblePinAssemblyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7217 import (
        GearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7218 import (
        GearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7219 import (
        GearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7220 import (
        GuideDxfModelAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7221 import (
        HarmonicAnalysisOptionsForAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7222 import (
        HypoidGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7223 import (
        HypoidGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7224 import (
        HypoidGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7225 import (
        InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7226 import (
        KlingelnbergCycloPalloidConicalGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7227 import (
        KlingelnbergCycloPalloidConicalGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7228 import (
        KlingelnbergCycloPalloidConicalGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7229 import (
        KlingelnbergCycloPalloidHypoidGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7230 import (
        KlingelnbergCycloPalloidHypoidGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7231 import (
        KlingelnbergCycloPalloidHypoidGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7232 import (
        KlingelnbergCycloPalloidSpiralBevelGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7233 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7234 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7235 import (
        MassDiscAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7236 import (
        MeasurementComponentAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7237 import (
        MicrophoneAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7238 import (
        MicrophoneArrayAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7239 import (
        MountableComponentAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7240 import (
        OilSealAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7241 import (
        PartAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7242 import (
        PartToPartShearCouplingAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7243 import (
        PartToPartShearCouplingConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7244 import (
        PartToPartShearCouplingHalfAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7245 import (
        PlanetaryConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7246 import (
        PlanetaryGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7247 import (
        PlanetCarrierAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7248 import (
        PointLoadAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7249 import (
        PowerLoadAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7250 import (
        PulleyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7251 import (
        RingPinsAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7252 import (
        RingPinsToDiscConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7253 import (
        RollingRingAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7254 import (
        RollingRingAssemblyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7255 import (
        RollingRingConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7256 import (
        RootAssemblyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7257 import (
        ShaftAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7258 import (
        ShaftHubConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7259 import (
        ShaftToMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7260 import (
        SpecialisedAssemblyAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7261 import (
        SpiralBevelGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7262 import (
        SpiralBevelGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7263 import (
        SpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7264 import (
        SpringDamperAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7265 import (
        SpringDamperConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7266 import (
        SpringDamperHalfAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7267 import (
        StraightBevelDiffGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7268 import (
        StraightBevelDiffGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7269 import (
        StraightBevelDiffGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7270 import (
        StraightBevelGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7271 import (
        StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7272 import (
        StraightBevelGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7273 import (
        StraightBevelPlanetGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7274 import (
        StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7275 import (
        SynchroniserAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7276 import (
        SynchroniserHalfAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7277 import (
        SynchroniserPartAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7278 import (
        SynchroniserSleeveAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7279 import (
        TorqueConverterAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7280 import (
        TorqueConverterConnectionAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7281 import (
        TorqueConverterPumpAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7282 import (
        TorqueConverterTurbineAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7283 import (
        UnbalancedMassAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7284 import (
        VirtualComponentAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7285 import (
        WormGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7286 import (
        WormGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7287 import (
        WormGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7288 import (
        ZerolBevelGearAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7289 import (
        ZerolBevelGearMeshAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7290 import (
        ZerolBevelGearSetAdvancedTimeSteppingAnalysisForModulation,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7154": [
            "AbstractAssemblyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7155": [
            "AbstractShaftAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7156": [
            "AbstractShaftOrHousingAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7157": [
            "AbstractShaftToMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7158": [
            "AdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7159": [
            "AtsamExcitationsOrOthers"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7160": [
            "AtsamNaturalFrequencyViewOption"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7161": [
            "AdvancedTimeSteppingAnalysisForModulationOptions"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7162": [
            "AGMAGleasonConicalGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7163": [
            "AGMAGleasonConicalGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7164": [
            "AGMAGleasonConicalGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7165": [
            "AssemblyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7166": [
            "ATSAMResultsVsLargeTimeStepSettings"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7167": [
            "BearingAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7168": [
            "BeltConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7169": [
            "BeltDriveAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7170": [
            "BevelDifferentialGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7171": [
            "BevelDifferentialGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7172": [
            "BevelDifferentialGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7173": [
            "BevelDifferentialPlanetGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7174": [
            "BevelDifferentialSunGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7175": [
            "BevelGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7176": [
            "BevelGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7177": [
            "BevelGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7178": [
            "BoltAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7179": [
            "BoltedJointAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7180": [
            "ClutchAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7181": [
            "ClutchConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7182": [
            "ClutchHalfAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7183": [
            "CoaxialConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7184": [
            "ComponentAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7185": [
            "ConceptCouplingAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7186": [
            "ConceptCouplingConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7187": [
            "ConceptCouplingHalfAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7188": [
            "ConceptGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7189": [
            "ConceptGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7190": [
            "ConceptGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7191": [
            "ConicalGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7192": [
            "ConicalGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7193": [
            "ConicalGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7194": [
            "ConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7195": [
            "ConnectorAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7196": [
            "CouplingAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7197": [
            "CouplingConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7198": [
            "CouplingHalfAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7199": [
            "CVTAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7200": [
            "CVTBeltConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7201": [
            "CVTPulleyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7202": [
            "CycloidalAssemblyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7203": [
            "CycloidalDiscAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7204": [
            "CycloidalDiscCentralBearingConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7205": [
            "CycloidalDiscPlanetaryBearingConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7206": [
            "CylindricalGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7207": [
            "CylindricalGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7208": [
            "CylindricalGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7209": [
            "CylindricalPlanetGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7210": [
            "DatumAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7211": [
            "ExternalCADModelAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7212": [
            "FaceGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7213": [
            "FaceGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7214": [
            "FaceGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7215": [
            "FEPartAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7216": [
            "FlexiblePinAssemblyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7217": [
            "GearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7218": [
            "GearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7219": [
            "GearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7220": [
            "GuideDxfModelAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7221": [
            "HarmonicAnalysisOptionsForAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7222": [
            "HypoidGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7223": [
            "HypoidGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7224": [
            "HypoidGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7225": [
            "InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7226": [
            "KlingelnbergCycloPalloidConicalGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7227": [
            "KlingelnbergCycloPalloidConicalGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7228": [
            "KlingelnbergCycloPalloidConicalGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7229": [
            "KlingelnbergCycloPalloidHypoidGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7230": [
            "KlingelnbergCycloPalloidHypoidGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7231": [
            "KlingelnbergCycloPalloidHypoidGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7232": [
            "KlingelnbergCycloPalloidSpiralBevelGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7233": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7234": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7235": [
            "MassDiscAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7236": [
            "MeasurementComponentAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7237": [
            "MicrophoneAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7238": [
            "MicrophoneArrayAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7239": [
            "MountableComponentAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7240": [
            "OilSealAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7241": [
            "PartAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7242": [
            "PartToPartShearCouplingAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7243": [
            "PartToPartShearCouplingConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7244": [
            "PartToPartShearCouplingHalfAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7245": [
            "PlanetaryConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7246": [
            "PlanetaryGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7247": [
            "PlanetCarrierAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7248": [
            "PointLoadAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7249": [
            "PowerLoadAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7250": [
            "PulleyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7251": [
            "RingPinsAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7252": [
            "RingPinsToDiscConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7253": [
            "RollingRingAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7254": [
            "RollingRingAssemblyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7255": [
            "RollingRingConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7256": [
            "RootAssemblyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7257": [
            "ShaftAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7258": [
            "ShaftHubConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7259": [
            "ShaftToMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7260": [
            "SpecialisedAssemblyAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7261": [
            "SpiralBevelGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7262": [
            "SpiralBevelGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7263": [
            "SpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7264": [
            "SpringDamperAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7265": [
            "SpringDamperConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7266": [
            "SpringDamperHalfAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7267": [
            "StraightBevelDiffGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7268": [
            "StraightBevelDiffGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7269": [
            "StraightBevelDiffGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7270": [
            "StraightBevelGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7271": [
            "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7272": [
            "StraightBevelGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7273": [
            "StraightBevelPlanetGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7274": [
            "StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7275": [
            "SynchroniserAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7276": [
            "SynchroniserHalfAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7277": [
            "SynchroniserPartAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7278": [
            "SynchroniserSleeveAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7279": [
            "TorqueConverterAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7280": [
            "TorqueConverterConnectionAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7281": [
            "TorqueConverterPumpAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7282": [
            "TorqueConverterTurbineAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7283": [
            "UnbalancedMassAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7284": [
            "VirtualComponentAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7285": [
            "WormGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7286": [
            "WormGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7287": [
            "WormGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7288": [
            "ZerolBevelGearAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7289": [
            "ZerolBevelGearMeshAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation._7290": [
            "ZerolBevelGearSetAdvancedTimeSteppingAnalysisForModulation"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyAdvancedTimeSteppingAnalysisForModulation",
    "AbstractShaftAdvancedTimeSteppingAnalysisForModulation",
    "AbstractShaftOrHousingAdvancedTimeSteppingAnalysisForModulation",
    "AbstractShaftToMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation",
    "AdvancedTimeSteppingAnalysisForModulation",
    "AtsamExcitationsOrOthers",
    "AtsamNaturalFrequencyViewOption",
    "AdvancedTimeSteppingAnalysisForModulationOptions",
    "AGMAGleasonConicalGearAdvancedTimeSteppingAnalysisForModulation",
    "AGMAGleasonConicalGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "AGMAGleasonConicalGearSetAdvancedTimeSteppingAnalysisForModulation",
    "AssemblyAdvancedTimeSteppingAnalysisForModulation",
    "ATSAMResultsVsLargeTimeStepSettings",
    "BearingAdvancedTimeSteppingAnalysisForModulation",
    "BeltConnectionAdvancedTimeSteppingAnalysisForModulation",
    "BeltDriveAdvancedTimeSteppingAnalysisForModulation",
    "BevelDifferentialGearAdvancedTimeSteppingAnalysisForModulation",
    "BevelDifferentialGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "BevelDifferentialGearSetAdvancedTimeSteppingAnalysisForModulation",
    "BevelDifferentialPlanetGearAdvancedTimeSteppingAnalysisForModulation",
    "BevelDifferentialSunGearAdvancedTimeSteppingAnalysisForModulation",
    "BevelGearAdvancedTimeSteppingAnalysisForModulation",
    "BevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "BevelGearSetAdvancedTimeSteppingAnalysisForModulation",
    "BoltAdvancedTimeSteppingAnalysisForModulation",
    "BoltedJointAdvancedTimeSteppingAnalysisForModulation",
    "ClutchAdvancedTimeSteppingAnalysisForModulation",
    "ClutchConnectionAdvancedTimeSteppingAnalysisForModulation",
    "ClutchHalfAdvancedTimeSteppingAnalysisForModulation",
    "CoaxialConnectionAdvancedTimeSteppingAnalysisForModulation",
    "ComponentAdvancedTimeSteppingAnalysisForModulation",
    "ConceptCouplingAdvancedTimeSteppingAnalysisForModulation",
    "ConceptCouplingConnectionAdvancedTimeSteppingAnalysisForModulation",
    "ConceptCouplingHalfAdvancedTimeSteppingAnalysisForModulation",
    "ConceptGearAdvancedTimeSteppingAnalysisForModulation",
    "ConceptGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "ConceptGearSetAdvancedTimeSteppingAnalysisForModulation",
    "ConicalGearAdvancedTimeSteppingAnalysisForModulation",
    "ConicalGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "ConicalGearSetAdvancedTimeSteppingAnalysisForModulation",
    "ConnectionAdvancedTimeSteppingAnalysisForModulation",
    "ConnectorAdvancedTimeSteppingAnalysisForModulation",
    "CouplingAdvancedTimeSteppingAnalysisForModulation",
    "CouplingConnectionAdvancedTimeSteppingAnalysisForModulation",
    "CouplingHalfAdvancedTimeSteppingAnalysisForModulation",
    "CVTAdvancedTimeSteppingAnalysisForModulation",
    "CVTBeltConnectionAdvancedTimeSteppingAnalysisForModulation",
    "CVTPulleyAdvancedTimeSteppingAnalysisForModulation",
    "CycloidalAssemblyAdvancedTimeSteppingAnalysisForModulation",
    "CycloidalDiscAdvancedTimeSteppingAnalysisForModulation",
    "CycloidalDiscCentralBearingConnectionAdvancedTimeSteppingAnalysisForModulation",
    "CycloidalDiscPlanetaryBearingConnectionAdvancedTimeSteppingAnalysisForModulation",
    "CylindricalGearAdvancedTimeSteppingAnalysisForModulation",
    "CylindricalGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "CylindricalGearSetAdvancedTimeSteppingAnalysisForModulation",
    "CylindricalPlanetGearAdvancedTimeSteppingAnalysisForModulation",
    "DatumAdvancedTimeSteppingAnalysisForModulation",
    "ExternalCADModelAdvancedTimeSteppingAnalysisForModulation",
    "FaceGearAdvancedTimeSteppingAnalysisForModulation",
    "FaceGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "FaceGearSetAdvancedTimeSteppingAnalysisForModulation",
    "FEPartAdvancedTimeSteppingAnalysisForModulation",
    "FlexiblePinAssemblyAdvancedTimeSteppingAnalysisForModulation",
    "GearAdvancedTimeSteppingAnalysisForModulation",
    "GearMeshAdvancedTimeSteppingAnalysisForModulation",
    "GearSetAdvancedTimeSteppingAnalysisForModulation",
    "GuideDxfModelAdvancedTimeSteppingAnalysisForModulation",
    "HarmonicAnalysisOptionsForAdvancedTimeSteppingAnalysisForModulation",
    "HypoidGearAdvancedTimeSteppingAnalysisForModulation",
    "HypoidGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "HypoidGearSetAdvancedTimeSteppingAnalysisForModulation",
    "InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidConicalGearAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidConicalGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidConicalGearSetAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidHypoidGearAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidHypoidGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidHypoidGearSetAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidSpiralBevelGearAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation",
    "MassDiscAdvancedTimeSteppingAnalysisForModulation",
    "MeasurementComponentAdvancedTimeSteppingAnalysisForModulation",
    "MicrophoneAdvancedTimeSteppingAnalysisForModulation",
    "MicrophoneArrayAdvancedTimeSteppingAnalysisForModulation",
    "MountableComponentAdvancedTimeSteppingAnalysisForModulation",
    "OilSealAdvancedTimeSteppingAnalysisForModulation",
    "PartAdvancedTimeSteppingAnalysisForModulation",
    "PartToPartShearCouplingAdvancedTimeSteppingAnalysisForModulation",
    "PartToPartShearCouplingConnectionAdvancedTimeSteppingAnalysisForModulation",
    "PartToPartShearCouplingHalfAdvancedTimeSteppingAnalysisForModulation",
    "PlanetaryConnectionAdvancedTimeSteppingAnalysisForModulation",
    "PlanetaryGearSetAdvancedTimeSteppingAnalysisForModulation",
    "PlanetCarrierAdvancedTimeSteppingAnalysisForModulation",
    "PointLoadAdvancedTimeSteppingAnalysisForModulation",
    "PowerLoadAdvancedTimeSteppingAnalysisForModulation",
    "PulleyAdvancedTimeSteppingAnalysisForModulation",
    "RingPinsAdvancedTimeSteppingAnalysisForModulation",
    "RingPinsToDiscConnectionAdvancedTimeSteppingAnalysisForModulation",
    "RollingRingAdvancedTimeSteppingAnalysisForModulation",
    "RollingRingAssemblyAdvancedTimeSteppingAnalysisForModulation",
    "RollingRingConnectionAdvancedTimeSteppingAnalysisForModulation",
    "RootAssemblyAdvancedTimeSteppingAnalysisForModulation",
    "ShaftAdvancedTimeSteppingAnalysisForModulation",
    "ShaftHubConnectionAdvancedTimeSteppingAnalysisForModulation",
    "ShaftToMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation",
    "SpecialisedAssemblyAdvancedTimeSteppingAnalysisForModulation",
    "SpiralBevelGearAdvancedTimeSteppingAnalysisForModulation",
    "SpiralBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "SpiralBevelGearSetAdvancedTimeSteppingAnalysisForModulation",
    "SpringDamperAdvancedTimeSteppingAnalysisForModulation",
    "SpringDamperConnectionAdvancedTimeSteppingAnalysisForModulation",
    "SpringDamperHalfAdvancedTimeSteppingAnalysisForModulation",
    "StraightBevelDiffGearAdvancedTimeSteppingAnalysisForModulation",
    "StraightBevelDiffGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "StraightBevelDiffGearSetAdvancedTimeSteppingAnalysisForModulation",
    "StraightBevelGearAdvancedTimeSteppingAnalysisForModulation",
    "StraightBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "StraightBevelGearSetAdvancedTimeSteppingAnalysisForModulation",
    "StraightBevelPlanetGearAdvancedTimeSteppingAnalysisForModulation",
    "StraightBevelSunGearAdvancedTimeSteppingAnalysisForModulation",
    "SynchroniserAdvancedTimeSteppingAnalysisForModulation",
    "SynchroniserHalfAdvancedTimeSteppingAnalysisForModulation",
    "SynchroniserPartAdvancedTimeSteppingAnalysisForModulation",
    "SynchroniserSleeveAdvancedTimeSteppingAnalysisForModulation",
    "TorqueConverterAdvancedTimeSteppingAnalysisForModulation",
    "TorqueConverterConnectionAdvancedTimeSteppingAnalysisForModulation",
    "TorqueConverterPumpAdvancedTimeSteppingAnalysisForModulation",
    "TorqueConverterTurbineAdvancedTimeSteppingAnalysisForModulation",
    "UnbalancedMassAdvancedTimeSteppingAnalysisForModulation",
    "VirtualComponentAdvancedTimeSteppingAnalysisForModulation",
    "WormGearAdvancedTimeSteppingAnalysisForModulation",
    "WormGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "WormGearSetAdvancedTimeSteppingAnalysisForModulation",
    "ZerolBevelGearAdvancedTimeSteppingAnalysisForModulation",
    "ZerolBevelGearMeshAdvancedTimeSteppingAnalysisForModulation",
    "ZerolBevelGearSetAdvancedTimeSteppingAnalysisForModulation",
)
