"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6011 import (
        AbstractAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6012 import (
        AbstractShaftCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6013 import (
        AbstractShaftOrHousingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6014 import (
        AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6015 import (
        AGMAGleasonConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6016 import (
        AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6017 import (
        AGMAGleasonConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6018 import (
        AssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6019 import (
        BearingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6020 import (
        BeltConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6021 import (
        BeltDriveCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6022 import (
        BevelDifferentialGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6023 import (
        BevelDifferentialGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6024 import (
        BevelDifferentialGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6025 import (
        BevelDifferentialPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6026 import (
        BevelDifferentialSunGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6027 import (
        BevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6028 import (
        BevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6029 import (
        BevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6030 import (
        BoltCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6031 import (
        BoltedJointCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6032 import (
        ClutchCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6033 import (
        ClutchConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6034 import (
        ClutchHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6035 import (
        CoaxialConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6036 import (
        ComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6037 import (
        ConceptCouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6038 import (
        ConceptCouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6039 import (
        ConceptCouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6040 import (
        ConceptGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6041 import (
        ConceptGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6042 import (
        ConceptGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6043 import (
        ConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6044 import (
        ConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6045 import (
        ConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6046 import (
        ConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6047 import (
        ConnectorCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6048 import (
        CouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6049 import (
        CouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6050 import (
        CouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6051 import (
        CVTBeltConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6052 import (
        CVTCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6053 import (
        CVTPulleyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6054 import (
        CycloidalAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6055 import (
        CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6056 import (
        CycloidalDiscCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6057 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6058 import (
        CylindricalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6059 import (
        CylindricalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6060 import (
        CylindricalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6061 import (
        CylindricalPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6062 import (
        DatumCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6063 import (
        ExternalCADModelCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6064 import (
        FaceGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6065 import (
        FaceGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6066 import (
        FaceGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6067 import (
        FEPartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6068 import (
        FlexiblePinAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6069 import (
        GearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6070 import (
        GearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6071 import (
        GearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6072 import (
        GuideDxfModelCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6073 import (
        HypoidGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6074 import (
        HypoidGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6075 import (
        HypoidGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6076 import (
        InterMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6077 import (
        KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6078 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6079 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6080 import (
        KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6081 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6082 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6083 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6084 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6085 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6086 import (
        MassDiscCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6087 import (
        MeasurementComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6088 import (
        MicrophoneArrayCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6089 import (
        MicrophoneCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6090 import (
        MountableComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6091 import (
        OilSealCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6092 import (
        PartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6093 import (
        PartToPartShearCouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6094 import (
        PartToPartShearCouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6095 import (
        PartToPartShearCouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6096 import (
        PlanetaryConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6097 import (
        PlanetaryGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6098 import (
        PlanetCarrierCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6099 import (
        PointLoadCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6100 import (
        PowerLoadCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6101 import (
        PulleyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6102 import (
        RingPinsCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6103 import (
        RingPinsToDiscConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6104 import (
        RollingRingAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6105 import (
        RollingRingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6106 import (
        RollingRingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6107 import (
        RootAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6108 import (
        ShaftCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6109 import (
        ShaftHubConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6110 import (
        ShaftToMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6111 import (
        SpecialisedAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6112 import (
        SpiralBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6113 import (
        SpiralBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6114 import (
        SpiralBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6115 import (
        SpringDamperCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6116 import (
        SpringDamperConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6117 import (
        SpringDamperHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6118 import (
        StraightBevelDiffGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6119 import (
        StraightBevelDiffGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6120 import (
        StraightBevelDiffGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6121 import (
        StraightBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6122 import (
        StraightBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6123 import (
        StraightBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6124 import (
        StraightBevelPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6125 import (
        StraightBevelSunGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6126 import (
        SynchroniserCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6127 import (
        SynchroniserHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6128 import (
        SynchroniserPartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6129 import (
        SynchroniserSleeveCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6130 import (
        TorqueConverterCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6131 import (
        TorqueConverterConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6132 import (
        TorqueConverterPumpCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6133 import (
        TorqueConverterTurbineCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6134 import (
        UnbalancedMassCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6135 import (
        VirtualComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6136 import (
        WormGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6137 import (
        WormGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6138 import (
        WormGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6139 import (
        ZerolBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6140 import (
        ZerolBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6141 import (
        ZerolBevelGearSetCompoundHarmonicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6011": [
            "AbstractAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6012": [
            "AbstractShaftCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6013": [
            "AbstractShaftOrHousingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6014": [
            "AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6015": [
            "AGMAGleasonConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6016": [
            "AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6017": [
            "AGMAGleasonConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6018": [
            "AssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6019": [
            "BearingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6020": [
            "BeltConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6021": [
            "BeltDriveCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6022": [
            "BevelDifferentialGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6023": [
            "BevelDifferentialGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6024": [
            "BevelDifferentialGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6025": [
            "BevelDifferentialPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6026": [
            "BevelDifferentialSunGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6027": [
            "BevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6028": [
            "BevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6029": [
            "BevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6030": [
            "BoltCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6031": [
            "BoltedJointCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6032": [
            "ClutchCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6033": [
            "ClutchConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6034": [
            "ClutchHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6035": [
            "CoaxialConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6036": [
            "ComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6037": [
            "ConceptCouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6038": [
            "ConceptCouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6039": [
            "ConceptCouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6040": [
            "ConceptGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6041": [
            "ConceptGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6042": [
            "ConceptGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6043": [
            "ConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6044": [
            "ConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6045": [
            "ConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6046": [
            "ConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6047": [
            "ConnectorCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6048": [
            "CouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6049": [
            "CouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6050": [
            "CouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6051": [
            "CVTBeltConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6052": [
            "CVTCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6053": [
            "CVTPulleyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6054": [
            "CycloidalAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6055": [
            "CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6056": [
            "CycloidalDiscCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6057": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6058": [
            "CylindricalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6059": [
            "CylindricalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6060": [
            "CylindricalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6061": [
            "CylindricalPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6062": [
            "DatumCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6063": [
            "ExternalCADModelCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6064": [
            "FaceGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6065": [
            "FaceGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6066": [
            "FaceGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6067": [
            "FEPartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6068": [
            "FlexiblePinAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6069": [
            "GearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6070": [
            "GearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6071": [
            "GearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6072": [
            "GuideDxfModelCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6073": [
            "HypoidGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6074": [
            "HypoidGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6075": [
            "HypoidGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6076": [
            "InterMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6077": [
            "KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6078": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6079": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6080": [
            "KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6081": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6082": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6083": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6084": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6085": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6086": [
            "MassDiscCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6087": [
            "MeasurementComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6088": [
            "MicrophoneArrayCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6089": [
            "MicrophoneCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6090": [
            "MountableComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6091": [
            "OilSealCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6092": [
            "PartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6093": [
            "PartToPartShearCouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6094": [
            "PartToPartShearCouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6095": [
            "PartToPartShearCouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6096": [
            "PlanetaryConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6097": [
            "PlanetaryGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6098": [
            "PlanetCarrierCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6099": [
            "PointLoadCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6100": [
            "PowerLoadCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6101": [
            "PulleyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6102": [
            "RingPinsCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6103": [
            "RingPinsToDiscConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6104": [
            "RollingRingAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6105": [
            "RollingRingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6106": [
            "RollingRingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6107": [
            "RootAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6108": [
            "ShaftCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6109": [
            "ShaftHubConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6110": [
            "ShaftToMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6111": [
            "SpecialisedAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6112": [
            "SpiralBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6113": [
            "SpiralBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6114": [
            "SpiralBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6115": [
            "SpringDamperCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6116": [
            "SpringDamperConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6117": [
            "SpringDamperHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6118": [
            "StraightBevelDiffGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6119": [
            "StraightBevelDiffGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6120": [
            "StraightBevelDiffGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6121": [
            "StraightBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6122": [
            "StraightBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6123": [
            "StraightBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6124": [
            "StraightBevelPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6125": [
            "StraightBevelSunGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6126": [
            "SynchroniserCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6127": [
            "SynchroniserHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6128": [
            "SynchroniserPartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6129": [
            "SynchroniserSleeveCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6130": [
            "TorqueConverterCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6131": [
            "TorqueConverterConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6132": [
            "TorqueConverterPumpCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6133": [
            "TorqueConverterTurbineCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6134": [
            "UnbalancedMassCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6135": [
            "VirtualComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6136": [
            "WormGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6137": [
            "WormGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6138": [
            "WormGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6139": [
            "ZerolBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6140": [
            "ZerolBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6141": [
            "ZerolBevelGearSetCompoundHarmonicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundHarmonicAnalysis",
    "AbstractShaftCompoundHarmonicAnalysis",
    "AbstractShaftOrHousingCompoundHarmonicAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearSetCompoundHarmonicAnalysis",
    "AssemblyCompoundHarmonicAnalysis",
    "BearingCompoundHarmonicAnalysis",
    "BeltConnectionCompoundHarmonicAnalysis",
    "BeltDriveCompoundHarmonicAnalysis",
    "BevelDifferentialGearCompoundHarmonicAnalysis",
    "BevelDifferentialGearMeshCompoundHarmonicAnalysis",
    "BevelDifferentialGearSetCompoundHarmonicAnalysis",
    "BevelDifferentialPlanetGearCompoundHarmonicAnalysis",
    "BevelDifferentialSunGearCompoundHarmonicAnalysis",
    "BevelGearCompoundHarmonicAnalysis",
    "BevelGearMeshCompoundHarmonicAnalysis",
    "BevelGearSetCompoundHarmonicAnalysis",
    "BoltCompoundHarmonicAnalysis",
    "BoltedJointCompoundHarmonicAnalysis",
    "ClutchCompoundHarmonicAnalysis",
    "ClutchConnectionCompoundHarmonicAnalysis",
    "ClutchHalfCompoundHarmonicAnalysis",
    "CoaxialConnectionCompoundHarmonicAnalysis",
    "ComponentCompoundHarmonicAnalysis",
    "ConceptCouplingCompoundHarmonicAnalysis",
    "ConceptCouplingConnectionCompoundHarmonicAnalysis",
    "ConceptCouplingHalfCompoundHarmonicAnalysis",
    "ConceptGearCompoundHarmonicAnalysis",
    "ConceptGearMeshCompoundHarmonicAnalysis",
    "ConceptGearSetCompoundHarmonicAnalysis",
    "ConicalGearCompoundHarmonicAnalysis",
    "ConicalGearMeshCompoundHarmonicAnalysis",
    "ConicalGearSetCompoundHarmonicAnalysis",
    "ConnectionCompoundHarmonicAnalysis",
    "ConnectorCompoundHarmonicAnalysis",
    "CouplingCompoundHarmonicAnalysis",
    "CouplingConnectionCompoundHarmonicAnalysis",
    "CouplingHalfCompoundHarmonicAnalysis",
    "CVTBeltConnectionCompoundHarmonicAnalysis",
    "CVTCompoundHarmonicAnalysis",
    "CVTPulleyCompoundHarmonicAnalysis",
    "CycloidalAssemblyCompoundHarmonicAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis",
    "CycloidalDiscCompoundHarmonicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis",
    "CylindricalGearCompoundHarmonicAnalysis",
    "CylindricalGearMeshCompoundHarmonicAnalysis",
    "CylindricalGearSetCompoundHarmonicAnalysis",
    "CylindricalPlanetGearCompoundHarmonicAnalysis",
    "DatumCompoundHarmonicAnalysis",
    "ExternalCADModelCompoundHarmonicAnalysis",
    "FaceGearCompoundHarmonicAnalysis",
    "FaceGearMeshCompoundHarmonicAnalysis",
    "FaceGearSetCompoundHarmonicAnalysis",
    "FEPartCompoundHarmonicAnalysis",
    "FlexiblePinAssemblyCompoundHarmonicAnalysis",
    "GearCompoundHarmonicAnalysis",
    "GearMeshCompoundHarmonicAnalysis",
    "GearSetCompoundHarmonicAnalysis",
    "GuideDxfModelCompoundHarmonicAnalysis",
    "HypoidGearCompoundHarmonicAnalysis",
    "HypoidGearMeshCompoundHarmonicAnalysis",
    "HypoidGearSetCompoundHarmonicAnalysis",
    "InterMountableComponentConnectionCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis",
    "MassDiscCompoundHarmonicAnalysis",
    "MeasurementComponentCompoundHarmonicAnalysis",
    "MicrophoneArrayCompoundHarmonicAnalysis",
    "MicrophoneCompoundHarmonicAnalysis",
    "MountableComponentCompoundHarmonicAnalysis",
    "OilSealCompoundHarmonicAnalysis",
    "PartCompoundHarmonicAnalysis",
    "PartToPartShearCouplingCompoundHarmonicAnalysis",
    "PartToPartShearCouplingConnectionCompoundHarmonicAnalysis",
    "PartToPartShearCouplingHalfCompoundHarmonicAnalysis",
    "PlanetaryConnectionCompoundHarmonicAnalysis",
    "PlanetaryGearSetCompoundHarmonicAnalysis",
    "PlanetCarrierCompoundHarmonicAnalysis",
    "PointLoadCompoundHarmonicAnalysis",
    "PowerLoadCompoundHarmonicAnalysis",
    "PulleyCompoundHarmonicAnalysis",
    "RingPinsCompoundHarmonicAnalysis",
    "RingPinsToDiscConnectionCompoundHarmonicAnalysis",
    "RollingRingAssemblyCompoundHarmonicAnalysis",
    "RollingRingCompoundHarmonicAnalysis",
    "RollingRingConnectionCompoundHarmonicAnalysis",
    "RootAssemblyCompoundHarmonicAnalysis",
    "ShaftCompoundHarmonicAnalysis",
    "ShaftHubConnectionCompoundHarmonicAnalysis",
    "ShaftToMountableComponentConnectionCompoundHarmonicAnalysis",
    "SpecialisedAssemblyCompoundHarmonicAnalysis",
    "SpiralBevelGearCompoundHarmonicAnalysis",
    "SpiralBevelGearMeshCompoundHarmonicAnalysis",
    "SpiralBevelGearSetCompoundHarmonicAnalysis",
    "SpringDamperCompoundHarmonicAnalysis",
    "SpringDamperConnectionCompoundHarmonicAnalysis",
    "SpringDamperHalfCompoundHarmonicAnalysis",
    "StraightBevelDiffGearCompoundHarmonicAnalysis",
    "StraightBevelDiffGearMeshCompoundHarmonicAnalysis",
    "StraightBevelDiffGearSetCompoundHarmonicAnalysis",
    "StraightBevelGearCompoundHarmonicAnalysis",
    "StraightBevelGearMeshCompoundHarmonicAnalysis",
    "StraightBevelGearSetCompoundHarmonicAnalysis",
    "StraightBevelPlanetGearCompoundHarmonicAnalysis",
    "StraightBevelSunGearCompoundHarmonicAnalysis",
    "SynchroniserCompoundHarmonicAnalysis",
    "SynchroniserHalfCompoundHarmonicAnalysis",
    "SynchroniserPartCompoundHarmonicAnalysis",
    "SynchroniserSleeveCompoundHarmonicAnalysis",
    "TorqueConverterCompoundHarmonicAnalysis",
    "TorqueConverterConnectionCompoundHarmonicAnalysis",
    "TorqueConverterPumpCompoundHarmonicAnalysis",
    "TorqueConverterTurbineCompoundHarmonicAnalysis",
    "UnbalancedMassCompoundHarmonicAnalysis",
    "VirtualComponentCompoundHarmonicAnalysis",
    "WormGearCompoundHarmonicAnalysis",
    "WormGearMeshCompoundHarmonicAnalysis",
    "WormGearSetCompoundHarmonicAnalysis",
    "ZerolBevelGearCompoundHarmonicAnalysis",
    "ZerolBevelGearMeshCompoundHarmonicAnalysis",
    "ZerolBevelGearSetCompoundHarmonicAnalysis",
)
