"""ShaftOrderForTE"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.utility.modal_analysis.gears import _1852
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_SHAFT_ORDER_FOR_TE = python_net_import(
    "SMT.MastaAPI.Utility.ModalAnalysis.Gears", "ShaftOrderForTE"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ShaftOrderForTE")
    CastSelf = TypeVar("CastSelf", bound="ShaftOrderForTE._Cast_ShaftOrderForTE")


__docformat__ = "restructuredtext en"
__all__ = ("ShaftOrderForTE",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ShaftOrderForTE:
    """Special nested class for casting ShaftOrderForTE to subclasses."""

    __parent__: "ShaftOrderForTE"

    @property
    def order_for_te(self: "CastSelf") -> "_1852.OrderForTE":
        return self.__parent__._cast(_1852.OrderForTE)

    @property
    def shaft_order_for_te(self: "CastSelf") -> "ShaftOrderForTE":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ShaftOrderForTE(_1852.OrderForTE):
    """ShaftOrderForTE

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SHAFT_ORDER_FOR_TE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_ShaftOrderForTE":
        """Cast to another type.

        Returns:
            _Cast_ShaftOrderForTE
        """
        return _Cast_ShaftOrderForTE(self)
