"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.scripting._7727 import ApiEnumForAttribute
    from mastapy._private.scripting._7728 import ApiVersion
    from mastapy._private.scripting._7729 import SMTBitmap
    from mastapy._private.scripting._7731 import MastaPropertyAttribute
    from mastapy._private.scripting._7732 import PythonCommand
    from mastapy._private.scripting._7733 import ScriptingCommand
    from mastapy._private.scripting._7734 import ScriptingExecutionCommand
    from mastapy._private.scripting._7735 import ScriptingObjectCommand
    from mastapy._private.scripting._7736 import ApiVersioning
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.scripting._7727": ["ApiEnumForAttribute"],
        "_private.scripting._7728": ["ApiVersion"],
        "_private.scripting._7729": ["SMTBitmap"],
        "_private.scripting._7731": ["MastaPropertyAttribute"],
        "_private.scripting._7732": ["PythonCommand"],
        "_private.scripting._7733": ["ScriptingCommand"],
        "_private.scripting._7734": ["ScriptingExecutionCommand"],
        "_private.scripting._7735": ["ScriptingObjectCommand"],
        "_private.scripting._7736": ["ApiVersioning"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "ApiEnumForAttribute",
    "ApiVersion",
    "SMTBitmap",
    "MastaPropertyAttribute",
    "PythonCommand",
    "ScriptingCommand",
    "ScriptingExecutionCommand",
    "ScriptingObjectCommand",
    "ApiVersioning",
)
