"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3862 import (
        AbstractAssemblyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3863 import (
        AbstractShaftOrHousingStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3864 import (
        AbstractShaftStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3865 import (
        AbstractShaftToMountableComponentConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3866 import (
        AGMAGleasonConicalGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3867 import (
        AGMAGleasonConicalGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3868 import (
        AGMAGleasonConicalGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3869 import (
        AssemblyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3870 import (
        BearingStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3871 import (
        BeltConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3872 import (
        BeltDriveStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3873 import (
        BevelDifferentialGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3874 import (
        BevelDifferentialGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3875 import (
        BevelDifferentialGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3876 import (
        BevelDifferentialPlanetGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3877 import (
        BevelDifferentialSunGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3878 import (
        BevelGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3879 import (
        BevelGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3880 import (
        BevelGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3881 import (
        BoltedJointStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3882 import (
        BoltStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3883 import (
        ClutchConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3884 import (
        ClutchHalfStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3885 import (
        ClutchStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3886 import (
        CoaxialConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3887 import (
        ComponentStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3888 import (
        ConceptCouplingConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3889 import (
        ConceptCouplingHalfStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3890 import (
        ConceptCouplingStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3891 import (
        ConceptGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3892 import (
        ConceptGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3893 import (
        ConceptGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3894 import (
        ConicalGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3895 import (
        ConicalGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3896 import (
        ConicalGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3897 import (
        ConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3898 import (
        ConnectorStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3899 import (
        CouplingConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3900 import (
        CouplingHalfStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3901 import (
        CouplingStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3902 import (
        CriticalSpeed,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3903 import (
        CVTBeltConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3904 import (
        CVTPulleyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3905 import (
        CVTStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3906 import (
        CycloidalAssemblyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3907 import (
        CycloidalDiscCentralBearingConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3908 import (
        CycloidalDiscPlanetaryBearingConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3909 import (
        CycloidalDiscStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3910 import (
        CylindricalGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3911 import (
        CylindricalGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3912 import (
        CylindricalGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3913 import (
        CylindricalPlanetGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3914 import (
        DatumStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3915 import (
        DynamicModelForStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3916 import (
        ExternalCADModelStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3917 import (
        FaceGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3918 import (
        FaceGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3919 import (
        FaceGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3920 import (
        FEPartStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3921 import (
        FlexiblePinAssemblyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3922 import (
        GearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3923 import (
        GearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3924 import (
        GearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3925 import (
        GuideDxfModelStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3926 import (
        HypoidGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3927 import (
        HypoidGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3928 import (
        HypoidGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3929 import (
        InterMountableComponentConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3930 import (
        KlingelnbergCycloPalloidConicalGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3931 import (
        KlingelnbergCycloPalloidConicalGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3932 import (
        KlingelnbergCycloPalloidConicalGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3933 import (
        KlingelnbergCycloPalloidHypoidGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3934 import (
        KlingelnbergCycloPalloidHypoidGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3935 import (
        KlingelnbergCycloPalloidHypoidGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3936 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3937 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3938 import (
        KlingelnbergCycloPalloidSpiralBevelGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3939 import (
        MassDiscStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3940 import (
        MeasurementComponentStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3941 import (
        MicrophoneArrayStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3942 import (
        MicrophoneStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3943 import (
        MountableComponentStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3944 import (
        OilSealStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3945 import (
        PartStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3946 import (
        PartToPartShearCouplingConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3947 import (
        PartToPartShearCouplingHalfStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3948 import (
        PartToPartShearCouplingStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3949 import (
        PlanetaryConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3950 import (
        PlanetaryGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3951 import (
        PlanetCarrierStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3952 import (
        PointLoadStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3953 import (
        PowerLoadStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3954 import (
        PulleyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3955 import (
        RingPinsStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3956 import (
        RingPinsToDiscConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3957 import (
        RollingRingAssemblyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3958 import (
        RollingRingConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3959 import (
        RollingRingStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3960 import (
        RootAssemblyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3961 import (
        ShaftHubConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3962 import (
        ShaftStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3963 import (
        ShaftToMountableComponentConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3964 import (
        SpecialisedAssemblyStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3965 import (
        SpiralBevelGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3966 import (
        SpiralBevelGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3967 import (
        SpiralBevelGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3968 import (
        SpringDamperConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3969 import (
        SpringDamperHalfStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3970 import (
        SpringDamperStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3971 import (
        StabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3972 import (
        StabilityAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3973 import (
        StabilityAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3974 import (
        StraightBevelDiffGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3975 import (
        StraightBevelDiffGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3976 import (
        StraightBevelDiffGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3977 import (
        StraightBevelGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3978 import (
        StraightBevelGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3979 import (
        StraightBevelGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3980 import (
        StraightBevelPlanetGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3981 import (
        StraightBevelSunGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3982 import (
        SynchroniserHalfStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3983 import (
        SynchroniserPartStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3984 import (
        SynchroniserSleeveStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3985 import (
        SynchroniserStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3986 import (
        TorqueConverterConnectionStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3987 import (
        TorqueConverterPumpStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3988 import (
        TorqueConverterStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3989 import (
        TorqueConverterTurbineStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3990 import (
        UnbalancedMassStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3991 import (
        VirtualComponentStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3992 import (
        WormGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3993 import (
        WormGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3994 import (
        WormGearStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3995 import (
        ZerolBevelGearMeshStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3996 import (
        ZerolBevelGearSetStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses._3997 import (
        ZerolBevelGearStabilityAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.stability_analyses._3862": [
            "AbstractAssemblyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3863": [
            "AbstractShaftOrHousingStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3864": [
            "AbstractShaftStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3865": [
            "AbstractShaftToMountableComponentConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3866": [
            "AGMAGleasonConicalGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3867": [
            "AGMAGleasonConicalGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3868": [
            "AGMAGleasonConicalGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3869": [
            "AssemblyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3870": [
            "BearingStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3871": [
            "BeltConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3872": [
            "BeltDriveStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3873": [
            "BevelDifferentialGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3874": [
            "BevelDifferentialGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3875": [
            "BevelDifferentialGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3876": [
            "BevelDifferentialPlanetGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3877": [
            "BevelDifferentialSunGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3878": [
            "BevelGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3879": [
            "BevelGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3880": [
            "BevelGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3881": [
            "BoltedJointStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3882": [
            "BoltStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3883": [
            "ClutchConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3884": [
            "ClutchHalfStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3885": [
            "ClutchStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3886": [
            "CoaxialConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3887": [
            "ComponentStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3888": [
            "ConceptCouplingConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3889": [
            "ConceptCouplingHalfStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3890": [
            "ConceptCouplingStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3891": [
            "ConceptGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3892": [
            "ConceptGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3893": [
            "ConceptGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3894": [
            "ConicalGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3895": [
            "ConicalGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3896": [
            "ConicalGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3897": [
            "ConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3898": [
            "ConnectorStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3899": [
            "CouplingConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3900": [
            "CouplingHalfStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3901": [
            "CouplingStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3902": [
            "CriticalSpeed"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3903": [
            "CVTBeltConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3904": [
            "CVTPulleyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3905": [
            "CVTStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3906": [
            "CycloidalAssemblyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3907": [
            "CycloidalDiscCentralBearingConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3908": [
            "CycloidalDiscPlanetaryBearingConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3909": [
            "CycloidalDiscStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3910": [
            "CylindricalGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3911": [
            "CylindricalGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3912": [
            "CylindricalGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3913": [
            "CylindricalPlanetGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3914": [
            "DatumStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3915": [
            "DynamicModelForStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3916": [
            "ExternalCADModelStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3917": [
            "FaceGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3918": [
            "FaceGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3919": [
            "FaceGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3920": [
            "FEPartStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3921": [
            "FlexiblePinAssemblyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3922": [
            "GearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3923": [
            "GearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3924": [
            "GearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3925": [
            "GuideDxfModelStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3926": [
            "HypoidGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3927": [
            "HypoidGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3928": [
            "HypoidGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3929": [
            "InterMountableComponentConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3930": [
            "KlingelnbergCycloPalloidConicalGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3931": [
            "KlingelnbergCycloPalloidConicalGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3932": [
            "KlingelnbergCycloPalloidConicalGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3933": [
            "KlingelnbergCycloPalloidHypoidGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3934": [
            "KlingelnbergCycloPalloidHypoidGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3935": [
            "KlingelnbergCycloPalloidHypoidGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3936": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3937": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3938": [
            "KlingelnbergCycloPalloidSpiralBevelGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3939": [
            "MassDiscStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3940": [
            "MeasurementComponentStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3941": [
            "MicrophoneArrayStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3942": [
            "MicrophoneStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3943": [
            "MountableComponentStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3944": [
            "OilSealStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3945": [
            "PartStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3946": [
            "PartToPartShearCouplingConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3947": [
            "PartToPartShearCouplingHalfStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3948": [
            "PartToPartShearCouplingStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3949": [
            "PlanetaryConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3950": [
            "PlanetaryGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3951": [
            "PlanetCarrierStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3952": [
            "PointLoadStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3953": [
            "PowerLoadStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3954": [
            "PulleyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3955": [
            "RingPinsStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3956": [
            "RingPinsToDiscConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3957": [
            "RollingRingAssemblyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3958": [
            "RollingRingConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3959": [
            "RollingRingStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3960": [
            "RootAssemblyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3961": [
            "ShaftHubConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3962": [
            "ShaftStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3963": [
            "ShaftToMountableComponentConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3964": [
            "SpecialisedAssemblyStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3965": [
            "SpiralBevelGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3966": [
            "SpiralBevelGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3967": [
            "SpiralBevelGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3968": [
            "SpringDamperConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3969": [
            "SpringDamperHalfStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3970": [
            "SpringDamperStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3971": [
            "StabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3972": [
            "StabilityAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3973": [
            "StabilityAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3974": [
            "StraightBevelDiffGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3975": [
            "StraightBevelDiffGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3976": [
            "StraightBevelDiffGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3977": [
            "StraightBevelGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3978": [
            "StraightBevelGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3979": [
            "StraightBevelGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3980": [
            "StraightBevelPlanetGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3981": [
            "StraightBevelSunGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3982": [
            "SynchroniserHalfStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3983": [
            "SynchroniserPartStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3984": [
            "SynchroniserSleeveStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3985": [
            "SynchroniserStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3986": [
            "TorqueConverterConnectionStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3987": [
            "TorqueConverterPumpStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3988": [
            "TorqueConverterStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3989": [
            "TorqueConverterTurbineStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3990": [
            "UnbalancedMassStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3991": [
            "VirtualComponentStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3992": [
            "WormGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3993": [
            "WormGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3994": [
            "WormGearStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3995": [
            "ZerolBevelGearMeshStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3996": [
            "ZerolBevelGearSetStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses._3997": [
            "ZerolBevelGearStabilityAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyStabilityAnalysis",
    "AbstractShaftOrHousingStabilityAnalysis",
    "AbstractShaftStabilityAnalysis",
    "AbstractShaftToMountableComponentConnectionStabilityAnalysis",
    "AGMAGleasonConicalGearMeshStabilityAnalysis",
    "AGMAGleasonConicalGearSetStabilityAnalysis",
    "AGMAGleasonConicalGearStabilityAnalysis",
    "AssemblyStabilityAnalysis",
    "BearingStabilityAnalysis",
    "BeltConnectionStabilityAnalysis",
    "BeltDriveStabilityAnalysis",
    "BevelDifferentialGearMeshStabilityAnalysis",
    "BevelDifferentialGearSetStabilityAnalysis",
    "BevelDifferentialGearStabilityAnalysis",
    "BevelDifferentialPlanetGearStabilityAnalysis",
    "BevelDifferentialSunGearStabilityAnalysis",
    "BevelGearMeshStabilityAnalysis",
    "BevelGearSetStabilityAnalysis",
    "BevelGearStabilityAnalysis",
    "BoltedJointStabilityAnalysis",
    "BoltStabilityAnalysis",
    "ClutchConnectionStabilityAnalysis",
    "ClutchHalfStabilityAnalysis",
    "ClutchStabilityAnalysis",
    "CoaxialConnectionStabilityAnalysis",
    "ComponentStabilityAnalysis",
    "ConceptCouplingConnectionStabilityAnalysis",
    "ConceptCouplingHalfStabilityAnalysis",
    "ConceptCouplingStabilityAnalysis",
    "ConceptGearMeshStabilityAnalysis",
    "ConceptGearSetStabilityAnalysis",
    "ConceptGearStabilityAnalysis",
    "ConicalGearMeshStabilityAnalysis",
    "ConicalGearSetStabilityAnalysis",
    "ConicalGearStabilityAnalysis",
    "ConnectionStabilityAnalysis",
    "ConnectorStabilityAnalysis",
    "CouplingConnectionStabilityAnalysis",
    "CouplingHalfStabilityAnalysis",
    "CouplingStabilityAnalysis",
    "CriticalSpeed",
    "CVTBeltConnectionStabilityAnalysis",
    "CVTPulleyStabilityAnalysis",
    "CVTStabilityAnalysis",
    "CycloidalAssemblyStabilityAnalysis",
    "CycloidalDiscCentralBearingConnectionStabilityAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionStabilityAnalysis",
    "CycloidalDiscStabilityAnalysis",
    "CylindricalGearMeshStabilityAnalysis",
    "CylindricalGearSetStabilityAnalysis",
    "CylindricalGearStabilityAnalysis",
    "CylindricalPlanetGearStabilityAnalysis",
    "DatumStabilityAnalysis",
    "DynamicModelForStabilityAnalysis",
    "ExternalCADModelStabilityAnalysis",
    "FaceGearMeshStabilityAnalysis",
    "FaceGearSetStabilityAnalysis",
    "FaceGearStabilityAnalysis",
    "FEPartStabilityAnalysis",
    "FlexiblePinAssemblyStabilityAnalysis",
    "GearMeshStabilityAnalysis",
    "GearSetStabilityAnalysis",
    "GearStabilityAnalysis",
    "GuideDxfModelStabilityAnalysis",
    "HypoidGearMeshStabilityAnalysis",
    "HypoidGearSetStabilityAnalysis",
    "HypoidGearStabilityAnalysis",
    "InterMountableComponentConnectionStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearStabilityAnalysis",
    "MassDiscStabilityAnalysis",
    "MeasurementComponentStabilityAnalysis",
    "MicrophoneArrayStabilityAnalysis",
    "MicrophoneStabilityAnalysis",
    "MountableComponentStabilityAnalysis",
    "OilSealStabilityAnalysis",
    "PartStabilityAnalysis",
    "PartToPartShearCouplingConnectionStabilityAnalysis",
    "PartToPartShearCouplingHalfStabilityAnalysis",
    "PartToPartShearCouplingStabilityAnalysis",
    "PlanetaryConnectionStabilityAnalysis",
    "PlanetaryGearSetStabilityAnalysis",
    "PlanetCarrierStabilityAnalysis",
    "PointLoadStabilityAnalysis",
    "PowerLoadStabilityAnalysis",
    "PulleyStabilityAnalysis",
    "RingPinsStabilityAnalysis",
    "RingPinsToDiscConnectionStabilityAnalysis",
    "RollingRingAssemblyStabilityAnalysis",
    "RollingRingConnectionStabilityAnalysis",
    "RollingRingStabilityAnalysis",
    "RootAssemblyStabilityAnalysis",
    "ShaftHubConnectionStabilityAnalysis",
    "ShaftStabilityAnalysis",
    "ShaftToMountableComponentConnectionStabilityAnalysis",
    "SpecialisedAssemblyStabilityAnalysis",
    "SpiralBevelGearMeshStabilityAnalysis",
    "SpiralBevelGearSetStabilityAnalysis",
    "SpiralBevelGearStabilityAnalysis",
    "SpringDamperConnectionStabilityAnalysis",
    "SpringDamperHalfStabilityAnalysis",
    "SpringDamperStabilityAnalysis",
    "StabilityAnalysis",
    "StabilityAnalysisDrawStyle",
    "StabilityAnalysisOptions",
    "StraightBevelDiffGearMeshStabilityAnalysis",
    "StraightBevelDiffGearSetStabilityAnalysis",
    "StraightBevelDiffGearStabilityAnalysis",
    "StraightBevelGearMeshStabilityAnalysis",
    "StraightBevelGearSetStabilityAnalysis",
    "StraightBevelGearStabilityAnalysis",
    "StraightBevelPlanetGearStabilityAnalysis",
    "StraightBevelSunGearStabilityAnalysis",
    "SynchroniserHalfStabilityAnalysis",
    "SynchroniserPartStabilityAnalysis",
    "SynchroniserSleeveStabilityAnalysis",
    "SynchroniserStabilityAnalysis",
    "TorqueConverterConnectionStabilityAnalysis",
    "TorqueConverterPumpStabilityAnalysis",
    "TorqueConverterStabilityAnalysis",
    "TorqueConverterTurbineStabilityAnalysis",
    "UnbalancedMassStabilityAnalysis",
    "VirtualComponentStabilityAnalysis",
    "WormGearMeshStabilityAnalysis",
    "WormGearSetStabilityAnalysis",
    "WormGearStabilityAnalysis",
    "ZerolBevelGearMeshStabilityAnalysis",
    "ZerolBevelGearSetStabilityAnalysis",
    "ZerolBevelGearStabilityAnalysis",
)
