"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.materials._247 import (
        AbstractStressCyclesDataForAnSNCurveOfAPlasticMaterial,
    )
    from mastapy._private.materials._248 import AcousticRadiationEfficiency
    from mastapy._private.materials._249 import AcousticRadiationEfficiencyInputType
    from mastapy._private.materials._250 import AGMALubricantType
    from mastapy._private.materials._251 import AGMAMaterialApplications
    from mastapy._private.materials._252 import AGMAMaterialClasses
    from mastapy._private.materials._253 import AGMAMaterialGrade
    from mastapy._private.materials._254 import AirProperties
    from mastapy._private.materials._255 import BearingLubricationCondition
    from mastapy._private.materials._256 import BearingMaterial
    from mastapy._private.materials._257 import BearingMaterialDatabase
    from mastapy._private.materials._258 import BHCurveExtrapolationMethod
    from mastapy._private.materials._259 import BHCurveSpecification
    from mastapy._private.materials._260 import ComponentMaterialDatabase
    from mastapy._private.materials._261 import CompositeFatigueSafetyFactorItem
    from mastapy._private.materials._262 import CylindricalGearRatingMethods
    from mastapy._private.materials._263 import DensitySpecificationMethod
    from mastapy._private.materials._264 import FatigueSafetyFactorItem
    from mastapy._private.materials._265 import FatigueSafetyFactorItemBase
    from mastapy._private.materials._266 import GearingTypes
    from mastapy._private.materials._267 import GeneralTransmissionProperties
    from mastapy._private.materials._268 import GreaseContaminationOptions
    from mastapy._private.materials._269 import HardnessType
    from mastapy._private.materials._270 import ISO76StaticSafetyFactorLimits
    from mastapy._private.materials._271 import ISOLubricantType
    from mastapy._private.materials._272 import LubricantDefinition
    from mastapy._private.materials._273 import LubricantDelivery
    from mastapy._private.materials._274 import LubricantViscosityClassAGMA
    from mastapy._private.materials._275 import LubricantViscosityClassification
    from mastapy._private.materials._276 import LubricantViscosityClassISO
    from mastapy._private.materials._277 import LubricantViscosityClassSAE
    from mastapy._private.materials._278 import LubricationDetail
    from mastapy._private.materials._279 import LubricationDetailDatabase
    from mastapy._private.materials._280 import Material
    from mastapy._private.materials._281 import MaterialDatabase
    from mastapy._private.materials._282 import MaterialsSettings
    from mastapy._private.materials._283 import MaterialsSettingsDatabase
    from mastapy._private.materials._284 import MaterialsSettingsItem
    from mastapy._private.materials._285 import MaterialStandards
    from mastapy._private.materials._286 import MetalPlasticType
    from mastapy._private.materials._287 import OilFiltrationOptions
    from mastapy._private.materials._288 import PressureViscosityCoefficientMethod
    from mastapy._private.materials._289 import QualityGrade
    from mastapy._private.materials._290 import SafetyFactorGroup
    from mastapy._private.materials._291 import SafetyFactorItem
    from mastapy._private.materials._292 import SNCurve
    from mastapy._private.materials._293 import SNCurvePoint
    from mastapy._private.materials._294 import SoundPressureEnclosure
    from mastapy._private.materials._295 import SoundPressureEnclosureType
    from mastapy._private.materials._296 import (
        StressCyclesDataForTheBendingSNCurveOfAPlasticMaterial,
    )
    from mastapy._private.materials._297 import (
        StressCyclesDataForTheContactSNCurveOfAPlasticMaterial,
    )
    from mastapy._private.materials._298 import TransmissionApplications
    from mastapy._private.materials._299 import VDI2736LubricantType
    from mastapy._private.materials._300 import VehicleDynamicsProperties
    from mastapy._private.materials._301 import WindTurbineStandards
    from mastapy._private.materials._302 import WorkingCharacteristics
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.materials._247": [
            "AbstractStressCyclesDataForAnSNCurveOfAPlasticMaterial"
        ],
        "_private.materials._248": ["AcousticRadiationEfficiency"],
        "_private.materials._249": ["AcousticRadiationEfficiencyInputType"],
        "_private.materials._250": ["AGMALubricantType"],
        "_private.materials._251": ["AGMAMaterialApplications"],
        "_private.materials._252": ["AGMAMaterialClasses"],
        "_private.materials._253": ["AGMAMaterialGrade"],
        "_private.materials._254": ["AirProperties"],
        "_private.materials._255": ["BearingLubricationCondition"],
        "_private.materials._256": ["BearingMaterial"],
        "_private.materials._257": ["BearingMaterialDatabase"],
        "_private.materials._258": ["BHCurveExtrapolationMethod"],
        "_private.materials._259": ["BHCurveSpecification"],
        "_private.materials._260": ["ComponentMaterialDatabase"],
        "_private.materials._261": ["CompositeFatigueSafetyFactorItem"],
        "_private.materials._262": ["CylindricalGearRatingMethods"],
        "_private.materials._263": ["DensitySpecificationMethod"],
        "_private.materials._264": ["FatigueSafetyFactorItem"],
        "_private.materials._265": ["FatigueSafetyFactorItemBase"],
        "_private.materials._266": ["GearingTypes"],
        "_private.materials._267": ["GeneralTransmissionProperties"],
        "_private.materials._268": ["GreaseContaminationOptions"],
        "_private.materials._269": ["HardnessType"],
        "_private.materials._270": ["ISO76StaticSafetyFactorLimits"],
        "_private.materials._271": ["ISOLubricantType"],
        "_private.materials._272": ["LubricantDefinition"],
        "_private.materials._273": ["LubricantDelivery"],
        "_private.materials._274": ["LubricantViscosityClassAGMA"],
        "_private.materials._275": ["LubricantViscosityClassification"],
        "_private.materials._276": ["LubricantViscosityClassISO"],
        "_private.materials._277": ["LubricantViscosityClassSAE"],
        "_private.materials._278": ["LubricationDetail"],
        "_private.materials._279": ["LubricationDetailDatabase"],
        "_private.materials._280": ["Material"],
        "_private.materials._281": ["MaterialDatabase"],
        "_private.materials._282": ["MaterialsSettings"],
        "_private.materials._283": ["MaterialsSettingsDatabase"],
        "_private.materials._284": ["MaterialsSettingsItem"],
        "_private.materials._285": ["MaterialStandards"],
        "_private.materials._286": ["MetalPlasticType"],
        "_private.materials._287": ["OilFiltrationOptions"],
        "_private.materials._288": ["PressureViscosityCoefficientMethod"],
        "_private.materials._289": ["QualityGrade"],
        "_private.materials._290": ["SafetyFactorGroup"],
        "_private.materials._291": ["SafetyFactorItem"],
        "_private.materials._292": ["SNCurve"],
        "_private.materials._293": ["SNCurvePoint"],
        "_private.materials._294": ["SoundPressureEnclosure"],
        "_private.materials._295": ["SoundPressureEnclosureType"],
        "_private.materials._296": [
            "StressCyclesDataForTheBendingSNCurveOfAPlasticMaterial"
        ],
        "_private.materials._297": [
            "StressCyclesDataForTheContactSNCurveOfAPlasticMaterial"
        ],
        "_private.materials._298": ["TransmissionApplications"],
        "_private.materials._299": ["VDI2736LubricantType"],
        "_private.materials._300": ["VehicleDynamicsProperties"],
        "_private.materials._301": ["WindTurbineStandards"],
        "_private.materials._302": ["WorkingCharacteristics"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractStressCyclesDataForAnSNCurveOfAPlasticMaterial",
    "AcousticRadiationEfficiency",
    "AcousticRadiationEfficiencyInputType",
    "AGMALubricantType",
    "AGMAMaterialApplications",
    "AGMAMaterialClasses",
    "AGMAMaterialGrade",
    "AirProperties",
    "BearingLubricationCondition",
    "BearingMaterial",
    "BearingMaterialDatabase",
    "BHCurveExtrapolationMethod",
    "BHCurveSpecification",
    "ComponentMaterialDatabase",
    "CompositeFatigueSafetyFactorItem",
    "CylindricalGearRatingMethods",
    "DensitySpecificationMethod",
    "FatigueSafetyFactorItem",
    "FatigueSafetyFactorItemBase",
    "GearingTypes",
    "GeneralTransmissionProperties",
    "GreaseContaminationOptions",
    "HardnessType",
    "ISO76StaticSafetyFactorLimits",
    "ISOLubricantType",
    "LubricantDefinition",
    "LubricantDelivery",
    "LubricantViscosityClassAGMA",
    "LubricantViscosityClassification",
    "LubricantViscosityClassISO",
    "LubricantViscosityClassSAE",
    "LubricationDetail",
    "LubricationDetailDatabase",
    "Material",
    "MaterialDatabase",
    "MaterialsSettings",
    "MaterialsSettingsDatabase",
    "MaterialsSettingsItem",
    "MaterialStandards",
    "MetalPlasticType",
    "OilFiltrationOptions",
    "PressureViscosityCoefficientMethod",
    "QualityGrade",
    "SafetyFactorGroup",
    "SafetyFactorItem",
    "SNCurve",
    "SNCurvePoint",
    "SoundPressureEnclosure",
    "SoundPressureEnclosureType",
    "StressCyclesDataForTheBendingSNCurveOfAPlasticMaterial",
    "StressCyclesDataForTheContactSNCurveOfAPlasticMaterial",
    "TransmissionApplications",
    "VDI2736LubricantType",
    "VehicleDynamicsProperties",
    "WindTurbineStandards",
    "WorkingCharacteristics",
)
