"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5105 import (
        AbstractAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5106 import (
        AbstractShaftCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5107 import (
        AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5108 import (
        AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5109 import (
        AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5110 import (
        AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5111 import (
        AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5112 import (
        AssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5113 import (
        BearingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5114 import (
        BeltConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5115 import (
        BeltDriveCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5116 import (
        BevelDifferentialGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5117 import (
        BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5118 import (
        BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5119 import (
        BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5120 import (
        BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5121 import (
        BevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5122 import (
        BevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5123 import (
        BevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5124 import (
        BoltCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5125 import (
        BoltedJointCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5126 import (
        ClutchCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5127 import (
        ClutchConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5128 import (
        ClutchHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5129 import (
        CoaxialConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5130 import (
        ComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5131 import (
        ConceptCouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5132 import (
        ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5133 import (
        ConceptCouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5134 import (
        ConceptGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5135 import (
        ConceptGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5136 import (
        ConceptGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5137 import (
        ConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5138 import (
        ConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5139 import (
        ConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5140 import (
        ConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5141 import (
        ConnectorCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5142 import (
        CouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5143 import (
        CouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5144 import (
        CouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5145 import (
        CVTBeltConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5146 import (
        CVTCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5147 import (
        CVTPulleyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5148 import (
        CycloidalAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5149 import (
        CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5150 import (
        CycloidalDiscCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5151 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5152 import (
        CylindricalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5153 import (
        CylindricalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5154 import (
        CylindricalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5155 import (
        CylindricalPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5156 import (
        DatumCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5157 import (
        ExternalCADModelCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5158 import (
        FaceGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5159 import (
        FaceGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5160 import (
        FaceGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5161 import (
        FEPartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5162 import (
        FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5163 import (
        GearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5164 import (
        GearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5165 import (
        GearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5166 import (
        GuideDxfModelCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5167 import (
        HypoidGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5168 import (
        HypoidGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5169 import (
        HypoidGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5170 import (
        InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5171 import (
        KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5172 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5173 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5174 import (
        KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5175 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5176 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5177 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5178 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5179 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5180 import (
        MassDiscCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5181 import (
        MeasurementComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5182 import (
        MicrophoneArrayCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5183 import (
        MicrophoneCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5184 import (
        MountableComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5185 import (
        OilSealCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5186 import (
        PartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5187 import (
        PartToPartShearCouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5188 import (
        PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5189 import (
        PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5190 import (
        PlanetaryConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5191 import (
        PlanetaryGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5192 import (
        PlanetCarrierCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5193 import (
        PointLoadCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5194 import (
        PowerLoadCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5195 import (
        PulleyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5196 import (
        RingPinsCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5197 import (
        RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5198 import (
        RollingRingAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5199 import (
        RollingRingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5200 import (
        RollingRingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5201 import (
        RootAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5202 import (
        ShaftCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5203 import (
        ShaftHubConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5204 import (
        ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5205 import (
        SpecialisedAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5206 import (
        SpiralBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5207 import (
        SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5208 import (
        SpiralBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5209 import (
        SpringDamperCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5210 import (
        SpringDamperConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5211 import (
        SpringDamperHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5212 import (
        StraightBevelDiffGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5213 import (
        StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5214 import (
        StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5215 import (
        StraightBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5216 import (
        StraightBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5217 import (
        StraightBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5218 import (
        StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5219 import (
        StraightBevelSunGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5220 import (
        SynchroniserCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5221 import (
        SynchroniserHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5222 import (
        SynchroniserPartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5223 import (
        SynchroniserSleeveCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5224 import (
        TorqueConverterCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5225 import (
        TorqueConverterConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5226 import (
        TorqueConverterPumpCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5227 import (
        TorqueConverterTurbineCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5228 import (
        UnbalancedMassCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5229 import (
        VirtualComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5230 import (
        WormGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5231 import (
        WormGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5232 import (
        WormGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5233 import (
        ZerolBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5234 import (
        ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5235 import (
        ZerolBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5105": [
            "AbstractAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5106": [
            "AbstractShaftCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5107": [
            "AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5108": [
            "AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5109": [
            "AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5110": [
            "AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5111": [
            "AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5112": [
            "AssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5113": [
            "BearingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5114": [
            "BeltConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5115": [
            "BeltDriveCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5116": [
            "BevelDifferentialGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5117": [
            "BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5118": [
            "BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5119": [
            "BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5120": [
            "BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5121": [
            "BevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5122": [
            "BevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5123": [
            "BevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5124": [
            "BoltCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5125": [
            "BoltedJointCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5126": [
            "ClutchCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5127": [
            "ClutchConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5128": [
            "ClutchHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5129": [
            "CoaxialConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5130": [
            "ComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5131": [
            "ConceptCouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5132": [
            "ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5133": [
            "ConceptCouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5134": [
            "ConceptGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5135": [
            "ConceptGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5136": [
            "ConceptGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5137": [
            "ConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5138": [
            "ConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5139": [
            "ConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5140": [
            "ConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5141": [
            "ConnectorCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5142": [
            "CouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5143": [
            "CouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5144": [
            "CouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5145": [
            "CVTBeltConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5146": [
            "CVTCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5147": [
            "CVTPulleyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5148": [
            "CycloidalAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5149": [
            "CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5150": [
            "CycloidalDiscCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5151": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5152": [
            "CylindricalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5153": [
            "CylindricalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5154": [
            "CylindricalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5155": [
            "CylindricalPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5156": [
            "DatumCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5157": [
            "ExternalCADModelCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5158": [
            "FaceGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5159": [
            "FaceGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5160": [
            "FaceGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5161": [
            "FEPartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5162": [
            "FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5163": [
            "GearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5164": [
            "GearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5165": [
            "GearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5166": [
            "GuideDxfModelCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5167": [
            "HypoidGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5168": [
            "HypoidGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5169": [
            "HypoidGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5170": [
            "InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5171": [
            "KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5172": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5173": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5174": [
            "KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5175": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5176": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5177": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5178": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5179": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5180": [
            "MassDiscCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5181": [
            "MeasurementComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5182": [
            "MicrophoneArrayCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5183": [
            "MicrophoneCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5184": [
            "MountableComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5185": [
            "OilSealCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5186": [
            "PartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5187": [
            "PartToPartShearCouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5188": [
            "PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5189": [
            "PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5190": [
            "PlanetaryConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5191": [
            "PlanetaryGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5192": [
            "PlanetCarrierCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5193": [
            "PointLoadCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5194": [
            "PowerLoadCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5195": [
            "PulleyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5196": [
            "RingPinsCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5197": [
            "RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5198": [
            "RollingRingAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5199": [
            "RollingRingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5200": [
            "RollingRingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5201": [
            "RootAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5202": [
            "ShaftCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5203": [
            "ShaftHubConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5204": [
            "ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5205": [
            "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5206": [
            "SpiralBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5207": [
            "SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5208": [
            "SpiralBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5209": [
            "SpringDamperCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5210": [
            "SpringDamperConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5211": [
            "SpringDamperHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5212": [
            "StraightBevelDiffGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5213": [
            "StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5214": [
            "StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5215": [
            "StraightBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5216": [
            "StraightBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5217": [
            "StraightBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5218": [
            "StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5219": [
            "StraightBevelSunGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5220": [
            "SynchroniserCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5221": [
            "SynchroniserHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5222": [
            "SynchroniserPartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5223": [
            "SynchroniserSleeveCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5224": [
            "TorqueConverterCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5225": [
            "TorqueConverterConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5226": [
            "TorqueConverterPumpCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5227": [
            "TorqueConverterTurbineCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5228": [
            "UnbalancedMassCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5229": [
            "VirtualComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5230": [
            "WormGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5231": [
            "WormGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5232": [
            "WormGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5233": [
            "ZerolBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5234": [
            "ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5235": [
            "ZerolBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundModalAnalysisAtAStiffness",
    "AbstractShaftCompoundModalAnalysisAtAStiffness",
    "AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness",
    "AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness",
    "AssemblyCompoundModalAnalysisAtAStiffness",
    "BearingCompoundModalAnalysisAtAStiffness",
    "BeltConnectionCompoundModalAnalysisAtAStiffness",
    "BeltDriveCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness",
    "BevelGearCompoundModalAnalysisAtAStiffness",
    "BevelGearMeshCompoundModalAnalysisAtAStiffness",
    "BevelGearSetCompoundModalAnalysisAtAStiffness",
    "BoltCompoundModalAnalysisAtAStiffness",
    "BoltedJointCompoundModalAnalysisAtAStiffness",
    "ClutchCompoundModalAnalysisAtAStiffness",
    "ClutchConnectionCompoundModalAnalysisAtAStiffness",
    "ClutchHalfCompoundModalAnalysisAtAStiffness",
    "CoaxialConnectionCompoundModalAnalysisAtAStiffness",
    "ComponentCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingHalfCompoundModalAnalysisAtAStiffness",
    "ConceptGearCompoundModalAnalysisAtAStiffness",
    "ConceptGearMeshCompoundModalAnalysisAtAStiffness",
    "ConceptGearSetCompoundModalAnalysisAtAStiffness",
    "ConicalGearCompoundModalAnalysisAtAStiffness",
    "ConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "ConicalGearSetCompoundModalAnalysisAtAStiffness",
    "ConnectionCompoundModalAnalysisAtAStiffness",
    "ConnectorCompoundModalAnalysisAtAStiffness",
    "CouplingCompoundModalAnalysisAtAStiffness",
    "CouplingConnectionCompoundModalAnalysisAtAStiffness",
    "CouplingHalfCompoundModalAnalysisAtAStiffness",
    "CVTBeltConnectionCompoundModalAnalysisAtAStiffness",
    "CVTCompoundModalAnalysisAtAStiffness",
    "CVTPulleyCompoundModalAnalysisAtAStiffness",
    "CycloidalAssemblyCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness",
    "CylindricalGearCompoundModalAnalysisAtAStiffness",
    "CylindricalGearMeshCompoundModalAnalysisAtAStiffness",
    "CylindricalGearSetCompoundModalAnalysisAtAStiffness",
    "CylindricalPlanetGearCompoundModalAnalysisAtAStiffness",
    "DatumCompoundModalAnalysisAtAStiffness",
    "ExternalCADModelCompoundModalAnalysisAtAStiffness",
    "FaceGearCompoundModalAnalysisAtAStiffness",
    "FaceGearMeshCompoundModalAnalysisAtAStiffness",
    "FaceGearSetCompoundModalAnalysisAtAStiffness",
    "FEPartCompoundModalAnalysisAtAStiffness",
    "FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness",
    "GearCompoundModalAnalysisAtAStiffness",
    "GearMeshCompoundModalAnalysisAtAStiffness",
    "GearSetCompoundModalAnalysisAtAStiffness",
    "GuideDxfModelCompoundModalAnalysisAtAStiffness",
    "HypoidGearCompoundModalAnalysisAtAStiffness",
    "HypoidGearMeshCompoundModalAnalysisAtAStiffness",
    "HypoidGearSetCompoundModalAnalysisAtAStiffness",
    "InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness",
    "MassDiscCompoundModalAnalysisAtAStiffness",
    "MeasurementComponentCompoundModalAnalysisAtAStiffness",
    "MicrophoneArrayCompoundModalAnalysisAtAStiffness",
    "MicrophoneCompoundModalAnalysisAtAStiffness",
    "MountableComponentCompoundModalAnalysisAtAStiffness",
    "OilSealCompoundModalAnalysisAtAStiffness",
    "PartCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness",
    "PlanetaryConnectionCompoundModalAnalysisAtAStiffness",
    "PlanetaryGearSetCompoundModalAnalysisAtAStiffness",
    "PlanetCarrierCompoundModalAnalysisAtAStiffness",
    "PointLoadCompoundModalAnalysisAtAStiffness",
    "PowerLoadCompoundModalAnalysisAtAStiffness",
    "PulleyCompoundModalAnalysisAtAStiffness",
    "RingPinsCompoundModalAnalysisAtAStiffness",
    "RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness",
    "RollingRingAssemblyCompoundModalAnalysisAtAStiffness",
    "RollingRingCompoundModalAnalysisAtAStiffness",
    "RollingRingConnectionCompoundModalAnalysisAtAStiffness",
    "RootAssemblyCompoundModalAnalysisAtAStiffness",
    "ShaftCompoundModalAnalysisAtAStiffness",
    "ShaftHubConnectionCompoundModalAnalysisAtAStiffness",
    "ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearSetCompoundModalAnalysisAtAStiffness",
    "SpringDamperCompoundModalAnalysisAtAStiffness",
    "SpringDamperConnectionCompoundModalAnalysisAtAStiffness",
    "SpringDamperHalfCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearSetCompoundModalAnalysisAtAStiffness",
    "StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelSunGearCompoundModalAnalysisAtAStiffness",
    "SynchroniserCompoundModalAnalysisAtAStiffness",
    "SynchroniserHalfCompoundModalAnalysisAtAStiffness",
    "SynchroniserPartCompoundModalAnalysisAtAStiffness",
    "SynchroniserSleeveCompoundModalAnalysisAtAStiffness",
    "TorqueConverterCompoundModalAnalysisAtAStiffness",
    "TorqueConverterConnectionCompoundModalAnalysisAtAStiffness",
    "TorqueConverterPumpCompoundModalAnalysisAtAStiffness",
    "TorqueConverterTurbineCompoundModalAnalysisAtAStiffness",
    "UnbalancedMassCompoundModalAnalysisAtAStiffness",
    "VirtualComponentCompoundModalAnalysisAtAStiffness",
    "WormGearCompoundModalAnalysisAtAStiffness",
    "WormGearMeshCompoundModalAnalysisAtAStiffness",
    "WormGearSetCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearSetCompoundModalAnalysisAtAStiffness",
)
