"""mastapy_version_exception.

Module containing mastapy version exceptions.
"""


from __future__ import annotations


class MastapyVersionException(Exception):
    """Custom exception for version errors."""
