"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2936 import (
        AbstractAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2937 import (
        AbstractShaftCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2938 import (
        AbstractShaftOrHousingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2939 import (
        AbstractShaftToMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2940 import (
        AGMAGleasonConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2941 import (
        AGMAGleasonConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2942 import (
        AGMAGleasonConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2943 import (
        AssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2944 import (
        BearingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2945 import (
        BeltConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2946 import (
        BeltDriveCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2947 import (
        BevelDifferentialGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2948 import (
        BevelDifferentialGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2949 import (
        BevelDifferentialGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2950 import (
        BevelDifferentialPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2951 import (
        BevelDifferentialSunGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2952 import (
        BevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2953 import (
        BevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2954 import (
        BevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2955 import (
        BoltCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2956 import (
        BoltedJointCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2957 import (
        ClutchCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2958 import (
        ClutchConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2959 import (
        ClutchHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2960 import (
        CoaxialConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2961 import (
        ComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2962 import (
        ConceptCouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2963 import (
        ConceptCouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2964 import (
        ConceptCouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2965 import (
        ConceptGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2966 import (
        ConceptGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2967 import (
        ConceptGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2968 import (
        ConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2969 import (
        ConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2970 import (
        ConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2971 import (
        ConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2972 import (
        ConnectorCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2973 import (
        CouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2974 import (
        CouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2975 import (
        CouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2976 import (
        CVTBeltConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2977 import (
        CVTCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2978 import (
        CVTPulleyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2979 import (
        CycloidalAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2980 import (
        CycloidalDiscCentralBearingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2981 import (
        CycloidalDiscCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2982 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2983 import (
        CylindricalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2984 import (
        CylindricalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2985 import (
        CylindricalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2986 import (
        CylindricalPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2987 import (
        DatumCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2988 import (
        DutyCycleEfficiencyResults,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2989 import (
        ExternalCADModelCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2990 import (
        FaceGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2991 import (
        FaceGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2992 import (
        FaceGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2993 import (
        FEPartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2994 import (
        FlexiblePinAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2995 import (
        GearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2996 import (
        GearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2997 import (
        GearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2998 import (
        GuideDxfModelCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._2999 import (
        HypoidGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3000 import (
        HypoidGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3001 import (
        HypoidGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3002 import (
        InterMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3003 import (
        KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3004 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3005 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3006 import (
        KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3007 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3008 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3009 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3010 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3011 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3012 import (
        MassDiscCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3013 import (
        MeasurementComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3014 import (
        MicrophoneArrayCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3015 import (
        MicrophoneCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3016 import (
        MountableComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3017 import (
        OilSealCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3018 import (
        PartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3019 import (
        PartToPartShearCouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3020 import (
        PartToPartShearCouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3021 import (
        PartToPartShearCouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3022 import (
        PlanetaryConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3023 import (
        PlanetaryGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3024 import (
        PlanetCarrierCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3025 import (
        PointLoadCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3026 import (
        PowerLoadCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3027 import (
        PulleyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3028 import (
        RingPinsCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3029 import (
        RingPinsToDiscConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3030 import (
        RollingRingAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3031 import (
        RollingRingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3032 import (
        RollingRingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3033 import (
        RootAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3034 import (
        ShaftCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3035 import (
        ShaftDutyCycleSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3036 import (
        ShaftHubConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3037 import (
        ShaftToMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3038 import (
        SpecialisedAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3039 import (
        SpiralBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3040 import (
        SpiralBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3041 import (
        SpiralBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3042 import (
        SpringDamperCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3043 import (
        SpringDamperConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3044 import (
        SpringDamperHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3045 import (
        StraightBevelDiffGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3046 import (
        StraightBevelDiffGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3047 import (
        StraightBevelDiffGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3048 import (
        StraightBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3049 import (
        StraightBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3050 import (
        StraightBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3051 import (
        StraightBevelPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3052 import (
        StraightBevelSunGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3053 import (
        SynchroniserCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3054 import (
        SynchroniserHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3055 import (
        SynchroniserPartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3056 import (
        SynchroniserSleeveCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3057 import (
        TorqueConverterCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3058 import (
        TorqueConverterConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3059 import (
        TorqueConverterPumpCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3060 import (
        TorqueConverterTurbineCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3061 import (
        UnbalancedMassCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3062 import (
        VirtualComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3063 import (
        WormGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3064 import (
        WormGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3065 import (
        WormGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3066 import (
        ZerolBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3067 import (
        ZerolBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3068 import (
        ZerolBevelGearSetCompoundSystemDeflection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.system_deflections.compound._2936": [
            "AbstractAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2937": [
            "AbstractShaftCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2938": [
            "AbstractShaftOrHousingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2939": [
            "AbstractShaftToMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2940": [
            "AGMAGleasonConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2941": [
            "AGMAGleasonConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2942": [
            "AGMAGleasonConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2943": [
            "AssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2944": [
            "BearingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2945": [
            "BeltConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2946": [
            "BeltDriveCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2947": [
            "BevelDifferentialGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2948": [
            "BevelDifferentialGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2949": [
            "BevelDifferentialGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2950": [
            "BevelDifferentialPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2951": [
            "BevelDifferentialSunGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2952": [
            "BevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2953": [
            "BevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2954": [
            "BevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2955": [
            "BoltCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2956": [
            "BoltedJointCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2957": [
            "ClutchCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2958": [
            "ClutchConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2959": [
            "ClutchHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2960": [
            "CoaxialConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2961": [
            "ComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2962": [
            "ConceptCouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2963": [
            "ConceptCouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2964": [
            "ConceptCouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2965": [
            "ConceptGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2966": [
            "ConceptGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2967": [
            "ConceptGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2968": [
            "ConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2969": [
            "ConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2970": [
            "ConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2971": [
            "ConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2972": [
            "ConnectorCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2973": [
            "CouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2974": [
            "CouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2975": [
            "CouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2976": [
            "CVTBeltConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2977": [
            "CVTCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2978": [
            "CVTPulleyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2979": [
            "CycloidalAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2980": [
            "CycloidalDiscCentralBearingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2981": [
            "CycloidalDiscCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2982": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2983": [
            "CylindricalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2984": [
            "CylindricalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2985": [
            "CylindricalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2986": [
            "CylindricalPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2987": [
            "DatumCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2988": [
            "DutyCycleEfficiencyResults"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2989": [
            "ExternalCADModelCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2990": [
            "FaceGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2991": [
            "FaceGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2992": [
            "FaceGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2993": [
            "FEPartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2994": [
            "FlexiblePinAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2995": [
            "GearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2996": [
            "GearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2997": [
            "GearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2998": [
            "GuideDxfModelCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._2999": [
            "HypoidGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3000": [
            "HypoidGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3001": [
            "HypoidGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3002": [
            "InterMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3003": [
            "KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3004": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3005": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3006": [
            "KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3007": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3008": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3009": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3010": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3011": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3012": [
            "MassDiscCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3013": [
            "MeasurementComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3014": [
            "MicrophoneArrayCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3015": [
            "MicrophoneCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3016": [
            "MountableComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3017": [
            "OilSealCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3018": [
            "PartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3019": [
            "PartToPartShearCouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3020": [
            "PartToPartShearCouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3021": [
            "PartToPartShearCouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3022": [
            "PlanetaryConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3023": [
            "PlanetaryGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3024": [
            "PlanetCarrierCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3025": [
            "PointLoadCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3026": [
            "PowerLoadCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3027": [
            "PulleyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3028": [
            "RingPinsCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3029": [
            "RingPinsToDiscConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3030": [
            "RollingRingAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3031": [
            "RollingRingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3032": [
            "RollingRingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3033": [
            "RootAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3034": [
            "ShaftCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3035": [
            "ShaftDutyCycleSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3036": [
            "ShaftHubConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3037": [
            "ShaftToMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3038": [
            "SpecialisedAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3039": [
            "SpiralBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3040": [
            "SpiralBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3041": [
            "SpiralBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3042": [
            "SpringDamperCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3043": [
            "SpringDamperConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3044": [
            "SpringDamperHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3045": [
            "StraightBevelDiffGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3046": [
            "StraightBevelDiffGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3047": [
            "StraightBevelDiffGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3048": [
            "StraightBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3049": [
            "StraightBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3050": [
            "StraightBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3051": [
            "StraightBevelPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3052": [
            "StraightBevelSunGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3053": [
            "SynchroniserCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3054": [
            "SynchroniserHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3055": [
            "SynchroniserPartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3056": [
            "SynchroniserSleeveCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3057": [
            "TorqueConverterCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3058": [
            "TorqueConverterConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3059": [
            "TorqueConverterPumpCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3060": [
            "TorqueConverterTurbineCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3061": [
            "UnbalancedMassCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3062": [
            "VirtualComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3063": [
            "WormGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3064": [
            "WormGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3065": [
            "WormGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3066": [
            "ZerolBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3067": [
            "ZerolBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3068": [
            "ZerolBevelGearSetCompoundSystemDeflection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundSystemDeflection",
    "AbstractShaftCompoundSystemDeflection",
    "AbstractShaftOrHousingCompoundSystemDeflection",
    "AbstractShaftToMountableComponentConnectionCompoundSystemDeflection",
    "AGMAGleasonConicalGearCompoundSystemDeflection",
    "AGMAGleasonConicalGearMeshCompoundSystemDeflection",
    "AGMAGleasonConicalGearSetCompoundSystemDeflection",
    "AssemblyCompoundSystemDeflection",
    "BearingCompoundSystemDeflection",
    "BeltConnectionCompoundSystemDeflection",
    "BeltDriveCompoundSystemDeflection",
    "BevelDifferentialGearCompoundSystemDeflection",
    "BevelDifferentialGearMeshCompoundSystemDeflection",
    "BevelDifferentialGearSetCompoundSystemDeflection",
    "BevelDifferentialPlanetGearCompoundSystemDeflection",
    "BevelDifferentialSunGearCompoundSystemDeflection",
    "BevelGearCompoundSystemDeflection",
    "BevelGearMeshCompoundSystemDeflection",
    "BevelGearSetCompoundSystemDeflection",
    "BoltCompoundSystemDeflection",
    "BoltedJointCompoundSystemDeflection",
    "ClutchCompoundSystemDeflection",
    "ClutchConnectionCompoundSystemDeflection",
    "ClutchHalfCompoundSystemDeflection",
    "CoaxialConnectionCompoundSystemDeflection",
    "ComponentCompoundSystemDeflection",
    "ConceptCouplingCompoundSystemDeflection",
    "ConceptCouplingConnectionCompoundSystemDeflection",
    "ConceptCouplingHalfCompoundSystemDeflection",
    "ConceptGearCompoundSystemDeflection",
    "ConceptGearMeshCompoundSystemDeflection",
    "ConceptGearSetCompoundSystemDeflection",
    "ConicalGearCompoundSystemDeflection",
    "ConicalGearMeshCompoundSystemDeflection",
    "ConicalGearSetCompoundSystemDeflection",
    "ConnectionCompoundSystemDeflection",
    "ConnectorCompoundSystemDeflection",
    "CouplingCompoundSystemDeflection",
    "CouplingConnectionCompoundSystemDeflection",
    "CouplingHalfCompoundSystemDeflection",
    "CVTBeltConnectionCompoundSystemDeflection",
    "CVTCompoundSystemDeflection",
    "CVTPulleyCompoundSystemDeflection",
    "CycloidalAssemblyCompoundSystemDeflection",
    "CycloidalDiscCentralBearingConnectionCompoundSystemDeflection",
    "CycloidalDiscCompoundSystemDeflection",
    "CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection",
    "CylindricalGearCompoundSystemDeflection",
    "CylindricalGearMeshCompoundSystemDeflection",
    "CylindricalGearSetCompoundSystemDeflection",
    "CylindricalPlanetGearCompoundSystemDeflection",
    "DatumCompoundSystemDeflection",
    "DutyCycleEfficiencyResults",
    "ExternalCADModelCompoundSystemDeflection",
    "FaceGearCompoundSystemDeflection",
    "FaceGearMeshCompoundSystemDeflection",
    "FaceGearSetCompoundSystemDeflection",
    "FEPartCompoundSystemDeflection",
    "FlexiblePinAssemblyCompoundSystemDeflection",
    "GearCompoundSystemDeflection",
    "GearMeshCompoundSystemDeflection",
    "GearSetCompoundSystemDeflection",
    "GuideDxfModelCompoundSystemDeflection",
    "HypoidGearCompoundSystemDeflection",
    "HypoidGearMeshCompoundSystemDeflection",
    "HypoidGearSetCompoundSystemDeflection",
    "InterMountableComponentConnectionCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection",
    "MassDiscCompoundSystemDeflection",
    "MeasurementComponentCompoundSystemDeflection",
    "MicrophoneArrayCompoundSystemDeflection",
    "MicrophoneCompoundSystemDeflection",
    "MountableComponentCompoundSystemDeflection",
    "OilSealCompoundSystemDeflection",
    "PartCompoundSystemDeflection",
    "PartToPartShearCouplingCompoundSystemDeflection",
    "PartToPartShearCouplingConnectionCompoundSystemDeflection",
    "PartToPartShearCouplingHalfCompoundSystemDeflection",
    "PlanetaryConnectionCompoundSystemDeflection",
    "PlanetaryGearSetCompoundSystemDeflection",
    "PlanetCarrierCompoundSystemDeflection",
    "PointLoadCompoundSystemDeflection",
    "PowerLoadCompoundSystemDeflection",
    "PulleyCompoundSystemDeflection",
    "RingPinsCompoundSystemDeflection",
    "RingPinsToDiscConnectionCompoundSystemDeflection",
    "RollingRingAssemblyCompoundSystemDeflection",
    "RollingRingCompoundSystemDeflection",
    "RollingRingConnectionCompoundSystemDeflection",
    "RootAssemblyCompoundSystemDeflection",
    "ShaftCompoundSystemDeflection",
    "ShaftDutyCycleSystemDeflection",
    "ShaftHubConnectionCompoundSystemDeflection",
    "ShaftToMountableComponentConnectionCompoundSystemDeflection",
    "SpecialisedAssemblyCompoundSystemDeflection",
    "SpiralBevelGearCompoundSystemDeflection",
    "SpiralBevelGearMeshCompoundSystemDeflection",
    "SpiralBevelGearSetCompoundSystemDeflection",
    "SpringDamperCompoundSystemDeflection",
    "SpringDamperConnectionCompoundSystemDeflection",
    "SpringDamperHalfCompoundSystemDeflection",
    "StraightBevelDiffGearCompoundSystemDeflection",
    "StraightBevelDiffGearMeshCompoundSystemDeflection",
    "StraightBevelDiffGearSetCompoundSystemDeflection",
    "StraightBevelGearCompoundSystemDeflection",
    "StraightBevelGearMeshCompoundSystemDeflection",
    "StraightBevelGearSetCompoundSystemDeflection",
    "StraightBevelPlanetGearCompoundSystemDeflection",
    "StraightBevelSunGearCompoundSystemDeflection",
    "SynchroniserCompoundSystemDeflection",
    "SynchroniserHalfCompoundSystemDeflection",
    "SynchroniserPartCompoundSystemDeflection",
    "SynchroniserSleeveCompoundSystemDeflection",
    "TorqueConverterCompoundSystemDeflection",
    "TorqueConverterConnectionCompoundSystemDeflection",
    "TorqueConverterPumpCompoundSystemDeflection",
    "TorqueConverterTurbineCompoundSystemDeflection",
    "UnbalancedMassCompoundSystemDeflection",
    "VirtualComponentCompoundSystemDeflection",
    "WormGearCompoundSystemDeflection",
    "WormGearMeshCompoundSystemDeflection",
    "WormGearSetCompoundSystemDeflection",
    "ZerolBevelGearCompoundSystemDeflection",
    "ZerolBevelGearMeshCompoundSystemDeflection",
    "ZerolBevelGearSetCompoundSystemDeflection",
)
