"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._681 import (
        ActiveProcessMethod,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._682 import (
        AnalysisMethod,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._683 import (
        CalculateLeadDeviationAccuracy,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._684 import (
        CalculatePitchDeviationAccuracy,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._685 import (
        CalculateProfileDeviationAccuracy,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._686 import (
        CentreDistanceOffsetMethod,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._687 import (
        CutterHeadSlideError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._688 import (
        GearMountingError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._689 import (
        HobbingProcessCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._690 import (
        HobbingProcessGearShape,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._691 import (
        HobbingProcessLeadCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._692 import (
        HobbingProcessMarkOnShaft,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._693 import (
        HobbingProcessPitchCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._694 import (
        HobbingProcessProfileCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._695 import (
        HobbingProcessSimulationInput,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._696 import (
        HobbingProcessSimulationNew,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._697 import (
        HobbingProcessSimulationViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._698 import (
        HobbingProcessTotalModificationCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._699 import (
        HobManufactureError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._700 import (
        HobResharpeningError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._701 import (
        ManufacturedQualityGrade,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._702 import (
        MountingError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._703 import (
        ProcessCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._704 import (
        ProcessGearShape,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._705 import (
        ProcessLeadCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._706 import (
        ProcessPitchCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._707 import (
        ProcessProfileCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._708 import (
        ProcessSimulationInput,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._709 import (
        ProcessSimulationNew,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._710 import (
        ProcessSimulationViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._711 import (
        ProcessTotalModificationCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._712 import (
        RackManufactureError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._713 import (
        RackMountingError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._714 import (
        WormGrinderManufactureError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._715 import (
        WormGrindingCutterCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._716 import (
        WormGrindingLeadCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._717 import (
        WormGrindingProcessCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._718 import (
        WormGrindingProcessGearShape,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._719 import (
        WormGrindingProcessMarkOnShaft,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._720 import (
        WormGrindingProcessPitchCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._721 import (
        WormGrindingProcessProfileCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._722 import (
        WormGrindingProcessSimulationInput,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._723 import (
        WormGrindingProcessSimulationNew,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._724 import (
        WormGrindingProcessSimulationViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._725 import (
        WormGrindingProcessTotalModificationCalculation,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._681": [
            "ActiveProcessMethod"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._682": [
            "AnalysisMethod"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._683": [
            "CalculateLeadDeviationAccuracy"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._684": [
            "CalculatePitchDeviationAccuracy"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._685": [
            "CalculateProfileDeviationAccuracy"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._686": [
            "CentreDistanceOffsetMethod"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._687": [
            "CutterHeadSlideError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._688": [
            "GearMountingError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._689": [
            "HobbingProcessCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._690": [
            "HobbingProcessGearShape"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._691": [
            "HobbingProcessLeadCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._692": [
            "HobbingProcessMarkOnShaft"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._693": [
            "HobbingProcessPitchCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._694": [
            "HobbingProcessProfileCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._695": [
            "HobbingProcessSimulationInput"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._696": [
            "HobbingProcessSimulationNew"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._697": [
            "HobbingProcessSimulationViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._698": [
            "HobbingProcessTotalModificationCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._699": [
            "HobManufactureError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._700": [
            "HobResharpeningError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._701": [
            "ManufacturedQualityGrade"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._702": [
            "MountingError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._703": [
            "ProcessCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._704": [
            "ProcessGearShape"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._705": [
            "ProcessLeadCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._706": [
            "ProcessPitchCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._707": [
            "ProcessProfileCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._708": [
            "ProcessSimulationInput"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._709": [
            "ProcessSimulationNew"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._710": [
            "ProcessSimulationViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._711": [
            "ProcessTotalModificationCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._712": [
            "RackManufactureError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._713": [
            "RackMountingError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._714": [
            "WormGrinderManufactureError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._715": [
            "WormGrindingCutterCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._716": [
            "WormGrindingLeadCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._717": [
            "WormGrindingProcessCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._718": [
            "WormGrindingProcessGearShape"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._719": [
            "WormGrindingProcessMarkOnShaft"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._720": [
            "WormGrindingProcessPitchCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._721": [
            "WormGrindingProcessProfileCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._722": [
            "WormGrindingProcessSimulationInput"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._723": [
            "WormGrindingProcessSimulationNew"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._724": [
            "WormGrindingProcessSimulationViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._725": [
            "WormGrindingProcessTotalModificationCalculation"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "ActiveProcessMethod",
    "AnalysisMethod",
    "CalculateLeadDeviationAccuracy",
    "CalculatePitchDeviationAccuracy",
    "CalculateProfileDeviationAccuracy",
    "CentreDistanceOffsetMethod",
    "CutterHeadSlideError",
    "GearMountingError",
    "HobbingProcessCalculation",
    "HobbingProcessGearShape",
    "HobbingProcessLeadCalculation",
    "HobbingProcessMarkOnShaft",
    "HobbingProcessPitchCalculation",
    "HobbingProcessProfileCalculation",
    "HobbingProcessSimulationInput",
    "HobbingProcessSimulationNew",
    "HobbingProcessSimulationViewModel",
    "HobbingProcessTotalModificationCalculation",
    "HobManufactureError",
    "HobResharpeningError",
    "ManufacturedQualityGrade",
    "MountingError",
    "ProcessCalculation",
    "ProcessGearShape",
    "ProcessLeadCalculation",
    "ProcessPitchCalculation",
    "ProcessProfileCalculation",
    "ProcessSimulationInput",
    "ProcessSimulationNew",
    "ProcessSimulationViewModel",
    "ProcessTotalModificationCalculation",
    "RackManufactureError",
    "RackMountingError",
    "WormGrinderManufactureError",
    "WormGrindingCutterCalculation",
    "WormGrindingLeadCalculation",
    "WormGrindingProcessCalculation",
    "WormGrindingProcessGearShape",
    "WormGrindingProcessMarkOnShaft",
    "WormGrindingProcessPitchCalculation",
    "WormGrindingProcessProfileCalculation",
    "WormGrindingProcessSimulationInput",
    "WormGrindingProcessSimulationNew",
    "WormGrindingProcessSimulationViewModel",
    "WormGrindingProcessTotalModificationCalculation",
)
