"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6685 import (
        AbstractAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6686 import (
        AbstractShaftCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6687 import (
        AbstractShaftOrHousingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6688 import (
        AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6689 import (
        AGMAGleasonConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6690 import (
        AGMAGleasonConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6691 import (
        AGMAGleasonConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6692 import (
        AssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6693 import (
        BearingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6694 import (
        BeltConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6695 import (
        BeltDriveCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6696 import (
        BevelDifferentialGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6697 import (
        BevelDifferentialGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6698 import (
        BevelDifferentialGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6699 import (
        BevelDifferentialPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6700 import (
        BevelDifferentialSunGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6701 import (
        BevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6702 import (
        BevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6703 import (
        BevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6704 import (
        BoltCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6705 import (
        BoltedJointCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6706 import (
        ClutchConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6707 import (
        ClutchCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6708 import (
        ClutchHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6709 import (
        CoaxialConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6710 import (
        ComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6711 import (
        ConceptCouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6712 import (
        ConceptCouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6713 import (
        ConceptCouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6714 import (
        ConceptGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6715 import (
        ConceptGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6716 import (
        ConceptGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6717 import (
        ConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6718 import (
        ConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6719 import (
        ConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6720 import (
        ConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6721 import (
        ConnectorCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6722 import (
        CouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6723 import (
        CouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6724 import (
        CouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6725 import (
        CriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6726 import (
        CriticalSpeedAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6727 import (
        CriticalSpeedAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6728 import (
        CVTBeltConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6729 import (
        CVTCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6730 import (
        CVTPulleyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6731 import (
        CycloidalAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6732 import (
        CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6733 import (
        CycloidalDiscCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6734 import (
        CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6735 import (
        CylindricalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6736 import (
        CylindricalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6737 import (
        CylindricalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6738 import (
        CylindricalPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6739 import (
        DatumCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6740 import (
        ExternalCADModelCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6741 import (
        FaceGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6742 import (
        FaceGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6743 import (
        FaceGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6744 import (
        FEPartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6745 import (
        FlexiblePinAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6746 import (
        GearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6747 import (
        GearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6748 import (
        GearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6749 import (
        GuideDxfModelCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6750 import (
        HypoidGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6751 import (
        HypoidGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6752 import (
        HypoidGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6753 import (
        InterMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6754 import (
        KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6755 import (
        KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6756 import (
        KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6757 import (
        KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6758 import (
        KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6759 import (
        KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6760 import (
        KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6761 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6762 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6763 import (
        MassDiscCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6764 import (
        MeasurementComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6765 import (
        MicrophoneArrayCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6766 import (
        MicrophoneCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6767 import (
        MountableComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6768 import (
        OilSealCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6769 import (
        PartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6770 import (
        PartToPartShearCouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6771 import (
        PartToPartShearCouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6772 import (
        PartToPartShearCouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6773 import (
        PlanetaryConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6774 import (
        PlanetaryGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6775 import (
        PlanetCarrierCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6776 import (
        PointLoadCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6777 import (
        PowerLoadCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6778 import (
        PulleyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6779 import (
        RingPinsCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6780 import (
        RingPinsToDiscConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6781 import (
        RollingRingAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6782 import (
        RollingRingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6783 import (
        RollingRingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6784 import (
        RootAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6785 import (
        ShaftCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6786 import (
        ShaftHubConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6787 import (
        ShaftToMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6788 import (
        SpecialisedAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6789 import (
        SpiralBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6790 import (
        SpiralBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6791 import (
        SpiralBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6792 import (
        SpringDamperConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6793 import (
        SpringDamperCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6794 import (
        SpringDamperHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6795 import (
        StraightBevelDiffGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6796 import (
        StraightBevelDiffGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6797 import (
        StraightBevelDiffGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6798 import (
        StraightBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6799 import (
        StraightBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6800 import (
        StraightBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6801 import (
        StraightBevelPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6802 import (
        StraightBevelSunGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6803 import (
        SynchroniserCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6804 import (
        SynchroniserHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6805 import (
        SynchroniserPartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6806 import (
        SynchroniserSleeveCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6807 import (
        TorqueConverterConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6808 import (
        TorqueConverterCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6809 import (
        TorqueConverterPumpCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6810 import (
        TorqueConverterTurbineCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6811 import (
        UnbalancedMassCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6812 import (
        VirtualComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6813 import (
        WormGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6814 import (
        WormGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6815 import (
        WormGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6816 import (
        ZerolBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6817 import (
        ZerolBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6818 import (
        ZerolBevelGearSetCriticalSpeedAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.critical_speed_analyses._6685": [
            "AbstractAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6686": [
            "AbstractShaftCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6687": [
            "AbstractShaftOrHousingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6688": [
            "AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6689": [
            "AGMAGleasonConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6690": [
            "AGMAGleasonConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6691": [
            "AGMAGleasonConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6692": [
            "AssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6693": [
            "BearingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6694": [
            "BeltConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6695": [
            "BeltDriveCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6696": [
            "BevelDifferentialGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6697": [
            "BevelDifferentialGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6698": [
            "BevelDifferentialGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6699": [
            "BevelDifferentialPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6700": [
            "BevelDifferentialSunGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6701": [
            "BevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6702": [
            "BevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6703": [
            "BevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6704": [
            "BoltCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6705": [
            "BoltedJointCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6706": [
            "ClutchConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6707": [
            "ClutchCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6708": [
            "ClutchHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6709": [
            "CoaxialConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6710": [
            "ComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6711": [
            "ConceptCouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6712": [
            "ConceptCouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6713": [
            "ConceptCouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6714": [
            "ConceptGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6715": [
            "ConceptGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6716": [
            "ConceptGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6717": [
            "ConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6718": [
            "ConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6719": [
            "ConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6720": [
            "ConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6721": [
            "ConnectorCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6722": [
            "CouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6723": [
            "CouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6724": [
            "CouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6725": [
            "CriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6726": [
            "CriticalSpeedAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6727": [
            "CriticalSpeedAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6728": [
            "CVTBeltConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6729": [
            "CVTCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6730": [
            "CVTPulleyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6731": [
            "CycloidalAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6732": [
            "CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6733": [
            "CycloidalDiscCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6734": [
            "CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6735": [
            "CylindricalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6736": [
            "CylindricalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6737": [
            "CylindricalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6738": [
            "CylindricalPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6739": [
            "DatumCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6740": [
            "ExternalCADModelCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6741": [
            "FaceGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6742": [
            "FaceGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6743": [
            "FaceGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6744": [
            "FEPartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6745": [
            "FlexiblePinAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6746": [
            "GearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6747": [
            "GearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6748": [
            "GearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6749": [
            "GuideDxfModelCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6750": [
            "HypoidGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6751": [
            "HypoidGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6752": [
            "HypoidGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6753": [
            "InterMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6754": [
            "KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6755": [
            "KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6756": [
            "KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6757": [
            "KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6758": [
            "KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6759": [
            "KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6760": [
            "KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6761": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6762": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6763": [
            "MassDiscCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6764": [
            "MeasurementComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6765": [
            "MicrophoneArrayCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6766": [
            "MicrophoneCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6767": [
            "MountableComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6768": [
            "OilSealCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6769": [
            "PartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6770": [
            "PartToPartShearCouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6771": [
            "PartToPartShearCouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6772": [
            "PartToPartShearCouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6773": [
            "PlanetaryConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6774": [
            "PlanetaryGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6775": [
            "PlanetCarrierCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6776": [
            "PointLoadCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6777": [
            "PowerLoadCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6778": [
            "PulleyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6779": [
            "RingPinsCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6780": [
            "RingPinsToDiscConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6781": [
            "RollingRingAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6782": [
            "RollingRingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6783": [
            "RollingRingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6784": [
            "RootAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6785": [
            "ShaftCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6786": [
            "ShaftHubConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6787": [
            "ShaftToMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6788": [
            "SpecialisedAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6789": [
            "SpiralBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6790": [
            "SpiralBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6791": [
            "SpiralBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6792": [
            "SpringDamperConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6793": [
            "SpringDamperCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6794": [
            "SpringDamperHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6795": [
            "StraightBevelDiffGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6796": [
            "StraightBevelDiffGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6797": [
            "StraightBevelDiffGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6798": [
            "StraightBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6799": [
            "StraightBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6800": [
            "StraightBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6801": [
            "StraightBevelPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6802": [
            "StraightBevelSunGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6803": [
            "SynchroniserCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6804": [
            "SynchroniserHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6805": [
            "SynchroniserPartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6806": [
            "SynchroniserSleeveCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6807": [
            "TorqueConverterConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6808": [
            "TorqueConverterCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6809": [
            "TorqueConverterPumpCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6810": [
            "TorqueConverterTurbineCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6811": [
            "UnbalancedMassCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6812": [
            "VirtualComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6813": [
            "WormGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6814": [
            "WormGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6815": [
            "WormGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6816": [
            "ZerolBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6817": [
            "ZerolBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6818": [
            "ZerolBevelGearSetCriticalSpeedAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCriticalSpeedAnalysis",
    "AbstractShaftCriticalSpeedAnalysis",
    "AbstractShaftOrHousingCriticalSpeedAnalysis",
    "AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearMeshCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearSetCriticalSpeedAnalysis",
    "AssemblyCriticalSpeedAnalysis",
    "BearingCriticalSpeedAnalysis",
    "BeltConnectionCriticalSpeedAnalysis",
    "BeltDriveCriticalSpeedAnalysis",
    "BevelDifferentialGearCriticalSpeedAnalysis",
    "BevelDifferentialGearMeshCriticalSpeedAnalysis",
    "BevelDifferentialGearSetCriticalSpeedAnalysis",
    "BevelDifferentialPlanetGearCriticalSpeedAnalysis",
    "BevelDifferentialSunGearCriticalSpeedAnalysis",
    "BevelGearCriticalSpeedAnalysis",
    "BevelGearMeshCriticalSpeedAnalysis",
    "BevelGearSetCriticalSpeedAnalysis",
    "BoltCriticalSpeedAnalysis",
    "BoltedJointCriticalSpeedAnalysis",
    "ClutchConnectionCriticalSpeedAnalysis",
    "ClutchCriticalSpeedAnalysis",
    "ClutchHalfCriticalSpeedAnalysis",
    "CoaxialConnectionCriticalSpeedAnalysis",
    "ComponentCriticalSpeedAnalysis",
    "ConceptCouplingConnectionCriticalSpeedAnalysis",
    "ConceptCouplingCriticalSpeedAnalysis",
    "ConceptCouplingHalfCriticalSpeedAnalysis",
    "ConceptGearCriticalSpeedAnalysis",
    "ConceptGearMeshCriticalSpeedAnalysis",
    "ConceptGearSetCriticalSpeedAnalysis",
    "ConicalGearCriticalSpeedAnalysis",
    "ConicalGearMeshCriticalSpeedAnalysis",
    "ConicalGearSetCriticalSpeedAnalysis",
    "ConnectionCriticalSpeedAnalysis",
    "ConnectorCriticalSpeedAnalysis",
    "CouplingConnectionCriticalSpeedAnalysis",
    "CouplingCriticalSpeedAnalysis",
    "CouplingHalfCriticalSpeedAnalysis",
    "CriticalSpeedAnalysis",
    "CriticalSpeedAnalysisDrawStyle",
    "CriticalSpeedAnalysisOptions",
    "CVTBeltConnectionCriticalSpeedAnalysis",
    "CVTCriticalSpeedAnalysis",
    "CVTPulleyCriticalSpeedAnalysis",
    "CycloidalAssemblyCriticalSpeedAnalysis",
    "CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis",
    "CycloidalDiscCriticalSpeedAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis",
    "CylindricalGearCriticalSpeedAnalysis",
    "CylindricalGearMeshCriticalSpeedAnalysis",
    "CylindricalGearSetCriticalSpeedAnalysis",
    "CylindricalPlanetGearCriticalSpeedAnalysis",
    "DatumCriticalSpeedAnalysis",
    "ExternalCADModelCriticalSpeedAnalysis",
    "FaceGearCriticalSpeedAnalysis",
    "FaceGearMeshCriticalSpeedAnalysis",
    "FaceGearSetCriticalSpeedAnalysis",
    "FEPartCriticalSpeedAnalysis",
    "FlexiblePinAssemblyCriticalSpeedAnalysis",
    "GearCriticalSpeedAnalysis",
    "GearMeshCriticalSpeedAnalysis",
    "GearSetCriticalSpeedAnalysis",
    "GuideDxfModelCriticalSpeedAnalysis",
    "HypoidGearCriticalSpeedAnalysis",
    "HypoidGearMeshCriticalSpeedAnalysis",
    "HypoidGearSetCriticalSpeedAnalysis",
    "InterMountableComponentConnectionCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis",
    "MassDiscCriticalSpeedAnalysis",
    "MeasurementComponentCriticalSpeedAnalysis",
    "MicrophoneArrayCriticalSpeedAnalysis",
    "MicrophoneCriticalSpeedAnalysis",
    "MountableComponentCriticalSpeedAnalysis",
    "OilSealCriticalSpeedAnalysis",
    "PartCriticalSpeedAnalysis",
    "PartToPartShearCouplingConnectionCriticalSpeedAnalysis",
    "PartToPartShearCouplingCriticalSpeedAnalysis",
    "PartToPartShearCouplingHalfCriticalSpeedAnalysis",
    "PlanetaryConnectionCriticalSpeedAnalysis",
    "PlanetaryGearSetCriticalSpeedAnalysis",
    "PlanetCarrierCriticalSpeedAnalysis",
    "PointLoadCriticalSpeedAnalysis",
    "PowerLoadCriticalSpeedAnalysis",
    "PulleyCriticalSpeedAnalysis",
    "RingPinsCriticalSpeedAnalysis",
    "RingPinsToDiscConnectionCriticalSpeedAnalysis",
    "RollingRingAssemblyCriticalSpeedAnalysis",
    "RollingRingConnectionCriticalSpeedAnalysis",
    "RollingRingCriticalSpeedAnalysis",
    "RootAssemblyCriticalSpeedAnalysis",
    "ShaftCriticalSpeedAnalysis",
    "ShaftHubConnectionCriticalSpeedAnalysis",
    "ShaftToMountableComponentConnectionCriticalSpeedAnalysis",
    "SpecialisedAssemblyCriticalSpeedAnalysis",
    "SpiralBevelGearCriticalSpeedAnalysis",
    "SpiralBevelGearMeshCriticalSpeedAnalysis",
    "SpiralBevelGearSetCriticalSpeedAnalysis",
    "SpringDamperConnectionCriticalSpeedAnalysis",
    "SpringDamperCriticalSpeedAnalysis",
    "SpringDamperHalfCriticalSpeedAnalysis",
    "StraightBevelDiffGearCriticalSpeedAnalysis",
    "StraightBevelDiffGearMeshCriticalSpeedAnalysis",
    "StraightBevelDiffGearSetCriticalSpeedAnalysis",
    "StraightBevelGearCriticalSpeedAnalysis",
    "StraightBevelGearMeshCriticalSpeedAnalysis",
    "StraightBevelGearSetCriticalSpeedAnalysis",
    "StraightBevelPlanetGearCriticalSpeedAnalysis",
    "StraightBevelSunGearCriticalSpeedAnalysis",
    "SynchroniserCriticalSpeedAnalysis",
    "SynchroniserHalfCriticalSpeedAnalysis",
    "SynchroniserPartCriticalSpeedAnalysis",
    "SynchroniserSleeveCriticalSpeedAnalysis",
    "TorqueConverterConnectionCriticalSpeedAnalysis",
    "TorqueConverterCriticalSpeedAnalysis",
    "TorqueConverterPumpCriticalSpeedAnalysis",
    "TorqueConverterTurbineCriticalSpeedAnalysis",
    "UnbalancedMassCriticalSpeedAnalysis",
    "VirtualComponentCriticalSpeedAnalysis",
    "WormGearCriticalSpeedAnalysis",
    "WormGearMeshCriticalSpeedAnalysis",
    "WormGearSetCriticalSpeedAnalysis",
    "ZerolBevelGearCriticalSpeedAnalysis",
    "ZerolBevelGearMeshCriticalSpeedAnalysis",
    "ZerolBevelGearSetCriticalSpeedAnalysis",
)
