"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results._2702 import (
        CompoundAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2703 import SingleAnalysis
    from mastapy._private.system_model.analyses_and_results._2704 import (
        AdvancedSystemDeflectionAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2705 import (
        AdvancedSystemDeflectionSubAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2706 import (
        AdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results._2707 import (
        CompoundParametricStudyToolAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2708 import (
        CriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2709 import DynamicAnalysis
    from mastapy._private.system_model.analyses_and_results._2710 import (
        DynamicModelAtAStiffnessAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2711 import (
        DynamicModelForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2712 import (
        DynamicModelForModalAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2713 import (
        DynamicModelForStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2714 import (
        DynamicModelForSteadyStateSynchronousResponseAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2715 import (
        HarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2716 import (
        HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results._2717 import (
        HarmonicAnalysisOfSingleExcitationAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2718 import ModalAnalysis
    from mastapy._private.system_model.analyses_and_results._2719 import (
        ModalAnalysisAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results._2720 import (
        ModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results._2721 import (
        ModalAnalysisForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2722 import (
        MultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2723 import (
        ParametricStudyToolAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2724 import (
        PowerFlowAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2725 import (
        StabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2726 import (
        SteadyStateSynchronousResponseAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2727 import (
        SteadyStateSynchronousResponseAtASpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2728 import (
        SteadyStateSynchronousResponseOnAShaftAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2729 import (
        SystemDeflectionAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2730 import (
        TorsionalSystemDeflectionAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2731 import (
        AnalysisCaseVariable,
    )
    from mastapy._private.system_model.analyses_and_results._2732 import (
        ConnectionAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2733 import Context
    from mastapy._private.system_model.analyses_and_results._2734 import (
        DesignEntityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2735 import (
        DesignEntityGroupAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2736 import (
        DesignEntitySingleContextAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2740 import PartAnalysis
    from mastapy._private.system_model.analyses_and_results._2741 import (
        CompoundAdvancedSystemDeflectionAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2742 import (
        CompoundAdvancedSystemDeflectionSubAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2743 import (
        CompoundAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results._2744 import (
        CompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2745 import (
        CompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2746 import (
        CompoundDynamicModelAtAStiffnessAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2747 import (
        CompoundDynamicModelForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2748 import (
        CompoundDynamicModelForModalAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2749 import (
        CompoundDynamicModelForStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2750 import (
        CompoundDynamicModelForSteadyStateSynchronousResponseAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2751 import (
        CompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2752 import (
        CompoundHarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results._2753 import (
        CompoundHarmonicAnalysisOfSingleExcitationAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2754 import (
        CompoundModalAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2755 import (
        CompoundModalAnalysisAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results._2756 import (
        CompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results._2757 import (
        CompoundModalAnalysisForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2758 import (
        CompoundMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2759 import (
        CompoundPowerFlowAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2760 import (
        CompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2761 import (
        CompoundSteadyStateSynchronousResponseAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2762 import (
        CompoundSteadyStateSynchronousResponseAtASpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2763 import (
        CompoundSteadyStateSynchronousResponseOnAShaftAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2764 import (
        CompoundSystemDeflectionAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2765 import (
        CompoundTorsionalSystemDeflectionAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results._2766 import (
        TESetUpForDynamicAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results._2767 import TimeOptions
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results._2702": ["CompoundAnalysis"],
        "_private.system_model.analyses_and_results._2703": ["SingleAnalysis"],
        "_private.system_model.analyses_and_results._2704": [
            "AdvancedSystemDeflectionAnalysis"
        ],
        "_private.system_model.analyses_and_results._2705": [
            "AdvancedSystemDeflectionSubAnalysis"
        ],
        "_private.system_model.analyses_and_results._2706": [
            "AdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results._2707": [
            "CompoundParametricStudyToolAnalysis"
        ],
        "_private.system_model.analyses_and_results._2708": ["CriticalSpeedAnalysis"],
        "_private.system_model.analyses_and_results._2709": ["DynamicAnalysis"],
        "_private.system_model.analyses_and_results._2710": [
            "DynamicModelAtAStiffnessAnalysis"
        ],
        "_private.system_model.analyses_and_results._2711": [
            "DynamicModelForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results._2712": [
            "DynamicModelForModalAnalysis"
        ],
        "_private.system_model.analyses_and_results._2713": [
            "DynamicModelForStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results._2714": [
            "DynamicModelForSteadyStateSynchronousResponseAnalysis"
        ],
        "_private.system_model.analyses_and_results._2715": ["HarmonicAnalysis"],
        "_private.system_model.analyses_and_results._2716": [
            "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results._2717": [
            "HarmonicAnalysisOfSingleExcitationAnalysis"
        ],
        "_private.system_model.analyses_and_results._2718": ["ModalAnalysis"],
        "_private.system_model.analyses_and_results._2719": ["ModalAnalysisAtASpeed"],
        "_private.system_model.analyses_and_results._2720": [
            "ModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results._2721": [
            "ModalAnalysisForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results._2722": [
            "MultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results._2723": [
            "ParametricStudyToolAnalysis"
        ],
        "_private.system_model.analyses_and_results._2724": ["PowerFlowAnalysis"],
        "_private.system_model.analyses_and_results._2725": ["StabilityAnalysis"],
        "_private.system_model.analyses_and_results._2726": [
            "SteadyStateSynchronousResponseAnalysis"
        ],
        "_private.system_model.analyses_and_results._2727": [
            "SteadyStateSynchronousResponseAtASpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results._2728": [
            "SteadyStateSynchronousResponseOnAShaftAnalysis"
        ],
        "_private.system_model.analyses_and_results._2729": [
            "SystemDeflectionAnalysis"
        ],
        "_private.system_model.analyses_and_results._2730": [
            "TorsionalSystemDeflectionAnalysis"
        ],
        "_private.system_model.analyses_and_results._2731": ["AnalysisCaseVariable"],
        "_private.system_model.analyses_and_results._2732": ["ConnectionAnalysis"],
        "_private.system_model.analyses_and_results._2733": ["Context"],
        "_private.system_model.analyses_and_results._2734": ["DesignEntityAnalysis"],
        "_private.system_model.analyses_and_results._2735": [
            "DesignEntityGroupAnalysis"
        ],
        "_private.system_model.analyses_and_results._2736": [
            "DesignEntitySingleContextAnalysis"
        ],
        "_private.system_model.analyses_and_results._2740": ["PartAnalysis"],
        "_private.system_model.analyses_and_results._2741": [
            "CompoundAdvancedSystemDeflectionAnalysis"
        ],
        "_private.system_model.analyses_and_results._2742": [
            "CompoundAdvancedSystemDeflectionSubAnalysis"
        ],
        "_private.system_model.analyses_and_results._2743": [
            "CompoundAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results._2744": [
            "CompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results._2745": ["CompoundDynamicAnalysis"],
        "_private.system_model.analyses_and_results._2746": [
            "CompoundDynamicModelAtAStiffnessAnalysis"
        ],
        "_private.system_model.analyses_and_results._2747": [
            "CompoundDynamicModelForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results._2748": [
            "CompoundDynamicModelForModalAnalysis"
        ],
        "_private.system_model.analyses_and_results._2749": [
            "CompoundDynamicModelForStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results._2750": [
            "CompoundDynamicModelForSteadyStateSynchronousResponseAnalysis"
        ],
        "_private.system_model.analyses_and_results._2751": [
            "CompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results._2752": [
            "CompoundHarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results._2753": [
            "CompoundHarmonicAnalysisOfSingleExcitationAnalysis"
        ],
        "_private.system_model.analyses_and_results._2754": ["CompoundModalAnalysis"],
        "_private.system_model.analyses_and_results._2755": [
            "CompoundModalAnalysisAtASpeed"
        ],
        "_private.system_model.analyses_and_results._2756": [
            "CompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results._2757": [
            "CompoundModalAnalysisForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results._2758": [
            "CompoundMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results._2759": [
            "CompoundPowerFlowAnalysis"
        ],
        "_private.system_model.analyses_and_results._2760": [
            "CompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results._2761": [
            "CompoundSteadyStateSynchronousResponseAnalysis"
        ],
        "_private.system_model.analyses_and_results._2762": [
            "CompoundSteadyStateSynchronousResponseAtASpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results._2763": [
            "CompoundSteadyStateSynchronousResponseOnAShaftAnalysis"
        ],
        "_private.system_model.analyses_and_results._2764": [
            "CompoundSystemDeflectionAnalysis"
        ],
        "_private.system_model.analyses_and_results._2765": [
            "CompoundTorsionalSystemDeflectionAnalysis"
        ],
        "_private.system_model.analyses_and_results._2766": [
            "TESetUpForDynamicAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results._2767": ["TimeOptions"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "CompoundAnalysis",
    "SingleAnalysis",
    "AdvancedSystemDeflectionAnalysis",
    "AdvancedSystemDeflectionSubAnalysis",
    "AdvancedTimeSteppingAnalysisForModulation",
    "CompoundParametricStudyToolAnalysis",
    "CriticalSpeedAnalysis",
    "DynamicAnalysis",
    "DynamicModelAtAStiffnessAnalysis",
    "DynamicModelForHarmonicAnalysis",
    "DynamicModelForModalAnalysis",
    "DynamicModelForStabilityAnalysis",
    "DynamicModelForSteadyStateSynchronousResponseAnalysis",
    "HarmonicAnalysis",
    "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation",
    "HarmonicAnalysisOfSingleExcitationAnalysis",
    "ModalAnalysis",
    "ModalAnalysisAtASpeed",
    "ModalAnalysisAtAStiffness",
    "ModalAnalysisForHarmonicAnalysis",
    "MultibodyDynamicsAnalysis",
    "ParametricStudyToolAnalysis",
    "PowerFlowAnalysis",
    "StabilityAnalysis",
    "SteadyStateSynchronousResponseAnalysis",
    "SteadyStateSynchronousResponseAtASpeedAnalysis",
    "SteadyStateSynchronousResponseOnAShaftAnalysis",
    "SystemDeflectionAnalysis",
    "TorsionalSystemDeflectionAnalysis",
    "AnalysisCaseVariable",
    "ConnectionAnalysis",
    "Context",
    "DesignEntityAnalysis",
    "DesignEntityGroupAnalysis",
    "DesignEntitySingleContextAnalysis",
    "PartAnalysis",
    "CompoundAdvancedSystemDeflectionAnalysis",
    "CompoundAdvancedSystemDeflectionSubAnalysis",
    "CompoundAdvancedTimeSteppingAnalysisForModulation",
    "CompoundCriticalSpeedAnalysis",
    "CompoundDynamicAnalysis",
    "CompoundDynamicModelAtAStiffnessAnalysis",
    "CompoundDynamicModelForHarmonicAnalysis",
    "CompoundDynamicModelForModalAnalysis",
    "CompoundDynamicModelForStabilityAnalysis",
    "CompoundDynamicModelForSteadyStateSynchronousResponseAnalysis",
    "CompoundHarmonicAnalysis",
    "CompoundHarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation",
    "CompoundHarmonicAnalysisOfSingleExcitationAnalysis",
    "CompoundModalAnalysis",
    "CompoundModalAnalysisAtASpeed",
    "CompoundModalAnalysisAtAStiffness",
    "CompoundModalAnalysisForHarmonicAnalysis",
    "CompoundMultibodyDynamicsAnalysis",
    "CompoundPowerFlowAnalysis",
    "CompoundStabilityAnalysis",
    "CompoundSteadyStateSynchronousResponseAnalysis",
    "CompoundSteadyStateSynchronousResponseAtASpeedAnalysis",
    "CompoundSteadyStateSynchronousResponseOnAShaftAnalysis",
    "CompoundSystemDeflectionAnalysis",
    "CompoundTorsionalSystemDeflectionAnalysis",
    "TESetUpForDynamicAnalysisOptions",
    "TimeOptions",
)
