"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7422 import (
        AbstractAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7423 import (
        AbstractShaftAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7424 import (
        AbstractShaftOrHousingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7425 import (
        AbstractShaftToMountableComponentConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7426 import (
        AdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7427 import (
        AdvancedSystemDeflectionOptions,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7428 import (
        AdvancedSystemDeflectionSubAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7429 import (
        AGMAGleasonConicalGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7430 import (
        AGMAGleasonConicalGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7431 import (
        AGMAGleasonConicalGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7432 import (
        AssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7433 import (
        BearingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7434 import (
        BeltConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7435 import (
        BeltDriveAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7436 import (
        BevelDifferentialGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7437 import (
        BevelDifferentialGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7438 import (
        BevelDifferentialGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7439 import (
        BevelDifferentialPlanetGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7440 import (
        BevelDifferentialSunGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7441 import (
        BevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7442 import (
        BevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7443 import (
        BevelGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7444 import (
        BoltAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7445 import (
        BoltedJointAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7446 import (
        ClutchAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7447 import (
        ClutchConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7448 import (
        ClutchHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7449 import (
        CoaxialConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7450 import (
        ComponentAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7451 import (
        ConceptCouplingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7452 import (
        ConceptCouplingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7453 import (
        ConceptCouplingHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7454 import (
        ConceptGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7455 import (
        ConceptGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7456 import (
        ConceptGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7457 import (
        ConicalGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7458 import (
        ConicalGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7459 import (
        ConicalGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7460 import (
        ConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7461 import (
        ConnectorAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7462 import (
        ContactChartPerToothPass,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7463 import (
        CouplingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7464 import (
        CouplingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7465 import (
        CouplingHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7466 import (
        CVTAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7467 import (
        CVTBeltConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7468 import (
        CVTPulleyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7469 import (
        CycloidalAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7470 import (
        CycloidalDiscAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7471 import (
        CycloidalDiscCentralBearingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7472 import (
        CycloidalDiscPlanetaryBearingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7473 import (
        CylindricalGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7474 import (
        CylindricalGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7475 import (
        CylindricalGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7476 import (
        CylindricalMeshedGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7477 import (
        CylindricalPlanetGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7478 import (
        DatumAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7479 import (
        ExternalCADModelAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7480 import (
        FaceGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7481 import (
        FaceGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7482 import (
        FaceGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7483 import (
        FEPartAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7484 import (
        FlexiblePinAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7485 import (
        GearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7486 import (
        GearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7487 import (
        GearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7488 import (
        GuideDxfModelAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7489 import (
        HypoidGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7490 import (
        HypoidGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7491 import (
        HypoidGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7492 import (
        InterMountableComponentConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7493 import (
        KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7494 import (
        KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7495 import (
        KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7496 import (
        KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7497 import (
        KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7498 import (
        KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7499 import (
        KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7500 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7501 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7502 import (
        UseLtcaInAsdOption,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7503 import (
        MassDiscAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7504 import (
        MeasurementComponentAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7505 import (
        MicrophoneAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7506 import (
        MicrophoneArrayAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7507 import (
        MountableComponentAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7508 import (
        OilSealAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7509 import (
        PartAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7510 import (
        PartToPartShearCouplingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7511 import (
        PartToPartShearCouplingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7512 import (
        PartToPartShearCouplingHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7513 import (
        PlanetaryConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7514 import (
        PlanetaryGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7515 import (
        PlanetCarrierAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7516 import (
        PointLoadAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7517 import (
        PowerLoadAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7518 import (
        PulleyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7519 import (
        RingPinsAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7520 import (
        RingPinsToDiscConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7521 import (
        RollingRingAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7522 import (
        RollingRingAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7523 import (
        RollingRingConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7524 import (
        RootAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7525 import (
        ShaftAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7526 import (
        ShaftHubConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7527 import (
        ShaftToMountableComponentConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7528 import (
        SpecialisedAssemblyAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7529 import (
        SpiralBevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7530 import (
        SpiralBevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7531 import (
        SpiralBevelGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7532 import (
        SpringDamperAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7533 import (
        SpringDamperConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7534 import (
        SpringDamperHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7535 import (
        StraightBevelDiffGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7536 import (
        StraightBevelDiffGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7537 import (
        StraightBevelDiffGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7538 import (
        StraightBevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7539 import (
        StraightBevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7540 import (
        StraightBevelGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7541 import (
        StraightBevelPlanetGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7542 import (
        StraightBevelSunGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7543 import (
        SynchroniserAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7544 import (
        SynchroniserHalfAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7545 import (
        SynchroniserPartAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7546 import (
        SynchroniserSleeveAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7547 import (
        TorqueConverterAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7548 import (
        TorqueConverterConnectionAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7549 import (
        TorqueConverterPumpAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7550 import (
        TorqueConverterTurbineAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7551 import (
        TransmissionErrorToOtherPowerLoad,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7552 import (
        UnbalancedMassAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7553 import (
        VirtualComponentAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7554 import (
        WormGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7555 import (
        WormGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7556 import (
        WormGearSetAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7557 import (
        ZerolBevelGearAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7558 import (
        ZerolBevelGearMeshAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections._7559 import (
        ZerolBevelGearSetAdvancedSystemDeflection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.advanced_system_deflections._7422": [
            "AbstractAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7423": [
            "AbstractShaftAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7424": [
            "AbstractShaftOrHousingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7425": [
            "AbstractShaftToMountableComponentConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7426": [
            "AdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7427": [
            "AdvancedSystemDeflectionOptions"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7428": [
            "AdvancedSystemDeflectionSubAnalysis"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7429": [
            "AGMAGleasonConicalGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7430": [
            "AGMAGleasonConicalGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7431": [
            "AGMAGleasonConicalGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7432": [
            "AssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7433": [
            "BearingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7434": [
            "BeltConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7435": [
            "BeltDriveAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7436": [
            "BevelDifferentialGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7437": [
            "BevelDifferentialGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7438": [
            "BevelDifferentialGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7439": [
            "BevelDifferentialPlanetGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7440": [
            "BevelDifferentialSunGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7441": [
            "BevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7442": [
            "BevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7443": [
            "BevelGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7444": [
            "BoltAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7445": [
            "BoltedJointAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7446": [
            "ClutchAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7447": [
            "ClutchConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7448": [
            "ClutchHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7449": [
            "CoaxialConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7450": [
            "ComponentAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7451": [
            "ConceptCouplingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7452": [
            "ConceptCouplingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7453": [
            "ConceptCouplingHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7454": [
            "ConceptGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7455": [
            "ConceptGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7456": [
            "ConceptGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7457": [
            "ConicalGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7458": [
            "ConicalGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7459": [
            "ConicalGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7460": [
            "ConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7461": [
            "ConnectorAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7462": [
            "ContactChartPerToothPass"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7463": [
            "CouplingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7464": [
            "CouplingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7465": [
            "CouplingHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7466": [
            "CVTAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7467": [
            "CVTBeltConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7468": [
            "CVTPulleyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7469": [
            "CycloidalAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7470": [
            "CycloidalDiscAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7471": [
            "CycloidalDiscCentralBearingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7472": [
            "CycloidalDiscPlanetaryBearingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7473": [
            "CylindricalGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7474": [
            "CylindricalGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7475": [
            "CylindricalGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7476": [
            "CylindricalMeshedGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7477": [
            "CylindricalPlanetGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7478": [
            "DatumAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7479": [
            "ExternalCADModelAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7480": [
            "FaceGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7481": [
            "FaceGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7482": [
            "FaceGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7483": [
            "FEPartAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7484": [
            "FlexiblePinAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7485": [
            "GearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7486": [
            "GearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7487": [
            "GearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7488": [
            "GuideDxfModelAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7489": [
            "HypoidGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7490": [
            "HypoidGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7491": [
            "HypoidGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7492": [
            "InterMountableComponentConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7493": [
            "KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7494": [
            "KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7495": [
            "KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7496": [
            "KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7497": [
            "KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7498": [
            "KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7499": [
            "KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7500": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7501": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7502": [
            "UseLtcaInAsdOption"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7503": [
            "MassDiscAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7504": [
            "MeasurementComponentAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7505": [
            "MicrophoneAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7506": [
            "MicrophoneArrayAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7507": [
            "MountableComponentAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7508": [
            "OilSealAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7509": [
            "PartAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7510": [
            "PartToPartShearCouplingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7511": [
            "PartToPartShearCouplingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7512": [
            "PartToPartShearCouplingHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7513": [
            "PlanetaryConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7514": [
            "PlanetaryGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7515": [
            "PlanetCarrierAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7516": [
            "PointLoadAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7517": [
            "PowerLoadAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7518": [
            "PulleyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7519": [
            "RingPinsAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7520": [
            "RingPinsToDiscConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7521": [
            "RollingRingAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7522": [
            "RollingRingAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7523": [
            "RollingRingConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7524": [
            "RootAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7525": [
            "ShaftAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7526": [
            "ShaftHubConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7527": [
            "ShaftToMountableComponentConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7528": [
            "SpecialisedAssemblyAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7529": [
            "SpiralBevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7530": [
            "SpiralBevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7531": [
            "SpiralBevelGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7532": [
            "SpringDamperAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7533": [
            "SpringDamperConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7534": [
            "SpringDamperHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7535": [
            "StraightBevelDiffGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7536": [
            "StraightBevelDiffGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7537": [
            "StraightBevelDiffGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7538": [
            "StraightBevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7539": [
            "StraightBevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7540": [
            "StraightBevelGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7541": [
            "StraightBevelPlanetGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7542": [
            "StraightBevelSunGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7543": [
            "SynchroniserAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7544": [
            "SynchroniserHalfAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7545": [
            "SynchroniserPartAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7546": [
            "SynchroniserSleeveAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7547": [
            "TorqueConverterAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7548": [
            "TorqueConverterConnectionAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7549": [
            "TorqueConverterPumpAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7550": [
            "TorqueConverterTurbineAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7551": [
            "TransmissionErrorToOtherPowerLoad"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7552": [
            "UnbalancedMassAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7553": [
            "VirtualComponentAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7554": [
            "WormGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7555": [
            "WormGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7556": [
            "WormGearSetAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7557": [
            "ZerolBevelGearAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7558": [
            "ZerolBevelGearMeshAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections._7559": [
            "ZerolBevelGearSetAdvancedSystemDeflection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyAdvancedSystemDeflection",
    "AbstractShaftAdvancedSystemDeflection",
    "AbstractShaftOrHousingAdvancedSystemDeflection",
    "AbstractShaftToMountableComponentConnectionAdvancedSystemDeflection",
    "AdvancedSystemDeflection",
    "AdvancedSystemDeflectionOptions",
    "AdvancedSystemDeflectionSubAnalysis",
    "AGMAGleasonConicalGearAdvancedSystemDeflection",
    "AGMAGleasonConicalGearMeshAdvancedSystemDeflection",
    "AGMAGleasonConicalGearSetAdvancedSystemDeflection",
    "AssemblyAdvancedSystemDeflection",
    "BearingAdvancedSystemDeflection",
    "BeltConnectionAdvancedSystemDeflection",
    "BeltDriveAdvancedSystemDeflection",
    "BevelDifferentialGearAdvancedSystemDeflection",
    "BevelDifferentialGearMeshAdvancedSystemDeflection",
    "BevelDifferentialGearSetAdvancedSystemDeflection",
    "BevelDifferentialPlanetGearAdvancedSystemDeflection",
    "BevelDifferentialSunGearAdvancedSystemDeflection",
    "BevelGearAdvancedSystemDeflection",
    "BevelGearMeshAdvancedSystemDeflection",
    "BevelGearSetAdvancedSystemDeflection",
    "BoltAdvancedSystemDeflection",
    "BoltedJointAdvancedSystemDeflection",
    "ClutchAdvancedSystemDeflection",
    "ClutchConnectionAdvancedSystemDeflection",
    "ClutchHalfAdvancedSystemDeflection",
    "CoaxialConnectionAdvancedSystemDeflection",
    "ComponentAdvancedSystemDeflection",
    "ConceptCouplingAdvancedSystemDeflection",
    "ConceptCouplingConnectionAdvancedSystemDeflection",
    "ConceptCouplingHalfAdvancedSystemDeflection",
    "ConceptGearAdvancedSystemDeflection",
    "ConceptGearMeshAdvancedSystemDeflection",
    "ConceptGearSetAdvancedSystemDeflection",
    "ConicalGearAdvancedSystemDeflection",
    "ConicalGearMeshAdvancedSystemDeflection",
    "ConicalGearSetAdvancedSystemDeflection",
    "ConnectionAdvancedSystemDeflection",
    "ConnectorAdvancedSystemDeflection",
    "ContactChartPerToothPass",
    "CouplingAdvancedSystemDeflection",
    "CouplingConnectionAdvancedSystemDeflection",
    "CouplingHalfAdvancedSystemDeflection",
    "CVTAdvancedSystemDeflection",
    "CVTBeltConnectionAdvancedSystemDeflection",
    "CVTPulleyAdvancedSystemDeflection",
    "CycloidalAssemblyAdvancedSystemDeflection",
    "CycloidalDiscAdvancedSystemDeflection",
    "CycloidalDiscCentralBearingConnectionAdvancedSystemDeflection",
    "CycloidalDiscPlanetaryBearingConnectionAdvancedSystemDeflection",
    "CylindricalGearAdvancedSystemDeflection",
    "CylindricalGearMeshAdvancedSystemDeflection",
    "CylindricalGearSetAdvancedSystemDeflection",
    "CylindricalMeshedGearAdvancedSystemDeflection",
    "CylindricalPlanetGearAdvancedSystemDeflection",
    "DatumAdvancedSystemDeflection",
    "ExternalCADModelAdvancedSystemDeflection",
    "FaceGearAdvancedSystemDeflection",
    "FaceGearMeshAdvancedSystemDeflection",
    "FaceGearSetAdvancedSystemDeflection",
    "FEPartAdvancedSystemDeflection",
    "FlexiblePinAssemblyAdvancedSystemDeflection",
    "GearAdvancedSystemDeflection",
    "GearMeshAdvancedSystemDeflection",
    "GearSetAdvancedSystemDeflection",
    "GuideDxfModelAdvancedSystemDeflection",
    "HypoidGearAdvancedSystemDeflection",
    "HypoidGearMeshAdvancedSystemDeflection",
    "HypoidGearSetAdvancedSystemDeflection",
    "InterMountableComponentConnectionAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection",
    "UseLtcaInAsdOption",
    "MassDiscAdvancedSystemDeflection",
    "MeasurementComponentAdvancedSystemDeflection",
    "MicrophoneAdvancedSystemDeflection",
    "MicrophoneArrayAdvancedSystemDeflection",
    "MountableComponentAdvancedSystemDeflection",
    "OilSealAdvancedSystemDeflection",
    "PartAdvancedSystemDeflection",
    "PartToPartShearCouplingAdvancedSystemDeflection",
    "PartToPartShearCouplingConnectionAdvancedSystemDeflection",
    "PartToPartShearCouplingHalfAdvancedSystemDeflection",
    "PlanetaryConnectionAdvancedSystemDeflection",
    "PlanetaryGearSetAdvancedSystemDeflection",
    "PlanetCarrierAdvancedSystemDeflection",
    "PointLoadAdvancedSystemDeflection",
    "PowerLoadAdvancedSystemDeflection",
    "PulleyAdvancedSystemDeflection",
    "RingPinsAdvancedSystemDeflection",
    "RingPinsToDiscConnectionAdvancedSystemDeflection",
    "RollingRingAdvancedSystemDeflection",
    "RollingRingAssemblyAdvancedSystemDeflection",
    "RollingRingConnectionAdvancedSystemDeflection",
    "RootAssemblyAdvancedSystemDeflection",
    "ShaftAdvancedSystemDeflection",
    "ShaftHubConnectionAdvancedSystemDeflection",
    "ShaftToMountableComponentConnectionAdvancedSystemDeflection",
    "SpecialisedAssemblyAdvancedSystemDeflection",
    "SpiralBevelGearAdvancedSystemDeflection",
    "SpiralBevelGearMeshAdvancedSystemDeflection",
    "SpiralBevelGearSetAdvancedSystemDeflection",
    "SpringDamperAdvancedSystemDeflection",
    "SpringDamperConnectionAdvancedSystemDeflection",
    "SpringDamperHalfAdvancedSystemDeflection",
    "StraightBevelDiffGearAdvancedSystemDeflection",
    "StraightBevelDiffGearMeshAdvancedSystemDeflection",
    "StraightBevelDiffGearSetAdvancedSystemDeflection",
    "StraightBevelGearAdvancedSystemDeflection",
    "StraightBevelGearMeshAdvancedSystemDeflection",
    "StraightBevelGearSetAdvancedSystemDeflection",
    "StraightBevelPlanetGearAdvancedSystemDeflection",
    "StraightBevelSunGearAdvancedSystemDeflection",
    "SynchroniserAdvancedSystemDeflection",
    "SynchroniserHalfAdvancedSystemDeflection",
    "SynchroniserPartAdvancedSystemDeflection",
    "SynchroniserSleeveAdvancedSystemDeflection",
    "TorqueConverterAdvancedSystemDeflection",
    "TorqueConverterConnectionAdvancedSystemDeflection",
    "TorqueConverterPumpAdvancedSystemDeflection",
    "TorqueConverterTurbineAdvancedSystemDeflection",
    "TransmissionErrorToOtherPowerLoad",
    "UnbalancedMassAdvancedSystemDeflection",
    "VirtualComponentAdvancedSystemDeflection",
    "WormGearAdvancedSystemDeflection",
    "WormGearMeshAdvancedSystemDeflection",
    "WormGearSetAdvancedSystemDeflection",
    "ZerolBevelGearAdvancedSystemDeflection",
    "ZerolBevelGearMeshAdvancedSystemDeflection",
    "ZerolBevelGearSetAdvancedSystemDeflection",
)
