"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._772 import (
        ActiveProfileRangeCalculationSource,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._773 import (
        AxialShaverRedressing,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._774 import (
        ConventionalShavingDynamics,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._775 import (
        ConventionalShavingDynamicsCalculationForDesignedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._776 import (
        ConventionalShavingDynamicsCalculationForHobbedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._777 import (
        ConventionalShavingDynamicsViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._778 import (
        PlungeShaverDynamics,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._779 import (
        PlungeShaverDynamicSettings,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._780 import (
        PlungeShaverRedressing,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._781 import (
        PlungeShavingDynamicsCalculationForDesignedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._782 import (
        PlungeShavingDynamicsCalculationForHobbedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._783 import (
        PlungeShavingDynamicsViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._784 import (
        RedressingSettings,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._785 import (
        RollAngleRangeRelativeToAccuracy,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._786 import (
        RollAngleReportObject,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._787 import (
        ShaverRedressing,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._788 import (
        ShavingDynamics,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._789 import (
        ShavingDynamicsCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._790 import (
        ShavingDynamicsCalculationForDesignedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._791 import (
        ShavingDynamicsCalculationForHobbedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._792 import (
        ShavingDynamicsConfiguration,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._793 import (
        ShavingDynamicsViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._794 import (
        ShavingDynamicsViewModelBase,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._772": [
            "ActiveProfileRangeCalculationSource"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._773": [
            "AxialShaverRedressing"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._774": [
            "ConventionalShavingDynamics"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._775": [
            "ConventionalShavingDynamicsCalculationForDesignedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._776": [
            "ConventionalShavingDynamicsCalculationForHobbedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._777": [
            "ConventionalShavingDynamicsViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._778": [
            "PlungeShaverDynamics"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._779": [
            "PlungeShaverDynamicSettings"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._780": [
            "PlungeShaverRedressing"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._781": [
            "PlungeShavingDynamicsCalculationForDesignedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._782": [
            "PlungeShavingDynamicsCalculationForHobbedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._783": [
            "PlungeShavingDynamicsViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._784": [
            "RedressingSettings"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._785": [
            "RollAngleRangeRelativeToAccuracy"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._786": [
            "RollAngleReportObject"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._787": [
            "ShaverRedressing"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._788": [
            "ShavingDynamics"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._789": [
            "ShavingDynamicsCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._790": [
            "ShavingDynamicsCalculationForDesignedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._791": [
            "ShavingDynamicsCalculationForHobbedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._792": [
            "ShavingDynamicsConfiguration"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._793": [
            "ShavingDynamicsViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._794": [
            "ShavingDynamicsViewModelBase"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "ActiveProfileRangeCalculationSource",
    "AxialShaverRedressing",
    "ConventionalShavingDynamics",
    "ConventionalShavingDynamicsCalculationForDesignedGears",
    "ConventionalShavingDynamicsCalculationForHobbedGears",
    "ConventionalShavingDynamicsViewModel",
    "PlungeShaverDynamics",
    "PlungeShaverDynamicSettings",
    "PlungeShaverRedressing",
    "PlungeShavingDynamicsCalculationForDesignedGears",
    "PlungeShavingDynamicsCalculationForHobbedGears",
    "PlungeShavingDynamicsViewModel",
    "RedressingSettings",
    "RollAngleRangeRelativeToAccuracy",
    "RollAngleReportObject",
    "ShaverRedressing",
    "ShavingDynamics",
    "ShavingDynamicsCalculation",
    "ShavingDynamicsCalculationForDesignedGears",
    "ShavingDynamicsCalculationForHobbedGears",
    "ShavingDynamicsConfiguration",
    "ShavingDynamicsViewModel",
    "ShavingDynamicsViewModelBase",
)
