"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.gears.gear_designs.cylindrical._1022 import (
        AddendumModificationDistributionRule,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1023 import (
        BacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1024 import BasicRackProfiles
    from mastapy._private.gears.gear_designs.cylindrical._1025 import (
        CaseHardeningProperties,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1026 import (
        CreateNewSuitableCutterOption,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1027 import (
        CrossedAxisCylindricalGearPair,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1028 import (
        CrossedAxisCylindricalGearPairLineContact,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1029 import (
        CrossedAxisCylindricalGearPairPointContact,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1030 import (
        Customer102DataSheetChangeLog,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1031 import (
        Customer102DataSheetChangeLogItem,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1032 import (
        Customer102DataSheetNote,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1033 import (
        Customer102DataSheetNotes,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1034 import (
        Customer102DataSheetTolerances,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1035 import (
        Customer102ToleranceDefinition,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1036 import (
        CylindricalGearAbstractRack,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1037 import (
        CylindricalGearAbstractRackFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1038 import (
        CylindricalGearBasicRack,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1039 import (
        CylindricalGearBasicRackFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1040 import (
        CylindricalGearCuttingOptions,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1041 import (
        CylindricalGearDefaults,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1042 import (
        CylindricalGearDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1043 import (
        CylindricalGearDesignConstraint,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1044 import (
        CylindricalGearDesignConstraints,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1045 import (
        CylindricalGearDesignConstraintsDatabase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1046 import (
        CylindricalGearDesignConstraintSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1047 import (
        CylindricalGearFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1048 import (
        CylindricalGearMeshDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1049 import (
        CylindricalGearMeshFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1050 import (
        CylindricalGearMicroGeometrySettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1051 import (
        CylindricalGearMicroGeometrySettingsDatabase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1052 import (
        CylindricalGearMicroGeometrySettingsItem,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1053 import (
        CylindricalGearPinionTypeCutter,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1054 import (
        CylindricalGearPinionTypeCutterFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1055 import (
        CylindricalGearProfileMeasurement,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1056 import (
        CylindricalGearProfileMeasurementType,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1057 import (
        CylindricalGearProfileModifications,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1058 import (
        CylindricalGearSetDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1059 import (
        CylindricalGearSetFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1060 import (
        CylindricalGearSetMacroGeometryOptimiser,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1061 import (
        CylindricalGearSetManufacturingConfigurationSelection,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1062 import (
        CylindricalGearSetMicroGeometrySettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1063 import (
        CylindricalGearSetOptimisationWrapper,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1064 import (
        CylindricalGearTableMGItemDetail,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1065 import (
        CylindricalGearTableWithMGCharts,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1066 import (
        CylindricalGearToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1067 import (
        CylindricalMeshAngularBacklash,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1068 import (
        CylindricalMeshedGear,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1069 import (
        CylindricalMeshedGearFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1070 import (
        CylindricalMeshLinearBacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1071 import (
        CylindricalPlanetaryGearSetDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1072 import (
        CylindricalPlanetGearDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1073 import (
        DIN3967AllowanceSeries,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1074 import (
        DIN3967ToleranceSeries,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1075 import (
        DoubleAxisScaleAndRange,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1076 import (
        FinishToothThicknessDesignSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1077 import GearFitSystems
    from mastapy._private.gears.gear_designs.cylindrical._1078 import (
        GearManufacturingConfigSetupViewModel,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1079 import (
        GearSetManufacturingConfigurationSetup,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1080 import (
        GeometrySpecificationType,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1081 import (
        HardenedMaterialProperties,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1082 import (
        HardnessProfileCalculationMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1083 import HeatTreatmentType
    from mastapy._private.gears.gear_designs.cylindrical._1084 import ISO6336Geometry
    from mastapy._private.gears.gear_designs.cylindrical._1085 import (
        ISO6336GeometryBase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1086 import (
        ISO6336GeometryForShapedGears,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1087 import (
        ISO6336GeometryManufactured,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1088 import (
        LinearBacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1089 import (
        LTCALoadCaseModifiableSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1090 import LTCASettings
    from mastapy._private.gears.gear_designs.cylindrical._1091 import (
        MicroGeometryConvention,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1092 import (
        MicroGeometryProfileConvention,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1093 import Micropitting
    from mastapy._private.gears.gear_designs.cylindrical._1094 import (
        MullerResidualStressDefinition,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1095 import (
        NamedPlanetAssemblyIndex,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1096 import (
        NamedPlanetSideBandAmplitudeFactor,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1097 import (
        ReadonlyToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1098 import (
        RelativeMeasurementViewModel,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1099 import (
        RelativeValuesSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1100 import (
        ResidualStressCalculationMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1101 import (
        RootStressSurfaceChartOption,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1102 import Scuffing
    from mastapy._private.gears.gear_designs.cylindrical._1103 import (
        ScuffingCoefficientOfFrictionMethods,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1104 import (
        ScuffingTemperatureMethodsAGMA,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1105 import (
        ScuffingTemperatureMethodsISO,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1106 import ShaperEdgeTypes
    from mastapy._private.gears.gear_designs.cylindrical._1107 import (
        SpurGearLoadSharingCodes,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1108 import StandardRack
    from mastapy._private.gears.gear_designs.cylindrical._1109 import StandardRackFlank
    from mastapy._private.gears.gear_designs.cylindrical._1110 import SurfaceRoughness
    from mastapy._private.gears.gear_designs.cylindrical._1111 import ThicknessType
    from mastapy._private.gears.gear_designs.cylindrical._1112 import (
        TiffAnalysisSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1113 import (
        TipAlterationCoefficientMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1114 import (
        TolerancedMetalMeasurements,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1115 import (
        TolerancedValueSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1116 import (
        ToothFlankFractureAnalysisSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1117 import (
        ToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1118 import (
        ToothThicknessSpecificationBase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1119 import (
        TypeOfMechanismHousing,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1120 import Usage
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_designs.cylindrical._1022": [
            "AddendumModificationDistributionRule"
        ],
        "_private.gears.gear_designs.cylindrical._1023": ["BacklashSpecification"],
        "_private.gears.gear_designs.cylindrical._1024": ["BasicRackProfiles"],
        "_private.gears.gear_designs.cylindrical._1025": ["CaseHardeningProperties"],
        "_private.gears.gear_designs.cylindrical._1026": [
            "CreateNewSuitableCutterOption"
        ],
        "_private.gears.gear_designs.cylindrical._1027": [
            "CrossedAxisCylindricalGearPair"
        ],
        "_private.gears.gear_designs.cylindrical._1028": [
            "CrossedAxisCylindricalGearPairLineContact"
        ],
        "_private.gears.gear_designs.cylindrical._1029": [
            "CrossedAxisCylindricalGearPairPointContact"
        ],
        "_private.gears.gear_designs.cylindrical._1030": [
            "Customer102DataSheetChangeLog"
        ],
        "_private.gears.gear_designs.cylindrical._1031": [
            "Customer102DataSheetChangeLogItem"
        ],
        "_private.gears.gear_designs.cylindrical._1032": ["Customer102DataSheetNote"],
        "_private.gears.gear_designs.cylindrical._1033": ["Customer102DataSheetNotes"],
        "_private.gears.gear_designs.cylindrical._1034": [
            "Customer102DataSheetTolerances"
        ],
        "_private.gears.gear_designs.cylindrical._1035": [
            "Customer102ToleranceDefinition"
        ],
        "_private.gears.gear_designs.cylindrical._1036": [
            "CylindricalGearAbstractRack"
        ],
        "_private.gears.gear_designs.cylindrical._1037": [
            "CylindricalGearAbstractRackFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1038": ["CylindricalGearBasicRack"],
        "_private.gears.gear_designs.cylindrical._1039": [
            "CylindricalGearBasicRackFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1040": [
            "CylindricalGearCuttingOptions"
        ],
        "_private.gears.gear_designs.cylindrical._1041": ["CylindricalGearDefaults"],
        "_private.gears.gear_designs.cylindrical._1042": ["CylindricalGearDesign"],
        "_private.gears.gear_designs.cylindrical._1043": [
            "CylindricalGearDesignConstraint"
        ],
        "_private.gears.gear_designs.cylindrical._1044": [
            "CylindricalGearDesignConstraints"
        ],
        "_private.gears.gear_designs.cylindrical._1045": [
            "CylindricalGearDesignConstraintsDatabase"
        ],
        "_private.gears.gear_designs.cylindrical._1046": [
            "CylindricalGearDesignConstraintSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1047": ["CylindricalGearFlankDesign"],
        "_private.gears.gear_designs.cylindrical._1048": ["CylindricalGearMeshDesign"],
        "_private.gears.gear_designs.cylindrical._1049": [
            "CylindricalGearMeshFlankDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1050": [
            "CylindricalGearMicroGeometrySettings"
        ],
        "_private.gears.gear_designs.cylindrical._1051": [
            "CylindricalGearMicroGeometrySettingsDatabase"
        ],
        "_private.gears.gear_designs.cylindrical._1052": [
            "CylindricalGearMicroGeometrySettingsItem"
        ],
        "_private.gears.gear_designs.cylindrical._1053": [
            "CylindricalGearPinionTypeCutter"
        ],
        "_private.gears.gear_designs.cylindrical._1054": [
            "CylindricalGearPinionTypeCutterFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1055": [
            "CylindricalGearProfileMeasurement"
        ],
        "_private.gears.gear_designs.cylindrical._1056": [
            "CylindricalGearProfileMeasurementType"
        ],
        "_private.gears.gear_designs.cylindrical._1057": [
            "CylindricalGearProfileModifications"
        ],
        "_private.gears.gear_designs.cylindrical._1058": ["CylindricalGearSetDesign"],
        "_private.gears.gear_designs.cylindrical._1059": [
            "CylindricalGearSetFlankDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1060": [
            "CylindricalGearSetMacroGeometryOptimiser"
        ],
        "_private.gears.gear_designs.cylindrical._1061": [
            "CylindricalGearSetManufacturingConfigurationSelection"
        ],
        "_private.gears.gear_designs.cylindrical._1062": [
            "CylindricalGearSetMicroGeometrySettings"
        ],
        "_private.gears.gear_designs.cylindrical._1063": [
            "CylindricalGearSetOptimisationWrapper"
        ],
        "_private.gears.gear_designs.cylindrical._1064": [
            "CylindricalGearTableMGItemDetail"
        ],
        "_private.gears.gear_designs.cylindrical._1065": [
            "CylindricalGearTableWithMGCharts"
        ],
        "_private.gears.gear_designs.cylindrical._1066": [
            "CylindricalGearToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1067": [
            "CylindricalMeshAngularBacklash"
        ],
        "_private.gears.gear_designs.cylindrical._1068": ["CylindricalMeshedGear"],
        "_private.gears.gear_designs.cylindrical._1069": ["CylindricalMeshedGearFlank"],
        "_private.gears.gear_designs.cylindrical._1070": [
            "CylindricalMeshLinearBacklashSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1071": [
            "CylindricalPlanetaryGearSetDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1072": [
            "CylindricalPlanetGearDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1073": ["DIN3967AllowanceSeries"],
        "_private.gears.gear_designs.cylindrical._1074": ["DIN3967ToleranceSeries"],
        "_private.gears.gear_designs.cylindrical._1075": ["DoubleAxisScaleAndRange"],
        "_private.gears.gear_designs.cylindrical._1076": [
            "FinishToothThicknessDesignSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1077": ["GearFitSystems"],
        "_private.gears.gear_designs.cylindrical._1078": [
            "GearManufacturingConfigSetupViewModel"
        ],
        "_private.gears.gear_designs.cylindrical._1079": [
            "GearSetManufacturingConfigurationSetup"
        ],
        "_private.gears.gear_designs.cylindrical._1080": ["GeometrySpecificationType"],
        "_private.gears.gear_designs.cylindrical._1081": ["HardenedMaterialProperties"],
        "_private.gears.gear_designs.cylindrical._1082": [
            "HardnessProfileCalculationMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1083": ["HeatTreatmentType"],
        "_private.gears.gear_designs.cylindrical._1084": ["ISO6336Geometry"],
        "_private.gears.gear_designs.cylindrical._1085": ["ISO6336GeometryBase"],
        "_private.gears.gear_designs.cylindrical._1086": [
            "ISO6336GeometryForShapedGears"
        ],
        "_private.gears.gear_designs.cylindrical._1087": [
            "ISO6336GeometryManufactured"
        ],
        "_private.gears.gear_designs.cylindrical._1088": [
            "LinearBacklashSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1089": [
            "LTCALoadCaseModifiableSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1090": ["LTCASettings"],
        "_private.gears.gear_designs.cylindrical._1091": ["MicroGeometryConvention"],
        "_private.gears.gear_designs.cylindrical._1092": [
            "MicroGeometryProfileConvention"
        ],
        "_private.gears.gear_designs.cylindrical._1093": ["Micropitting"],
        "_private.gears.gear_designs.cylindrical._1094": [
            "MullerResidualStressDefinition"
        ],
        "_private.gears.gear_designs.cylindrical._1095": ["NamedPlanetAssemblyIndex"],
        "_private.gears.gear_designs.cylindrical._1096": [
            "NamedPlanetSideBandAmplitudeFactor"
        ],
        "_private.gears.gear_designs.cylindrical._1097": [
            "ReadonlyToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1098": [
            "RelativeMeasurementViewModel"
        ],
        "_private.gears.gear_designs.cylindrical._1099": [
            "RelativeValuesSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1100": [
            "ResidualStressCalculationMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1101": [
            "RootStressSurfaceChartOption"
        ],
        "_private.gears.gear_designs.cylindrical._1102": ["Scuffing"],
        "_private.gears.gear_designs.cylindrical._1103": [
            "ScuffingCoefficientOfFrictionMethods"
        ],
        "_private.gears.gear_designs.cylindrical._1104": [
            "ScuffingTemperatureMethodsAGMA"
        ],
        "_private.gears.gear_designs.cylindrical._1105": [
            "ScuffingTemperatureMethodsISO"
        ],
        "_private.gears.gear_designs.cylindrical._1106": ["ShaperEdgeTypes"],
        "_private.gears.gear_designs.cylindrical._1107": ["SpurGearLoadSharingCodes"],
        "_private.gears.gear_designs.cylindrical._1108": ["StandardRack"],
        "_private.gears.gear_designs.cylindrical._1109": ["StandardRackFlank"],
        "_private.gears.gear_designs.cylindrical._1110": ["SurfaceRoughness"],
        "_private.gears.gear_designs.cylindrical._1111": ["ThicknessType"],
        "_private.gears.gear_designs.cylindrical._1112": ["TiffAnalysisSettings"],
        "_private.gears.gear_designs.cylindrical._1113": [
            "TipAlterationCoefficientMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1114": [
            "TolerancedMetalMeasurements"
        ],
        "_private.gears.gear_designs.cylindrical._1115": [
            "TolerancedValueSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1116": [
            "ToothFlankFractureAnalysisSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1117": [
            "ToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1118": [
            "ToothThicknessSpecificationBase"
        ],
        "_private.gears.gear_designs.cylindrical._1119": ["TypeOfMechanismHousing"],
        "_private.gears.gear_designs.cylindrical._1120": ["Usage"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AddendumModificationDistributionRule",
    "BacklashSpecification",
    "BasicRackProfiles",
    "CaseHardeningProperties",
    "CreateNewSuitableCutterOption",
    "CrossedAxisCylindricalGearPair",
    "CrossedAxisCylindricalGearPairLineContact",
    "CrossedAxisCylindricalGearPairPointContact",
    "Customer102DataSheetChangeLog",
    "Customer102DataSheetChangeLogItem",
    "Customer102DataSheetNote",
    "Customer102DataSheetNotes",
    "Customer102DataSheetTolerances",
    "Customer102ToleranceDefinition",
    "CylindricalGearAbstractRack",
    "CylindricalGearAbstractRackFlank",
    "CylindricalGearBasicRack",
    "CylindricalGearBasicRackFlank",
    "CylindricalGearCuttingOptions",
    "CylindricalGearDefaults",
    "CylindricalGearDesign",
    "CylindricalGearDesignConstraint",
    "CylindricalGearDesignConstraints",
    "CylindricalGearDesignConstraintsDatabase",
    "CylindricalGearDesignConstraintSettings",
    "CylindricalGearFlankDesign",
    "CylindricalGearMeshDesign",
    "CylindricalGearMeshFlankDesign",
    "CylindricalGearMicroGeometrySettings",
    "CylindricalGearMicroGeometrySettingsDatabase",
    "CylindricalGearMicroGeometrySettingsItem",
    "CylindricalGearPinionTypeCutter",
    "CylindricalGearPinionTypeCutterFlank",
    "CylindricalGearProfileMeasurement",
    "CylindricalGearProfileMeasurementType",
    "CylindricalGearProfileModifications",
    "CylindricalGearSetDesign",
    "CylindricalGearSetFlankDesign",
    "CylindricalGearSetMacroGeometryOptimiser",
    "CylindricalGearSetManufacturingConfigurationSelection",
    "CylindricalGearSetMicroGeometrySettings",
    "CylindricalGearSetOptimisationWrapper",
    "CylindricalGearTableMGItemDetail",
    "CylindricalGearTableWithMGCharts",
    "CylindricalGearToothThicknessSpecification",
    "CylindricalMeshAngularBacklash",
    "CylindricalMeshedGear",
    "CylindricalMeshedGearFlank",
    "CylindricalMeshLinearBacklashSpecification",
    "CylindricalPlanetaryGearSetDesign",
    "CylindricalPlanetGearDesign",
    "DIN3967AllowanceSeries",
    "DIN3967ToleranceSeries",
    "DoubleAxisScaleAndRange",
    "FinishToothThicknessDesignSpecification",
    "GearFitSystems",
    "GearManufacturingConfigSetupViewModel",
    "GearSetManufacturingConfigurationSetup",
    "GeometrySpecificationType",
    "HardenedMaterialProperties",
    "HardnessProfileCalculationMethod",
    "HeatTreatmentType",
    "ISO6336Geometry",
    "ISO6336GeometryBase",
    "ISO6336GeometryForShapedGears",
    "ISO6336GeometryManufactured",
    "LinearBacklashSpecification",
    "LTCALoadCaseModifiableSettings",
    "LTCASettings",
    "MicroGeometryConvention",
    "MicroGeometryProfileConvention",
    "Micropitting",
    "MullerResidualStressDefinition",
    "NamedPlanetAssemblyIndex",
    "NamedPlanetSideBandAmplitudeFactor",
    "ReadonlyToothThicknessSpecification",
    "RelativeMeasurementViewModel",
    "RelativeValuesSpecification",
    "ResidualStressCalculationMethod",
    "RootStressSurfaceChartOption",
    "Scuffing",
    "ScuffingCoefficientOfFrictionMethods",
    "ScuffingTemperatureMethodsAGMA",
    "ScuffingTemperatureMethodsISO",
    "ShaperEdgeTypes",
    "SpurGearLoadSharingCodes",
    "StandardRack",
    "StandardRackFlank",
    "SurfaceRoughness",
    "ThicknessType",
    "TiffAnalysisSettings",
    "TipAlterationCoefficientMethod",
    "TolerancedMetalMeasurements",
    "TolerancedValueSpecification",
    "ToothFlankFractureAnalysisSettings",
    "ToothThicknessSpecification",
    "ToothThicknessSpecificationBase",
    "TypeOfMechanismHousing",
    "Usage",
)
