"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._3998 import (
        AbstractAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._3999 import (
        AbstractShaftCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4000 import (
        AbstractShaftOrHousingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4001 import (
        AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4002 import (
        AGMAGleasonConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4003 import (
        AGMAGleasonConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4004 import (
        AGMAGleasonConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4005 import (
        AssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4006 import (
        BearingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4007 import (
        BeltConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4008 import (
        BeltDriveCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4009 import (
        BevelDifferentialGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4010 import (
        BevelDifferentialGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4011 import (
        BevelDifferentialGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4012 import (
        BevelDifferentialPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4013 import (
        BevelDifferentialSunGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4014 import (
        BevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4015 import (
        BevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4016 import (
        BevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4017 import (
        BoltCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4018 import (
        BoltedJointCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4019 import (
        ClutchCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4020 import (
        ClutchConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4021 import (
        ClutchHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4022 import (
        CoaxialConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4023 import (
        ComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4024 import (
        ConceptCouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4025 import (
        ConceptCouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4026 import (
        ConceptCouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4027 import (
        ConceptGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4028 import (
        ConceptGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4029 import (
        ConceptGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4030 import (
        ConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4031 import (
        ConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4032 import (
        ConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4033 import (
        ConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4034 import (
        ConnectorCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4035 import (
        CouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4036 import (
        CouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4037 import (
        CouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4038 import (
        CVTBeltConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4039 import (
        CVTCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4040 import (
        CVTPulleyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4041 import (
        CycloidalAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4042 import (
        CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4043 import (
        CycloidalDiscCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4044 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4045 import (
        CylindricalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4046 import (
        CylindricalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4047 import (
        CylindricalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4048 import (
        CylindricalPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4049 import (
        DatumCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4050 import (
        ExternalCADModelCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4051 import (
        FaceGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4052 import (
        FaceGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4053 import (
        FaceGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4054 import (
        FEPartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4055 import (
        FlexiblePinAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4056 import (
        GearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4057 import (
        GearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4058 import (
        GearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4059 import (
        GuideDxfModelCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4060 import (
        HypoidGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4061 import (
        HypoidGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4062 import (
        HypoidGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4063 import (
        InterMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4064 import (
        KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4065 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4066 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4067 import (
        KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4068 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4069 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4070 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4071 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4072 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4073 import (
        MassDiscCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4074 import (
        MeasurementComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4075 import (
        MicrophoneArrayCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4076 import (
        MicrophoneCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4077 import (
        MountableComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4078 import (
        OilSealCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4079 import (
        PartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4080 import (
        PartToPartShearCouplingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4081 import (
        PartToPartShearCouplingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4082 import (
        PartToPartShearCouplingHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4083 import (
        PlanetaryConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4084 import (
        PlanetaryGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4085 import (
        PlanetCarrierCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4086 import (
        PointLoadCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4087 import (
        PowerLoadCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4088 import (
        PulleyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4089 import (
        RingPinsCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4090 import (
        RingPinsToDiscConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4091 import (
        RollingRingAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4092 import (
        RollingRingCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4093 import (
        RollingRingConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4094 import (
        RootAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4095 import (
        ShaftCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4096 import (
        ShaftHubConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4097 import (
        ShaftToMountableComponentConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4098 import (
        SpecialisedAssemblyCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4099 import (
        SpiralBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4100 import (
        SpiralBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4101 import (
        SpiralBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4102 import (
        SpringDamperCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4103 import (
        SpringDamperConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4104 import (
        SpringDamperHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4105 import (
        StraightBevelDiffGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4106 import (
        StraightBevelDiffGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4107 import (
        StraightBevelDiffGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4108 import (
        StraightBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4109 import (
        StraightBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4110 import (
        StraightBevelGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4111 import (
        StraightBevelPlanetGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4112 import (
        StraightBevelSunGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4113 import (
        SynchroniserCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4114 import (
        SynchroniserHalfCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4115 import (
        SynchroniserPartCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4116 import (
        SynchroniserSleeveCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4117 import (
        TorqueConverterCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4118 import (
        TorqueConverterConnectionCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4119 import (
        TorqueConverterPumpCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4120 import (
        TorqueConverterTurbineCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4121 import (
        UnbalancedMassCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4122 import (
        VirtualComponentCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4123 import (
        WormGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4124 import (
        WormGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4125 import (
        WormGearSetCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4126 import (
        ZerolBevelGearCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4127 import (
        ZerolBevelGearMeshCompoundStabilityAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound._4128 import (
        ZerolBevelGearSetCompoundStabilityAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.stability_analyses.compound._3998": [
            "AbstractAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._3999": [
            "AbstractShaftCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4000": [
            "AbstractShaftOrHousingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4001": [
            "AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4002": [
            "AGMAGleasonConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4003": [
            "AGMAGleasonConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4004": [
            "AGMAGleasonConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4005": [
            "AssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4006": [
            "BearingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4007": [
            "BeltConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4008": [
            "BeltDriveCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4009": [
            "BevelDifferentialGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4010": [
            "BevelDifferentialGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4011": [
            "BevelDifferentialGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4012": [
            "BevelDifferentialPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4013": [
            "BevelDifferentialSunGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4014": [
            "BevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4015": [
            "BevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4016": [
            "BevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4017": [
            "BoltCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4018": [
            "BoltedJointCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4019": [
            "ClutchCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4020": [
            "ClutchConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4021": [
            "ClutchHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4022": [
            "CoaxialConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4023": [
            "ComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4024": [
            "ConceptCouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4025": [
            "ConceptCouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4026": [
            "ConceptCouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4027": [
            "ConceptGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4028": [
            "ConceptGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4029": [
            "ConceptGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4030": [
            "ConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4031": [
            "ConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4032": [
            "ConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4033": [
            "ConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4034": [
            "ConnectorCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4035": [
            "CouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4036": [
            "CouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4037": [
            "CouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4038": [
            "CVTBeltConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4039": [
            "CVTCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4040": [
            "CVTPulleyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4041": [
            "CycloidalAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4042": [
            "CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4043": [
            "CycloidalDiscCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4044": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4045": [
            "CylindricalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4046": [
            "CylindricalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4047": [
            "CylindricalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4048": [
            "CylindricalPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4049": [
            "DatumCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4050": [
            "ExternalCADModelCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4051": [
            "FaceGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4052": [
            "FaceGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4053": [
            "FaceGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4054": [
            "FEPartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4055": [
            "FlexiblePinAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4056": [
            "GearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4057": [
            "GearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4058": [
            "GearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4059": [
            "GuideDxfModelCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4060": [
            "HypoidGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4061": [
            "HypoidGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4062": [
            "HypoidGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4063": [
            "InterMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4064": [
            "KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4065": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4066": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4067": [
            "KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4068": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4069": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4070": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4071": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4072": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4073": [
            "MassDiscCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4074": [
            "MeasurementComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4075": [
            "MicrophoneArrayCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4076": [
            "MicrophoneCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4077": [
            "MountableComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4078": [
            "OilSealCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4079": [
            "PartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4080": [
            "PartToPartShearCouplingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4081": [
            "PartToPartShearCouplingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4082": [
            "PartToPartShearCouplingHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4083": [
            "PlanetaryConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4084": [
            "PlanetaryGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4085": [
            "PlanetCarrierCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4086": [
            "PointLoadCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4087": [
            "PowerLoadCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4088": [
            "PulleyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4089": [
            "RingPinsCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4090": [
            "RingPinsToDiscConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4091": [
            "RollingRingAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4092": [
            "RollingRingCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4093": [
            "RollingRingConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4094": [
            "RootAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4095": [
            "ShaftCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4096": [
            "ShaftHubConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4097": [
            "ShaftToMountableComponentConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4098": [
            "SpecialisedAssemblyCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4099": [
            "SpiralBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4100": [
            "SpiralBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4101": [
            "SpiralBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4102": [
            "SpringDamperCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4103": [
            "SpringDamperConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4104": [
            "SpringDamperHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4105": [
            "StraightBevelDiffGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4106": [
            "StraightBevelDiffGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4107": [
            "StraightBevelDiffGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4108": [
            "StraightBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4109": [
            "StraightBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4110": [
            "StraightBevelGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4111": [
            "StraightBevelPlanetGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4112": [
            "StraightBevelSunGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4113": [
            "SynchroniserCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4114": [
            "SynchroniserHalfCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4115": [
            "SynchroniserPartCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4116": [
            "SynchroniserSleeveCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4117": [
            "TorqueConverterCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4118": [
            "TorqueConverterConnectionCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4119": [
            "TorqueConverterPumpCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4120": [
            "TorqueConverterTurbineCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4121": [
            "UnbalancedMassCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4122": [
            "VirtualComponentCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4123": [
            "WormGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4124": [
            "WormGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4125": [
            "WormGearSetCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4126": [
            "ZerolBevelGearCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4127": [
            "ZerolBevelGearMeshCompoundStabilityAnalysis"
        ],
        "_private.system_model.analyses_and_results.stability_analyses.compound._4128": [
            "ZerolBevelGearSetCompoundStabilityAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundStabilityAnalysis",
    "AbstractShaftCompoundStabilityAnalysis",
    "AbstractShaftOrHousingCompoundStabilityAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearMeshCompoundStabilityAnalysis",
    "AGMAGleasonConicalGearSetCompoundStabilityAnalysis",
    "AssemblyCompoundStabilityAnalysis",
    "BearingCompoundStabilityAnalysis",
    "BeltConnectionCompoundStabilityAnalysis",
    "BeltDriveCompoundStabilityAnalysis",
    "BevelDifferentialGearCompoundStabilityAnalysis",
    "BevelDifferentialGearMeshCompoundStabilityAnalysis",
    "BevelDifferentialGearSetCompoundStabilityAnalysis",
    "BevelDifferentialPlanetGearCompoundStabilityAnalysis",
    "BevelDifferentialSunGearCompoundStabilityAnalysis",
    "BevelGearCompoundStabilityAnalysis",
    "BevelGearMeshCompoundStabilityAnalysis",
    "BevelGearSetCompoundStabilityAnalysis",
    "BoltCompoundStabilityAnalysis",
    "BoltedJointCompoundStabilityAnalysis",
    "ClutchCompoundStabilityAnalysis",
    "ClutchConnectionCompoundStabilityAnalysis",
    "ClutchHalfCompoundStabilityAnalysis",
    "CoaxialConnectionCompoundStabilityAnalysis",
    "ComponentCompoundStabilityAnalysis",
    "ConceptCouplingCompoundStabilityAnalysis",
    "ConceptCouplingConnectionCompoundStabilityAnalysis",
    "ConceptCouplingHalfCompoundStabilityAnalysis",
    "ConceptGearCompoundStabilityAnalysis",
    "ConceptGearMeshCompoundStabilityAnalysis",
    "ConceptGearSetCompoundStabilityAnalysis",
    "ConicalGearCompoundStabilityAnalysis",
    "ConicalGearMeshCompoundStabilityAnalysis",
    "ConicalGearSetCompoundStabilityAnalysis",
    "ConnectionCompoundStabilityAnalysis",
    "ConnectorCompoundStabilityAnalysis",
    "CouplingCompoundStabilityAnalysis",
    "CouplingConnectionCompoundStabilityAnalysis",
    "CouplingHalfCompoundStabilityAnalysis",
    "CVTBeltConnectionCompoundStabilityAnalysis",
    "CVTCompoundStabilityAnalysis",
    "CVTPulleyCompoundStabilityAnalysis",
    "CycloidalAssemblyCompoundStabilityAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundStabilityAnalysis",
    "CycloidalDiscCompoundStabilityAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundStabilityAnalysis",
    "CylindricalGearCompoundStabilityAnalysis",
    "CylindricalGearMeshCompoundStabilityAnalysis",
    "CylindricalGearSetCompoundStabilityAnalysis",
    "CylindricalPlanetGearCompoundStabilityAnalysis",
    "DatumCompoundStabilityAnalysis",
    "ExternalCADModelCompoundStabilityAnalysis",
    "FaceGearCompoundStabilityAnalysis",
    "FaceGearMeshCompoundStabilityAnalysis",
    "FaceGearSetCompoundStabilityAnalysis",
    "FEPartCompoundStabilityAnalysis",
    "FlexiblePinAssemblyCompoundStabilityAnalysis",
    "GearCompoundStabilityAnalysis",
    "GearMeshCompoundStabilityAnalysis",
    "GearSetCompoundStabilityAnalysis",
    "GuideDxfModelCompoundStabilityAnalysis",
    "HypoidGearCompoundStabilityAnalysis",
    "HypoidGearMeshCompoundStabilityAnalysis",
    "HypoidGearSetCompoundStabilityAnalysis",
    "InterMountableComponentConnectionCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundStabilityAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundStabilityAnalysis",
    "MassDiscCompoundStabilityAnalysis",
    "MeasurementComponentCompoundStabilityAnalysis",
    "MicrophoneArrayCompoundStabilityAnalysis",
    "MicrophoneCompoundStabilityAnalysis",
    "MountableComponentCompoundStabilityAnalysis",
    "OilSealCompoundStabilityAnalysis",
    "PartCompoundStabilityAnalysis",
    "PartToPartShearCouplingCompoundStabilityAnalysis",
    "PartToPartShearCouplingConnectionCompoundStabilityAnalysis",
    "PartToPartShearCouplingHalfCompoundStabilityAnalysis",
    "PlanetaryConnectionCompoundStabilityAnalysis",
    "PlanetaryGearSetCompoundStabilityAnalysis",
    "PlanetCarrierCompoundStabilityAnalysis",
    "PointLoadCompoundStabilityAnalysis",
    "PowerLoadCompoundStabilityAnalysis",
    "PulleyCompoundStabilityAnalysis",
    "RingPinsCompoundStabilityAnalysis",
    "RingPinsToDiscConnectionCompoundStabilityAnalysis",
    "RollingRingAssemblyCompoundStabilityAnalysis",
    "RollingRingCompoundStabilityAnalysis",
    "RollingRingConnectionCompoundStabilityAnalysis",
    "RootAssemblyCompoundStabilityAnalysis",
    "ShaftCompoundStabilityAnalysis",
    "ShaftHubConnectionCompoundStabilityAnalysis",
    "ShaftToMountableComponentConnectionCompoundStabilityAnalysis",
    "SpecialisedAssemblyCompoundStabilityAnalysis",
    "SpiralBevelGearCompoundStabilityAnalysis",
    "SpiralBevelGearMeshCompoundStabilityAnalysis",
    "SpiralBevelGearSetCompoundStabilityAnalysis",
    "SpringDamperCompoundStabilityAnalysis",
    "SpringDamperConnectionCompoundStabilityAnalysis",
    "SpringDamperHalfCompoundStabilityAnalysis",
    "StraightBevelDiffGearCompoundStabilityAnalysis",
    "StraightBevelDiffGearMeshCompoundStabilityAnalysis",
    "StraightBevelDiffGearSetCompoundStabilityAnalysis",
    "StraightBevelGearCompoundStabilityAnalysis",
    "StraightBevelGearMeshCompoundStabilityAnalysis",
    "StraightBevelGearSetCompoundStabilityAnalysis",
    "StraightBevelPlanetGearCompoundStabilityAnalysis",
    "StraightBevelSunGearCompoundStabilityAnalysis",
    "SynchroniserCompoundStabilityAnalysis",
    "SynchroniserHalfCompoundStabilityAnalysis",
    "SynchroniserPartCompoundStabilityAnalysis",
    "SynchroniserSleeveCompoundStabilityAnalysis",
    "TorqueConverterCompoundStabilityAnalysis",
    "TorqueConverterConnectionCompoundStabilityAnalysis",
    "TorqueConverterPumpCompoundStabilityAnalysis",
    "TorqueConverterTurbineCompoundStabilityAnalysis",
    "UnbalancedMassCompoundStabilityAnalysis",
    "VirtualComponentCompoundStabilityAnalysis",
    "WormGearCompoundStabilityAnalysis",
    "WormGearMeshCompoundStabilityAnalysis",
    "WormGearSetCompoundStabilityAnalysis",
    "ZerolBevelGearCompoundStabilityAnalysis",
    "ZerolBevelGearMeshCompoundStabilityAnalysis",
    "ZerolBevelGearSetCompoundStabilityAnalysis",
)
