"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5808 import (
        AbstractAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5809 import (
        AbstractPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5810 import (
        AbstractShaftHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5811 import (
        AbstractShaftOrHousingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5812 import (
        AbstractShaftToMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5813 import (
        AGMAGleasonConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5814 import (
        AGMAGleasonConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5815 import (
        AGMAGleasonConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5816 import (
        AssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5817 import (
        BearingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5818 import (
        BeltConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5819 import (
        BeltDriveHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5820 import (
        BevelDifferentialGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5821 import (
        BevelDifferentialGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5822 import (
        BevelDifferentialGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5823 import (
        BevelDifferentialPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5824 import (
        BevelDifferentialSunGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5825 import (
        BevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5826 import (
        BevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5827 import (
        BevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5828 import (
        BoltedJointHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5829 import (
        BoltHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5830 import (
        ClutchConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5831 import (
        ClutchHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5832 import (
        ClutchHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5833 import (
        CoaxialConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5834 import (
        ComplianceAndForceData,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5835 import (
        ComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5836 import (
        ConceptCouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5837 import (
        ConceptCouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5838 import (
        ConceptCouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5839 import (
        ConceptGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5840 import (
        ConceptGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5841 import (
        ConceptGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5842 import (
        ConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5843 import (
        ConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5844 import (
        ConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5845 import (
        ConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5846 import (
        ConnectorHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5847 import (
        CouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5848 import (
        CouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5849 import (
        CouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5850 import (
        CVTBeltConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5851 import (
        CVTHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5852 import (
        CVTPulleyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5853 import (
        CycloidalAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5854 import (
        CycloidalDiscCentralBearingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5855 import (
        CycloidalDiscHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5856 import (
        CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5857 import (
        CylindricalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5858 import (
        CylindricalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5859 import (
        CylindricalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5860 import (
        CylindricalPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5861 import (
        DatumHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5862 import (
        DynamicModelForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5863 import (
        ElectricMachinePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5864 import (
        ElectricMachineRotorXForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5865 import (
        ElectricMachineRotorXMomentPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5866 import (
        ElectricMachineRotorYForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5867 import (
        ElectricMachineRotorYMomentPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5868 import (
        ElectricMachineRotorZForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5869 import (
        ElectricMachineStatorToothAxialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5870 import (
        ElectricMachineStatorToothLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5871 import (
        ElectricMachineStatorToothMomentsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5872 import (
        ElectricMachineStatorToothRadialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5873 import (
        ElectricMachineStatorToothTangentialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5874 import (
        ElectricMachineTorqueRipplePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5875 import (
        ExportOutputType,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5876 import (
        ExternalCADModelHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5877 import (
        FaceGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5878 import (
        FaceGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5879 import (
        FaceGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5880 import (
        FEPartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5881 import (
        FlexiblePinAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5882 import (
        FrequencyOptionsForHarmonicAnalysisResults,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5883 import (
        GearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5884 import (
        GearMeshExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5885 import (
        GearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5886 import (
        GearMeshMisalignmentExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5887 import (
        GearMeshTEExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5888 import (
        GearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5889 import (
        GeneralPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5890 import (
        GuideDxfModelHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5891 import (
        HarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5892 import (
        HarmonicAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5893 import (
        HarmonicAnalysisExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5894 import (
        HarmonicAnalysisFEExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5895 import (
        HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5896 import (
        HarmonicAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5897 import (
        HarmonicAnalysisRootAssemblyExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5898 import (
        HarmonicAnalysisShaftExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5899 import (
        HarmonicAnalysisTorqueInputType,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5900 import (
        HarmonicAnalysisWithVaryingStiffnessStaticLoadCase,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5901 import (
        HypoidGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5902 import (
        HypoidGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5903 import (
        HypoidGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5904 import (
        InterMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5905 import (
        KlingelnbergCycloPalloidConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5906 import (
        KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5907 import (
        KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5908 import (
        KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5909 import (
        KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5910 import (
        KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5911 import (
        KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5912 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5913 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5914 import (
        MassDiscHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5915 import (
        MeasurementComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5916 import (
        MicrophoneArrayHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5917 import (
        MicrophoneHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5918 import (
        MountableComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5919 import (
        OilSealHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5920 import (
        PartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5921 import (
        PartToPartShearCouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5922 import (
        PartToPartShearCouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5923 import (
        PartToPartShearCouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5924 import (
        PeriodicExcitationWithReferenceShaft,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5925 import (
        PlanetaryConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5926 import (
        PlanetaryGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5927 import (
        PlanetCarrierHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5928 import (
        PointLoadHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5929 import (
        PowerLoadHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5930 import (
        PulleyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5931 import (
        ResponseCacheLevel,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5932 import (
        RingPinsHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5933 import (
        RingPinsToDiscConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5934 import (
        RollingRingAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5935 import (
        RollingRingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5936 import (
        RollingRingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5937 import (
        RootAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5938 import (
        ShaftHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5939 import (
        ShaftHubConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5940 import (
        ShaftToMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5941 import (
        SingleNodePeriodicExcitationWithReferenceShaft,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5942 import (
        SpecialisedAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5943 import (
        SpeedOptionsForHarmonicAnalysisResults,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5944 import (
        SpiralBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5945 import (
        SpiralBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5946 import (
        SpiralBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5947 import (
        SpringDamperConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5948 import (
        SpringDamperHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5949 import (
        SpringDamperHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5950 import (
        StiffnessOptionsForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5951 import (
        StraightBevelDiffGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5952 import (
        StraightBevelDiffGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5953 import (
        StraightBevelDiffGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5954 import (
        StraightBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5955 import (
        StraightBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5956 import (
        StraightBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5957 import (
        StraightBevelPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5958 import (
        StraightBevelSunGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5959 import (
        SynchroniserHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5960 import (
        SynchroniserHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5961 import (
        SynchroniserPartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5962 import (
        SynchroniserSleeveHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5963 import (
        TorqueConverterConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5964 import (
        TorqueConverterHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5965 import (
        TorqueConverterPumpHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5966 import (
        TorqueConverterTurbineHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5967 import (
        UnbalancedMassExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5968 import (
        UnbalancedMassHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5969 import (
        VirtualComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5970 import (
        WormGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5971 import (
        WormGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5972 import (
        WormGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5973 import (
        ZerolBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5974 import (
        ZerolBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._5975 import (
        ZerolBevelGearSetHarmonicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses._5808": [
            "AbstractAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5809": [
            "AbstractPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5810": [
            "AbstractShaftHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5811": [
            "AbstractShaftOrHousingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5812": [
            "AbstractShaftToMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5813": [
            "AGMAGleasonConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5814": [
            "AGMAGleasonConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5815": [
            "AGMAGleasonConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5816": [
            "AssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5817": [
            "BearingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5818": [
            "BeltConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5819": [
            "BeltDriveHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5820": [
            "BevelDifferentialGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5821": [
            "BevelDifferentialGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5822": [
            "BevelDifferentialGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5823": [
            "BevelDifferentialPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5824": [
            "BevelDifferentialSunGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5825": [
            "BevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5826": [
            "BevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5827": [
            "BevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5828": [
            "BoltedJointHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5829": [
            "BoltHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5830": [
            "ClutchConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5831": [
            "ClutchHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5832": [
            "ClutchHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5833": [
            "CoaxialConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5834": [
            "ComplianceAndForceData"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5835": [
            "ComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5836": [
            "ConceptCouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5837": [
            "ConceptCouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5838": [
            "ConceptCouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5839": [
            "ConceptGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5840": [
            "ConceptGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5841": [
            "ConceptGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5842": [
            "ConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5843": [
            "ConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5844": [
            "ConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5845": [
            "ConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5846": [
            "ConnectorHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5847": [
            "CouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5848": [
            "CouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5849": [
            "CouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5850": [
            "CVTBeltConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5851": [
            "CVTHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5852": [
            "CVTPulleyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5853": [
            "CycloidalAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5854": [
            "CycloidalDiscCentralBearingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5855": [
            "CycloidalDiscHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5856": [
            "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5857": [
            "CylindricalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5858": [
            "CylindricalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5859": [
            "CylindricalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5860": [
            "CylindricalPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5861": [
            "DatumHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5862": [
            "DynamicModelForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5863": [
            "ElectricMachinePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5864": [
            "ElectricMachineRotorXForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5865": [
            "ElectricMachineRotorXMomentPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5866": [
            "ElectricMachineRotorYForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5867": [
            "ElectricMachineRotorYMomentPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5868": [
            "ElectricMachineRotorZForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5869": [
            "ElectricMachineStatorToothAxialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5870": [
            "ElectricMachineStatorToothLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5871": [
            "ElectricMachineStatorToothMomentsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5872": [
            "ElectricMachineStatorToothRadialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5873": [
            "ElectricMachineStatorToothTangentialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5874": [
            "ElectricMachineTorqueRipplePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5875": [
            "ExportOutputType"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5876": [
            "ExternalCADModelHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5877": [
            "FaceGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5878": [
            "FaceGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5879": [
            "FaceGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5880": [
            "FEPartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5881": [
            "FlexiblePinAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5882": [
            "FrequencyOptionsForHarmonicAnalysisResults"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5883": [
            "GearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5884": [
            "GearMeshExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5885": [
            "GearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5886": [
            "GearMeshMisalignmentExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5887": [
            "GearMeshTEExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5888": [
            "GearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5889": [
            "GeneralPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5890": [
            "GuideDxfModelHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5891": [
            "HarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5892": [
            "HarmonicAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5893": [
            "HarmonicAnalysisExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5894": [
            "HarmonicAnalysisFEExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5895": [
            "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5896": [
            "HarmonicAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5897": [
            "HarmonicAnalysisRootAssemblyExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5898": [
            "HarmonicAnalysisShaftExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5899": [
            "HarmonicAnalysisTorqueInputType"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5900": [
            "HarmonicAnalysisWithVaryingStiffnessStaticLoadCase"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5901": [
            "HypoidGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5902": [
            "HypoidGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5903": [
            "HypoidGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5904": [
            "InterMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5905": [
            "KlingelnbergCycloPalloidConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5906": [
            "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5907": [
            "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5908": [
            "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5909": [
            "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5910": [
            "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5911": [
            "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5912": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5913": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5914": [
            "MassDiscHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5915": [
            "MeasurementComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5916": [
            "MicrophoneArrayHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5917": [
            "MicrophoneHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5918": [
            "MountableComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5919": [
            "OilSealHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5920": [
            "PartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5921": [
            "PartToPartShearCouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5922": [
            "PartToPartShearCouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5923": [
            "PartToPartShearCouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5924": [
            "PeriodicExcitationWithReferenceShaft"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5925": [
            "PlanetaryConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5926": [
            "PlanetaryGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5927": [
            "PlanetCarrierHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5928": [
            "PointLoadHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5929": [
            "PowerLoadHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5930": [
            "PulleyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5931": [
            "ResponseCacheLevel"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5932": [
            "RingPinsHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5933": [
            "RingPinsToDiscConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5934": [
            "RollingRingAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5935": [
            "RollingRingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5936": [
            "RollingRingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5937": [
            "RootAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5938": [
            "ShaftHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5939": [
            "ShaftHubConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5940": [
            "ShaftToMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5941": [
            "SingleNodePeriodicExcitationWithReferenceShaft"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5942": [
            "SpecialisedAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5943": [
            "SpeedOptionsForHarmonicAnalysisResults"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5944": [
            "SpiralBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5945": [
            "SpiralBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5946": [
            "SpiralBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5947": [
            "SpringDamperConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5948": [
            "SpringDamperHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5949": [
            "SpringDamperHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5950": [
            "StiffnessOptionsForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5951": [
            "StraightBevelDiffGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5952": [
            "StraightBevelDiffGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5953": [
            "StraightBevelDiffGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5954": [
            "StraightBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5955": [
            "StraightBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5956": [
            "StraightBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5957": [
            "StraightBevelPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5958": [
            "StraightBevelSunGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5959": [
            "SynchroniserHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5960": [
            "SynchroniserHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5961": [
            "SynchroniserPartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5962": [
            "SynchroniserSleeveHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5963": [
            "TorqueConverterConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5964": [
            "TorqueConverterHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5965": [
            "TorqueConverterPumpHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5966": [
            "TorqueConverterTurbineHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5967": [
            "UnbalancedMassExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5968": [
            "UnbalancedMassHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5969": [
            "VirtualComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5970": [
            "WormGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5971": [
            "WormGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5972": [
            "WormGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5973": [
            "ZerolBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5974": [
            "ZerolBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._5975": [
            "ZerolBevelGearSetHarmonicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyHarmonicAnalysis",
    "AbstractPeriodicExcitationDetail",
    "AbstractShaftHarmonicAnalysis",
    "AbstractShaftOrHousingHarmonicAnalysis",
    "AbstractShaftToMountableComponentConnectionHarmonicAnalysis",
    "AGMAGleasonConicalGearHarmonicAnalysis",
    "AGMAGleasonConicalGearMeshHarmonicAnalysis",
    "AGMAGleasonConicalGearSetHarmonicAnalysis",
    "AssemblyHarmonicAnalysis",
    "BearingHarmonicAnalysis",
    "BeltConnectionHarmonicAnalysis",
    "BeltDriveHarmonicAnalysis",
    "BevelDifferentialGearHarmonicAnalysis",
    "BevelDifferentialGearMeshHarmonicAnalysis",
    "BevelDifferentialGearSetHarmonicAnalysis",
    "BevelDifferentialPlanetGearHarmonicAnalysis",
    "BevelDifferentialSunGearHarmonicAnalysis",
    "BevelGearHarmonicAnalysis",
    "BevelGearMeshHarmonicAnalysis",
    "BevelGearSetHarmonicAnalysis",
    "BoltedJointHarmonicAnalysis",
    "BoltHarmonicAnalysis",
    "ClutchConnectionHarmonicAnalysis",
    "ClutchHalfHarmonicAnalysis",
    "ClutchHarmonicAnalysis",
    "CoaxialConnectionHarmonicAnalysis",
    "ComplianceAndForceData",
    "ComponentHarmonicAnalysis",
    "ConceptCouplingConnectionHarmonicAnalysis",
    "ConceptCouplingHalfHarmonicAnalysis",
    "ConceptCouplingHarmonicAnalysis",
    "ConceptGearHarmonicAnalysis",
    "ConceptGearMeshHarmonicAnalysis",
    "ConceptGearSetHarmonicAnalysis",
    "ConicalGearHarmonicAnalysis",
    "ConicalGearMeshHarmonicAnalysis",
    "ConicalGearSetHarmonicAnalysis",
    "ConnectionHarmonicAnalysis",
    "ConnectorHarmonicAnalysis",
    "CouplingConnectionHarmonicAnalysis",
    "CouplingHalfHarmonicAnalysis",
    "CouplingHarmonicAnalysis",
    "CVTBeltConnectionHarmonicAnalysis",
    "CVTHarmonicAnalysis",
    "CVTPulleyHarmonicAnalysis",
    "CycloidalAssemblyHarmonicAnalysis",
    "CycloidalDiscCentralBearingConnectionHarmonicAnalysis",
    "CycloidalDiscHarmonicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis",
    "CylindricalGearHarmonicAnalysis",
    "CylindricalGearMeshHarmonicAnalysis",
    "CylindricalGearSetHarmonicAnalysis",
    "CylindricalPlanetGearHarmonicAnalysis",
    "DatumHarmonicAnalysis",
    "DynamicModelForHarmonicAnalysis",
    "ElectricMachinePeriodicExcitationDetail",
    "ElectricMachineRotorXForcePeriodicExcitationDetail",
    "ElectricMachineRotorXMomentPeriodicExcitationDetail",
    "ElectricMachineRotorYForcePeriodicExcitationDetail",
    "ElectricMachineRotorYMomentPeriodicExcitationDetail",
    "ElectricMachineRotorZForcePeriodicExcitationDetail",
    "ElectricMachineStatorToothAxialLoadsExcitationDetail",
    "ElectricMachineStatorToothLoadsExcitationDetail",
    "ElectricMachineStatorToothMomentsExcitationDetail",
    "ElectricMachineStatorToothRadialLoadsExcitationDetail",
    "ElectricMachineStatorToothTangentialLoadsExcitationDetail",
    "ElectricMachineTorqueRipplePeriodicExcitationDetail",
    "ExportOutputType",
    "ExternalCADModelHarmonicAnalysis",
    "FaceGearHarmonicAnalysis",
    "FaceGearMeshHarmonicAnalysis",
    "FaceGearSetHarmonicAnalysis",
    "FEPartHarmonicAnalysis",
    "FlexiblePinAssemblyHarmonicAnalysis",
    "FrequencyOptionsForHarmonicAnalysisResults",
    "GearHarmonicAnalysis",
    "GearMeshExcitationDetail",
    "GearMeshHarmonicAnalysis",
    "GearMeshMisalignmentExcitationDetail",
    "GearMeshTEExcitationDetail",
    "GearSetHarmonicAnalysis",
    "GeneralPeriodicExcitationDetail",
    "GuideDxfModelHarmonicAnalysis",
    "HarmonicAnalysis",
    "HarmonicAnalysisDrawStyle",
    "HarmonicAnalysisExportOptions",
    "HarmonicAnalysisFEExportOptions",
    "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation",
    "HarmonicAnalysisOptions",
    "HarmonicAnalysisRootAssemblyExportOptions",
    "HarmonicAnalysisShaftExportOptions",
    "HarmonicAnalysisTorqueInputType",
    "HarmonicAnalysisWithVaryingStiffnessStaticLoadCase",
    "HypoidGearHarmonicAnalysis",
    "HypoidGearMeshHarmonicAnalysis",
    "HypoidGearSetHarmonicAnalysis",
    "InterMountableComponentConnectionHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis",
    "MassDiscHarmonicAnalysis",
    "MeasurementComponentHarmonicAnalysis",
    "MicrophoneArrayHarmonicAnalysis",
    "MicrophoneHarmonicAnalysis",
    "MountableComponentHarmonicAnalysis",
    "OilSealHarmonicAnalysis",
    "PartHarmonicAnalysis",
    "PartToPartShearCouplingConnectionHarmonicAnalysis",
    "PartToPartShearCouplingHalfHarmonicAnalysis",
    "PartToPartShearCouplingHarmonicAnalysis",
    "PeriodicExcitationWithReferenceShaft",
    "PlanetaryConnectionHarmonicAnalysis",
    "PlanetaryGearSetHarmonicAnalysis",
    "PlanetCarrierHarmonicAnalysis",
    "PointLoadHarmonicAnalysis",
    "PowerLoadHarmonicAnalysis",
    "PulleyHarmonicAnalysis",
    "ResponseCacheLevel",
    "RingPinsHarmonicAnalysis",
    "RingPinsToDiscConnectionHarmonicAnalysis",
    "RollingRingAssemblyHarmonicAnalysis",
    "RollingRingConnectionHarmonicAnalysis",
    "RollingRingHarmonicAnalysis",
    "RootAssemblyHarmonicAnalysis",
    "ShaftHarmonicAnalysis",
    "ShaftHubConnectionHarmonicAnalysis",
    "ShaftToMountableComponentConnectionHarmonicAnalysis",
    "SingleNodePeriodicExcitationWithReferenceShaft",
    "SpecialisedAssemblyHarmonicAnalysis",
    "SpeedOptionsForHarmonicAnalysisResults",
    "SpiralBevelGearHarmonicAnalysis",
    "SpiralBevelGearMeshHarmonicAnalysis",
    "SpiralBevelGearSetHarmonicAnalysis",
    "SpringDamperConnectionHarmonicAnalysis",
    "SpringDamperHalfHarmonicAnalysis",
    "SpringDamperHarmonicAnalysis",
    "StiffnessOptionsForHarmonicAnalysis",
    "StraightBevelDiffGearHarmonicAnalysis",
    "StraightBevelDiffGearMeshHarmonicAnalysis",
    "StraightBevelDiffGearSetHarmonicAnalysis",
    "StraightBevelGearHarmonicAnalysis",
    "StraightBevelGearMeshHarmonicAnalysis",
    "StraightBevelGearSetHarmonicAnalysis",
    "StraightBevelPlanetGearHarmonicAnalysis",
    "StraightBevelSunGearHarmonicAnalysis",
    "SynchroniserHalfHarmonicAnalysis",
    "SynchroniserHarmonicAnalysis",
    "SynchroniserPartHarmonicAnalysis",
    "SynchroniserSleeveHarmonicAnalysis",
    "TorqueConverterConnectionHarmonicAnalysis",
    "TorqueConverterHarmonicAnalysis",
    "TorqueConverterPumpHarmonicAnalysis",
    "TorqueConverterTurbineHarmonicAnalysis",
    "UnbalancedMassExcitationDetail",
    "UnbalancedMassHarmonicAnalysis",
    "VirtualComponentHarmonicAnalysis",
    "WormGearHarmonicAnalysis",
    "WormGearMeshHarmonicAnalysis",
    "WormGearSetHarmonicAnalysis",
    "ZerolBevelGearHarmonicAnalysis",
    "ZerolBevelGearMeshHarmonicAnalysis",
    "ZerolBevelGearSetHarmonicAnalysis",
)
